@@ -375,8 +375,8 @@ static inline void encode_line(FFV1Context *s, int w, int_fast16_t *sample[2], i
     for(x=0; x<w; x++){
         int diff, context;
         
-        context= get_context(s, sample[1]+x, sample[0]+x, sample[2]+x);
-        diff= sample[1][x] - predict(sample[1]+x, sample[0]+x);
+        context= get_context(s, sample[0]+x, sample[1]+x, sample[2]+x);
+        diff= sample[0][x] - predict(sample[0]+x, sample[1]+x);
 
         if(context < 0){
             context = -context;
@@ -429,25 +429,22 @@ static inline void encode_line(FFV1Context *s, int w, int_fast16_t *sample[2], i
 }
 
 static void encode_plane(FFV1Context *s, uint8_t *src, int w, int h, int stride, int plane_index){
-    int x,y;
-    int_fast16_t sample_buffer[3][w+6];
-    int_fast16_t *sample[3]= {sample_buffer[0]+3, sample_buffer[1]+3, sample_buffer[2]+3};
+    int x,y,i;
+    const int ring_size= s->avctx->context_model ? 3 : 2;
+    int_fast16_t sample_buffer[ring_size][w+6], *sample[ring_size];
     s->run_index=0;
     
     memset(sample_buffer, 0, sizeof(sample_buffer));
     
     for(y=0; y<h; y++){
-        int_fast16_t *temp= sample[0]; //FIXME try a normal buffer
-
-        sample[0]= sample[1];
-        sample[1]= sample[2];
-        sample[2]= temp;
+        for(i=0; i<ring_size; i++)
+            sample[i]= sample_buffer[(h+i-y)%ring_size]+3;
         
-        sample[1][-1]= sample[0][0  ];
-        sample[0][ w]= sample[0][w-1];
+        sample[0][-1]= sample[1][0  ];
+        sample[1][ w]= sample[1][w-1];
 //{START_TIMER
         for(x=0; x<w; x++){
-            sample[1][x]= src[x + stride*y];
+            sample[0][x]= src[x + stride*y];
         }
         encode_line(s, w, sample, plane_index, 8);
 //STOP_TIMER("encode line")}
@@ -455,17 +452,18 @@ static void encode_plane(FFV1Context *s, uint8_t *src, int w, int h, int stride,
 }
 
 static void encode_rgb_frame(FFV1Context *s, uint32_t *src, int w, int h, int stride){
-    int x, y, p;
-    int_fast16_t sample_buffer[3][2][w+6];
-    int_fast16_t *sample[3][2]= {
-        {sample_buffer[0][0]+3, sample_buffer[0][1]+3},
-        {sample_buffer[1][0]+3, sample_buffer[1][1]+3},
-        {sample_buffer[2][0]+3, sample_buffer[2][1]+3}};
+    int x, y, p, i;
+    const int ring_size= s->avctx->context_model ? 3 : 2;
+    int_fast16_t sample_buffer[3][ring_size][w+6], *sample[3][ring_size];
     s->run_index=0;
     
     memset(sample_buffer, 0, sizeof(sample_buffer));
     
     for(y=0; y<h; y++){
+        for(i=0; i<ring_size; i++)
+            for(p=0; p<3; p++)
+                sample[p][i]= sample_buffer[p][(h+i-y)%ring_size]+3;
+
         for(x=0; x<w; x++){
             int v= src[x + stride*y];
             int b= v&0xFF;
@@ -485,13 +483,8 @@ static void encode_rgb_frame(FFV1Context *s, uint32_t *src, int w, int h, int st
             sample[2][0][x]= r;
         }
         for(p=0; p<3; p++){
-            int_fast16_t *temp= sample[p][0]; //FIXME try a normal buffer
-
-            sample[p][0]= sample[p][1];
-            sample[p][1]= temp;
-
-            sample[p][1][-1]= sample[p][0][0  ];
-            sample[p][0][ w]= sample[p][0][w-1];
+            sample[p][0][-1]= sample[p][1][0  ];
+            sample[p][1][ w]= sample[p][1][w-1];
             encode_line(s, w, sample[p], FFMIN(p, 1), 9);
         }
     }
@@ -948,8 +941,6 @@ static int decode_frame(AVCodecContext *avctx, void *data, int *data_size, uint8
 
     AVFrame *picture = data;
 
-    *data_size = 0;
-
     /* no supplementary picture */
     if (buf_size == 0)
         return 0;
@@ -968,6 +959,7 @@ static int decode_frame(AVCodecContext *avctx, void *data, int *data_size, uint8
     }else{
         p->key_frame= 0;
 	p->pict_type= FF_P_TYPE; // MEANX : looks more like a P to me as user
+ 
     }
 
     p->reference= 0;
@@ -1019,22 +1011,6 @@ static int decode_frame(AVCodecContext *avctx, void *data, int *data_size, uint8
     return bytes_read;
 }
 
-static int decode_end(AVCodecContext *avctx)
-{
-    FFV1Context *s = avctx->priv_data;
-    int i;
-    
-    if(avctx->get_buffer == avcodec_default_get_buffer){
-        for(i=0; i<4; i++){
-            av_freep(&s->picture.base[i]);
-            s->picture.data[i]= NULL;
-        }
-        av_freep(&s->picture.opaque);
-    }
-
-    return 0;
-}
-
 AVCodec ffv1_decoder = {
     "ffv1",
     CODEC_TYPE_VIDEO,
@@ -1042,7 +1018,7 @@ AVCodec ffv1_decoder = {
     sizeof(FFV1Context),
     decode_init,
     NULL,
-    decode_end,
+    NULL,
     decode_frame,
     CODEC_CAP_DR1 /*| CODEC_CAP_DRAW_HORIZ_BAND*/,
     NULL
