@@ -17,14 +17,15 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+#include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <ADM_assert.h>
 #include <string.h>
 #include <math.h>
-#include "config.h"
+
 #ifdef USE_FFMPEG
+#include <ADM_assert.h>
 
 #include "ADM_lavcodec.h"
 #include "ADM_library/default.h"
@@ -42,45 +43,37 @@
 #define MODULE_NAME  MODULE_CODEC
 #include "ADM_toolkit/ADM_debug.h"
 
-extern int DIA_getMPParams( int *pplevel, int *ppstrength,int *swap);
-//#include "../adm_lavcodec/mpegvideo.h"
-
-uint32_t PP_DefaultValue=3;
-uint32_t PP_DefaultStrength=5;
-
-void setPostProc(int v,int s)
-{
-	PP_DefaultValue=v;
-	PP_DefaultStrength=s;
-	printf("\n New default PP value  : %ld %ld",PP_DefaultValue,PP_DefaultStrength);
-
-}
+extern uint8_t DIA_lavDecoder(uint32_t *swapUv, uint32_t *showU);
 extern "C"
 {
-int av_is_voppacked(AVCodecContext *avctx);
+int av_is_voppacked(AVCodecContext *avctx, int *vop_packed, int *gmc, int *qpel);
 };
 uint8_t  decoderFF::isDivxPacked( void )
 {
-	return av_is_voppacked(_context);
+	int vop, gmc,qpel;
+	av_is_voppacked(_context,&vop,&gmc,&qpel);
+	return vop;
+}
+// Fill the bitfields for some mpeg4 specific info
+// It is a bit of a hack as we make it a general
+// stuff (i.e. shared with all codecs) whereas it is mpeg4 specific
+// and should stay within mpeg4 scope FIXME
+uint32_t decoderFF::getSpecificMpeg4Info( void )
+{
+	int vop, gmc,qpel;
+	uint32_t out=0;
+	av_is_voppacked(_context,&vop,&gmc,&qpel);
+	
+	if(qpel) out+=ADM_QPEL_ON;
+	if(gmc)  out+=ADM_GMC_ON;
+	
+	return out;
 }
-
 
 //________________________________________________
 void decoderFF::setParam( void )
 {
-	int postproc, strength,uv;
-		postproc=_postproc.postProcType;
-		strength=_postproc.postProcStrength;
-		uv=_swapUV;
-		if( DIA_getMPParams( &postproc,&strength,(int *)&_swapUV))
-		{
-				_postproc.postProcType=postproc;
-				_postproc.postProcStrength=strength;				
-				printf("\n new PP : %ld %ld \n",postproc,strength);
-				updatePostProc(&_postproc );				
-
-		}
-
+	DIA_lavDecoder(&_swapUV,&_showMv);
         return; // no param for ffmpeg
 }
 
@@ -104,18 +97,20 @@ decoderFF::decoderFF(uint32_t w,uint32_t h) :decoders(w,h)
 
 		  		_context->width=_w;
 				_context->height=_h;
-			  	_context->pix_fmt				=PIX_FMT_YUV420P;
+			  	_context->pix_fmt=PIX_FMT_YUV420P;//PIX_FMT_RGBA32
 				//_context->debug=1;
 
 			    _internalBuffer=new uint8_t[w*h*3];
 			   
 			    _swapUV=0;
-
-	   		    initPostProc(&_postproc,w,h);			    
-			    _postproc.postProcType=3;
-			    _postproc.postProcStrength=5;
-			    updatePostProc(&_postproc);
+				//_context->strict_std_compliance=-1;
+				
+				_showMv=0;
+#define FF_SHOW		(FF_DEBUG_VIS_MV_P_FOR+	FF_DEBUG_VIS_MV_B_FOR+FF_DEBUG_VIS_MV_B_BACK)
+//#define FF_SHOW		(FF_DEBUG_VIS_MV_P_FOR)
 			    printf("FFMpeg build : %d\n", LIBAVCODEC_BUILD);
+			_context->debug_mv 	|=FF_SHOW;
+			_context->debug		|=FF_DEBUG_VIS_MB_TYPE+FF_DEBUG_VIS_QP;
 }
 
 //_____________________________________________________
@@ -123,12 +118,8 @@ decoderFF::decoderFF(uint32_t w,uint32_t h) :decoders(w,h)
 decoderFF::~decoderFF()
 {
 		avcodec_close(_context);
-		free(_context);
-		delete [] _internalBuffer;
-		deletePostProc(&_postproc);
-		// if(_ppMode) {pp_free_mode(_ppMode);_ppMode=NULL;}
-		// if(_ppContext) {pp_free_context(_ppContext);_ppContext=NULL;}
-
+		ADM_dealloc(_context);
+		delete [] _internalBuffer;	
 		printf("FF base destroyed\n");
 }
 
@@ -176,7 +167,7 @@ uint8_t decoderFF::decodeFull(void )
 	return 1;
 }
 
-uint8_t     decoderFF::uncompress(uint8_t *in,uint8_t *out,uint32_t len,uint32_t *flagz)
+uint8_t     decoderFF::uncompress(uint8_t *in,ADMImage *out,uint32_t len,uint32_t *flagz)
 
 {
  int got_picture=0;
@@ -185,7 +176,18 @@ uint8_t     decoderFF::uncompress(uint8_t *in,uint8_t *out,uint32_t len,uint32_t
  int strideTab2[3];
  int ret=0;
 
-
+ 		if(_showMv) 
+		{
+			_context->debug_mv 	|= FF_SHOW;
+			_context->debug		|=0;//FF_DEBUG_VIS_MB_TYPE;
+			//_context->debug	|=FF_DEBUG_VIS_MB_TYPE+FF_DEBUG_VIS_QP;
+		}
+		else 
+		{
+			_context->debug_mv 	&=~FF_SHOW;
+			_context->debug		&=~(FF_DEBUG_VIS_MB_TYPE+FF_DEBUG_VIS_QP);
+		}
+			
 		if(len==0 && !_allowNull) // Null frame, silently skipped
 				{
             				if(flagz) *flagz=AVI_KEY_FRAME;
@@ -194,10 +196,11 @@ uint8_t     decoderFF::uncompress(uint8_t *in,uint8_t *out,uint32_t len,uint32_t
 				}
 
 		ret= avcodec_decode_video(_context,&_frame,&got_picture, in, len);
-		
+		out->_qStride=0; //Default = no quant
 		if(0>ret && !_context->hurry_up)
 		{
 					printf("\n error in FFMP43/mpeg4!\n");
+					printf("Err: %d, size :%d\n",ret,len);
 					return 0;
 		}
 		if(!got_picture && !_context->hurry_up)
@@ -205,9 +208,13 @@ uint8_t     decoderFF::uncompress(uint8_t *in,uint8_t *out,uint32_t len,uint32_t
 				// Some encoder code a vop header with the 
 				// vop flag set to 0
 				// it is meant to mean frame skipped but very dubious
-				if(len<8)
+				if(len<=8)
 					{
 						printf("Probably pseudo black frame...\n");
+						out->_Qp=2;
+						out->flags=0; // assume P ?
+						if(flagz)
+							*flagz=out->flags;
 						return 1;
 					}
 				// allow null means we allow null frame in and so potentially
@@ -216,12 +223,13 @@ uint8_t     decoderFF::uncompress(uint8_t *in,uint8_t *out,uint32_t len,uint32_t
 				if(_allowNull)
 				{
 					if(flagz) *flagz=AVI_KEY_FRAME;
-					memset(out,0,_w*_h);
-					memset(out+_w*_h,128,(_w*_h)>>1);
+					memset(out->data,0,_w*_h);
+					memset(out->data+_w*_h,128,(_w*_h)>>1);
 					printf("\n ignoring got pict ==0\n");
 					return 1;
 
 				}
+					printf("Err: %d, size :%d\n",ret,len);
 					printf("\n error in FFMP43/mpeg4!: got picture \n");
 					//GUI_Alert("Please retry with misc->Turbo off");
 					//return 1;
@@ -239,7 +247,7 @@ uint8_t     decoderFF::uncompress(uint8_t *in,uint8_t *out,uint32_t len,uint32_t
 		uint8_t **src;
 		uint32_t stridex[3];
 		uint8_t  *inx[3];
-
+		//printf("cspace %d\n", _context->pix_fmt);
 
 		switch(_context->pix_fmt)
 		{
@@ -262,10 +270,12 @@ uint8_t     decoderFF::uncompress(uint8_t *in,uint8_t *out,uint32_t len,uint32_t
 			_frame.linesize[0 ]=_w;
 			_frame.linesize[1 ]=_w>>1;
 			_frame.linesize[2 ]=_w>>1;
-
+			
+			
 			break;
 
 		case PIX_FMT_YUV422P:
+			//printf("422p\n");
 			stridex[0]=	_frame.linesize[0 ];
 			stridex[1]=	_frame.linesize[1 ];
 			stridex[2]=	_frame.linesize[2 ];
@@ -284,15 +294,44 @@ uint8_t     decoderFF::uncompress(uint8_t *in,uint8_t *out,uint32_t len,uint32_t
 			_frame.linesize[0 ]=_w;
 			_frame.linesize[1 ]=_w>>1;
 			_frame.linesize[2 ]=_w>>1;
+		
+			
 			break;
-		default:
-
+		
+		case PIX_FMT_YUV420P:
+		case PIX_FMT_YUVJ420P:
 		// Default is YV12 or I420
 		// In that case depending on swap u/v
 		// we do it or not
-
+	
+				//printf("420p\n");
 				src= (uint8_t **) _frame.data;
-#ifndef ADM_BIG_ENDIAN_ZZ
+				
+				if(_frame.qstride && _frame.qscale_table)	
+				{
+				if(out->quant)
+				{
+					{
+						uint8_t *src,*dst;
+						src=(uint8_t *)_frame.qscale_table;
+						dst=out->quant;
+						// Pack them
+						// /16 width = >>4
+						// /16 height= >>4
+						out->_qStride=(_w+15)>>4;
+						for(uint32_t y=0;y<((_h+15)>>4);y++)
+						{				
+							memcpy(dst,src,out->_qStride);
+							src+=_frame.qstride;
+							dst+=out->_qStride;
+							
+						}
+					}
+				}
+				}
+				else out->_qStride=0;
+
+#if 0
 			if(_postproc.postProcType && _postproc.postProcStrength)
 			{ 	// we do postproc !
 				// keep
@@ -320,10 +359,54 @@ uint8_t     decoderFF::uncompress(uint8_t *in,uint8_t *out,uint32_t len,uint32_t
 			}
 #endif
 			break;
+/*
+uint8_t COL_RawRGB32toYV12(uint8_t *data1,uint8_t *data2, uint8_t *oy,uint8_t *oy2, 
+				uint8_t *u, uint8_t *v,uint32_t lineSize)
+*/			
+		case PIX_FMT_RGBA32:
+				{
+				uint32_t stride;
+				uint8_t *data1,*data2;
+				uint8_t *oy,*oy2,*u,*v;
+				
+						
+						stride=	_frame.linesize[0 ];
+						data1=(uint8_t *)_frame.data[0];
+						data2=(uint8_t *)_frame.data[0]+stride;
+						oy=out->data;
+						oy2=out->data+_w;
+						if(!_swapUV)
+						{
+							u=out->data+(_w*_h);
+							v=out->data+((_w*_h*5)>>2);
+						
+						}
+						else
+						{
+							v=out->data+(_w*_h);
+							u=out->data+((_w*_h*5)>>2);	
+						}
+						
+						 COL_RawRGB32toYV12(data1,data2, oy,oy2, 
+							u, v,_w,_h,stride)	;
+						_lastQ=0; //_context->quality;	
+						if(flagz)
+						{
+							*flagz=frameType();
+						}
+						
+ 						return 1;
+				}
+		default:
+				printf("\n Unhandled colorspace:%d\n",_context->pix_fmt);
+				return 0;
+				
 		}
+		// Pack the output so that stride=width
+		
 		uint8_t *tmp;
 		tmp=src[0];
-		uint8_t *otmp= out;
+		uint8_t *otmp= out->data;
 		uint32_t stride;
 
 		stride=  _frame.linesize[0 ];
@@ -334,14 +417,21 @@ uint8_t     decoderFF::uncompress(uint8_t *in,uint8_t *out,uint32_t len,uint32_t
 				  	tmp+=stride;
    				  	otmp+=_w;
 				}
-		stride=  _frame.linesize[1 ];
+		
 
 		if(!_swapUV)
+		{
 			tmp= src[1];
+			stride=  _frame.linesize[1];
+		}
 		else
-			tmp= src[2];
+		{
+			tmp= src[2];			
+			stride=  _frame.linesize[2];
+		}
+			
 
-		otmp= out+_w*_h+((_w*_h)>>2);
+		otmp= out->data+((5*_w*_h)>>2);
 
 		for(uint32_t y=_h>>1;y>0;y--)
 			{
@@ -350,10 +440,16 @@ uint8_t     decoderFF::uncompress(uint8_t *in,uint8_t *out,uint32_t len,uint32_t
    				  	otmp+=_w>>1;
 				}
 		if(!_swapUV)
-			tmp= src[2];
+		{
+			tmp= src[2];			
+			stride=  _frame.linesize[2];
+		}
 		else
+		{
 			tmp= src[1];
-		otmp= out+_w*_h;
+			stride=  _frame.linesize[1];
+		}
+		otmp= out->data+_w*_h;
 
 		for(uint32_t y=_h>>1;y>0;y--)
 			{
@@ -364,13 +460,15 @@ uint8_t     decoderFF::uncompress(uint8_t *in,uint8_t *out,uint32_t len,uint32_t
 
 		_lastQ=0; //_context->quality;
 	//	printf("FF %d :: \n",_frame.pict_type);
+		out->_Qp=(_frame.quality*32)/FF_LAMBDA_MAX;
+		//printf("%d %d\n",_frame.quality,FF_LAMBDA_MAX);
+		out->flags=frameType();
 		if(flagz)
 		{
 
-			*flagz=frameType();
-
+			*flagz=out->flags;
 		}
-
+		
  		return 1;
 }
 
@@ -462,14 +560,18 @@ decoderFFSVQ3::decoderFFSVQ3(uint32_t w,uint32_t h,uint32_t extraLen,uint8_t *ex
 	    :decoderFF(w,h)
 {
 int got_picture=0;
+	
   	_context->flags|=CODEC_FLAG_LOW_DELAY;
+	 _context->extradata=(void *)extraData;
+      _context->extradata_size=(int)extraLen;
       if (avcodec_open(_context,& svq3_decoder) < 0)
 	      {
 					printf(" Decoder init: FFMpeg SVQ3 video decoder failed!\n");
 				}
 				else
 				{
-					printf(" Decoder init: FFMpeg SVQ3 video decoder initialized!\n");
+					printf(" Decoder init: FFMpeg SVQ3 video decoder initialized"
+						" (%lu bytes of extra)!\n",extraLen);
 				}
 
 }
@@ -558,6 +660,19 @@ decoderFFMJPEG::decoderFFMJPEG(uint32_t w,uint32_t h)       :decoderFF(w,h)
 				}
 
 }
+decoderSnow::decoderSnow(uint32_t w,uint32_t h)       :decoderFF(w,h)
+{
 
 
+      if (avcodec_open(_context,& snow_decoder) < 0)
+	      			{
+					printf(" Decoder init: FFMpeg snow video decoder failed!\n");
+				}
+				else
+				{
+					printf(" Decoder init: FFMpeg snow video decoder initialized!\n");
+				}
+
+}
+
 #endif
