@@ -17,13 +17,13 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+#include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <ADM_assert.h>
 #include <string.h>
 #include <math.h>
-#include "config.h"
+
 #include "ADM_library/default.h"
 #include "ADM_codecs/ADM_codec.h"
 #ifdef USE_XVID_4
@@ -31,6 +31,7 @@
 #include "ADM_codecs/ADM_xvid4param.h"
 #include "ADM_codecs/ADM_xvid4.h"
 #include "xvid.h"
+#include <ADM_assert.h>
 
 
 static const int motion_presets[] = {	
@@ -84,14 +85,17 @@ void xvid4_init(void)
 	printf("\txvid thread:%d\n",xvid_gbl_info.num_threads);
 	printf("\txvid SIMD supported:(%x)\n",xvid_gbl_info.cpu_flags);
 	#define CPUF(x) if(xvid_gbl_info.cpu_flags  & XVID_CPU_##x) printf("\t\t"#x"\n");	
-
+#ifdef USE_MMX
 	CPUF(MMX);
 	CPUF(MMXEXT);
 	CPUF(SSE);
 	CPUF(SSE2);
 	CPUF(3DNOW);
 	CPUF(3DNOWEXT);
+#endif	
+#ifdef USE_ALTIVEC	
 	CPUF(ALTIVEC);
+#endif	
 	
 }
 xvid4Encoder::~xvid4Encoder()
@@ -393,7 +397,7 @@ uint8_t xvid4EncoderCQ::init(uint32_t q,uint32_t fps1000, xvid4EncParam *param)
 
 
 uint8_t xvid4EncoderCQ::encode(
-			uint8_t * in,
+			ADMImage * in,
 			uint8_t * out,
 			uint32_t * len,
        			uint32_t * flags)
@@ -402,7 +406,7 @@ int ret;
 
 	
 	
-	preAmble(in);
+	preAmble(in->data);
 	
 	xvid_enc_frame.quant = _q;
 	xvid_enc_frame.bitstream = out;	
@@ -423,6 +427,112 @@ int ret;
 	
 	return 1;
 
+}
+// *************************************************
+// *************************************************
+//		CQ but Q is controlled externally
+// *************************************************
+// *************************************************
+
+uint8_t xvid4EncoderVBRExternal::init(uint32_t q,uint32_t fps1000, xvid4EncParam *param)
+{
+    int xerr;
+    	printf("Using Xvid 4 codec with CQ mode = %lu (%dx%d)\n",q,_w,_h);
+    	_q=q;
+	_fps1000=fps1000;	
+	memcpy(&_param,param,sizeof(_param));
+	dump();
+	// Here we go...
+	MMSET(xvid_enc_create);
+	xvid_enc_create.version = XVID_VERSION;
+	xvid_enc_create.width = _w;
+	xvid_enc_create.height = _h;
+	MMSET(single);
+	
+
+	plugins[0].func = xvid_plugin_single;
+	plugins[0].param = &single;
+	
+	single.version = XVID_VERSION;
+	single.bitrate = 1500;
+
+	xvid_enc_create.plugins = plugins;
+	xvid_enc_create.num_plugins = 1;
+	
+	//Framerate
+	xvid_enc_create.fincr = 1000;
+	xvid_enc_create.fbase = _fps1000;
+	//
+	createUpdate();
+	xerr = xvid_encore(NULL, XVID_ENC_CREATE, &xvid_enc_create, NULL);
+	if(xerr<0)
+	{
+		printf("Xvid-4 init error :%d\n",xerr);
+		return 0;
+	
+	}
+	
+	_handle = xvid_enc_create.handle;
+
+	printf("Xvid-4 CQ init Ok\n");
+
+ 	return 1;
+}
+
+
+uint8_t xvid4EncoderVBRExternal::encode(
+			ADMImage * in,
+			uint8_t * out,
+			uint32_t * len,
+       			uint32_t * flags)
+{
+int q;
+	q=(*flags)>>16;
+	*flags&=0xFFFF;
+	return encodeVBR(in,out,len,q,flags);
+}
+
+uint8_t xvid4EncoderVBRExternal::encodeVBR(
+			ADMImage * in,
+			uint8_t * out,
+			uint32_t * len,
+			uint32_t q,
+       			uint32_t * flags)
+{	
+int  ret;
+	preAmble(in->data);
+	
+	xvid_enc_frame.quant = q;
+	xvid_enc_frame.bitstream = out;	
+	if(*flags & AVI_KEY_FRAME)
+	{
+		xvid_enc_frame.type=XVID_TYPE_IVOP;
+	}
+	else if(*flags & AVI_B_FRAME)
+	{
+		xvid_enc_frame.type=XVID_TYPE_BVOP;
+	}
+	else
+	{	//P
+			xvid_enc_frame.type=XVID_TYPE_PVOP;
+	}
+	
+	/* Encode the frame */
+	ret = xvid_encore(_handle, XVID_ENC_ENCODE, &xvid_enc_frame,
+					  &xvid_enc_stats);
+	if(ret<0)
+		{
+			printf("Error calling xvid4 %d\n",ret);
+			return 0;
+			
+		}
+	postAmble(flags);
+	
+	*len=xvid_res.total_bits=ret;
+	xvid_res.total_bits*=8;
+	
+	return 1;
+
 }
 // *************************************************
 // *************************************************
@@ -477,7 +587,7 @@ uint8_t xvid4EncoderCBR::init(uint32_t br,uint32_t fps1000, xvid4EncParam *param
 
 
 uint8_t xvid4EncoderCBR::encode(
-			uint8_t * in,
+			ADMImage * in,
 			uint8_t * out,
 			uint32_t * len,
        			uint32_t * flags)
@@ -486,7 +596,7 @@ int ret;
 
 	
 	
-	preAmble(in);
+	preAmble(in->data);
 	
 	xvid_enc_frame.quant = 0;
 	xvid_enc_frame.bitstream = out;
@@ -570,7 +680,7 @@ uint8_t xvid4EncoderPass1::init(uint32_t br,uint32_t fps1000, xvid4EncParam *par
 
 
 uint8_t xvid4EncoderPass1::encode(
-			uint8_t * in,
+			ADMImage * in,
 			uint8_t * out,
 			uint32_t * len,
        			uint32_t * flags)
@@ -579,11 +689,11 @@ int ret;
 
 	
 	
-	preAmble(in);
+	preAmble(in->data);
 	
 	//xvid_enc_frame.quant = 2;
 	xvid_enc_frame.bitstream = out;
-	xvid_enc_frame.input.plane[0] = in;
+	xvid_enc_frame.input.plane[0] = YPLANE(in);
 	
 
 	
@@ -674,7 +784,7 @@ uint8_t xvid4EncoderPass2::init(uint32_t br,uint32_t fps1000, xvid4EncParam *par
 
 
 uint8_t xvid4EncoderPass2::encode(
-			uint8_t * in,
+			ADMImage * in,
 			uint8_t * out,
 			uint32_t * len,
        			uint32_t * flags)
@@ -683,10 +793,10 @@ int ret;
 
 	
 	
-	preAmble(in);
+	preAmble(in->data);
 		
 	xvid_enc_frame.bitstream = out;
-	xvid_enc_frame.input.plane[0] = in;
+	xvid_enc_frame.input.plane[0] = YPLANE(in);
 	
 
 	
@@ -707,4 +817,4 @@ int ret;
 	return 1;
 
 }
-#endif
\ No newline at end of file
+#endif
