@@ -16,6 +16,7 @@
  ***************************************************************************/
 #include <stdio.h>
 #include <stdlib.h>
+#include <math.h>
 #include <string.h>
 #include <ADM_assert.h>
 
@@ -36,6 +37,7 @@
 #include "ADM_dialog/DIA_working.h"
 #include "ADM_ogm/ADM_ogm.h"
 #include "ADM_assert.h"
+#include "prefs.h"
 
 #include "ADM_toolkit/ADM_debugID.h"
 #define MODULE_NAME MODULE_EDITOR
@@ -51,6 +53,8 @@ extern uint8_t indexMpeg (char *mpeg, char *file, uint8_t aid);
 extern uint8_t loadVideoCodecConf( char *name);
 //
 //
+int filterDefaultPPType=3;
+int filterDefaultPPStrength=3;
 
 #define TEST_MPEG2DEC
 
@@ -61,12 +65,20 @@ ADM_Composer::ADM_Composer (void)
   _total_frames = 0;
   _audioseg = 0;
   _audiooffset = 0;
+  _audioSample=0;
   _lastseg = 99;
   _lastframe = 99;
   _cached = 1;
   _nb_clipboard=0;
   _haveMarkers=0; // only edl have markers
-
+  // Initialize a default postprocessing (dummy)
+  initPostProc(&_pp,16,16);
+  _pp.postProcType=filterDefaultPPType;
+  _pp.postProcStrength=filterDefaultPPStrength;
+  _pp.forcedQuant=0;
+  updatePostProc(&_pp);
+  _imageBuffer=NULL;    
+  _internalFlags=0;
 }
 /**
 	Remap 1:1 video to segments
@@ -81,6 +93,7 @@ uint8_t ADM_Composer::resetSeg( void )
   		_segments[i]._audio_size = _videos[i]._audio_size;
   		_segments[i]._audio_start = 0;
   		_segments[i]._start_frame = 0;
+		_segments[i]._audio_duration = 0;		
 		_segments[i]._nb_frames   =   _videos[i]._nb_video_frames ;
 		_total_frames+=_segments[i]._nb_frames  ;
 		updateAudioTrack (i);
@@ -155,15 +168,17 @@ ADM_Composer::deleteAllVideos (void)
 	delete _videos[vid].decoder;
       // prevent from crashing
       _videos[vid]._aviheader->close ();
-      if(_videos[vid]._forwardFrame)
-      	{
-		delete [] _videos[vid]._forwardFrame;
-		_videos[vid]._forwardFrame=NULL;
-	}
       delete _videos[vid]._aviheader;
+      if(_videos[vid]._videoCache)
+      	delete  _videos[vid]._videoCache;
+      _videos[vid]._videoCache=NULL;
     }
 
   memset (_videos, 0, sizeof (_videos));
+  
+  if(_imageBuffer)
+  	delete _imageBuffer;
+  _imageBuffer=NULL;
 
 }
 
@@ -171,6 +186,10 @@ ADM_Composer::~ADM_Composer ()
 {
   deleteAllSegments ();
   deleteAllVideos ();
+  deletePostProc(&_pp);
+  if(_imageBuffer)
+  	delete _imageBuffer;
+  _imageBuffer=NULL;
 
 }
 
@@ -220,7 +239,23 @@ UNUSED_ARG(mode);
 			 ret = _videos[_nb_video]._aviheader->open(name); 			
 			break;
       
-      OPEN_AS (Nuppel_FileType, nuvHeader);
+    case Nuppel_FileType:
+	{ // look if the idx exists
+	  char *tmpname = (char*)ADM_alloc(strlen(name)+strlen(".idx")+1);
+		ADM_assert(tmpname);
+		sprintf(tmpname,"%s.idx",name);
+		if(addFile(tmpname))
+		{
+			return 1; // Memleak ?
+		}
+		ADM_dealloc(tmpname);
+		// open .nuv file
+		_videos[_nb_video]._aviheader=new nuvHeader;
+		ret = _videos[_nb_video]._aviheader->open(name);
+		// we store the native .nuv file in the edl
+		// the next load of the edl will open .idx instead
+		break;
+	}
       OPEN_AS (BMP_FileType, picHeader);
       OPEN_AS (MpegIdx_FileType, mpeg2decHeader);
       OPEN_AS (_3GPP_FileType, _3GPHeader);
@@ -234,6 +269,45 @@ UNUSED_ARG(mode);
 	strcat(tmpname,".idx");
 	if(addFile(tmpname)) return 1;
       // then propose to index it
+	{ unsigned int autoidx = 0;
+		prefs->get(FEATURE_TRYAUTOIDX,&autoidx);
+		if( autoidx ){
+		   mpegAudioTrack track[24];
+		   int tracknum = -1;
+		   int trackcount = 0;
+			if(MpegaudoDetectAudio(name,track)){
+				for(int i=0;i<8;i++){
+					if(track[i+8].presence){
+						tracknum = i;
+						trackcount++;
+					}
+					if(track[i].presence){
+						tracknum = 0xC0 | i;
+						trackcount++;
+					}
+					if(track[i+16].presence){
+						tracknum = 0xA0 | i;
+						trackcount++;
+					}
+				}
+				if( trackcount == 0 ){
+					printf("\nNo audio tracks found. Autoindex aborted ...\n");
+				}else if( trackcount > 1 ){
+					printf("\nMore than one audio track found. Autoindex aborted ...\n");
+				}else{
+					if(indexMpeg (name,tmpname,(uint8_t)tracknum)){
+						printf("\n re-opening %s\n",tmpname);
+						return addFile (tmpname, 0);
+					} // else goto GUI_Question
+				} // else goto GUI_Question
+			}else{ // no audio stream
+				if(indexMpeg (name,tmpname,0)){
+					printf("\n re-opening %s\n",tmpname);
+					return addFile (tmpname, 0); // memleak ?
+				} // else goto GUI_Question
+			}
+		}
+	}
       if (GUI_Question ("This looks like mpeg\n Do you want to index it?"))
 	{
 	  char *	  idx, *	    mname;
@@ -284,10 +358,29 @@ UNUSED_ARG(mode);
 	_aviheader;;
       return 0;
     }
-
+ 
   // else update info
   _videos[_nb_video]._aviheader->getVideoInfo (&info);
   _videos[_nb_video]._aviheader->setMyName (name);
+  // 1st if it is our first video we update postproc
+ if(!_nb_video)
+ {
+ 	
+	deletePostProc(&_pp );
+ 	initPostProc(&_pp,info.width,info.height);
+	_pp.postProcType=filterDefaultPPType;
+	_pp.postProcStrength=filterDefaultPPStrength;
+	_pp.forcedQuant=0;
+	updatePostProc(&_pp);
+
+	if(_imageBuffer) delete _imageBuffer;
+	_imageBuffer=new ADMImage(info.width,info.height);
+ 	_imageBuffer->_qSize= ((info.width+15)>>4)*((info.height+15)>>4);
+	_imageBuffer->quant=new uint8_t[_imageBuffer->_qSize];
+	_imageBuffer->_qStride=(info.width+15)>>4;
+ }
+    
+ 
 //    fourCC::print( info.fcc );
   _total_frames += info.nb_frames;
   _videos[_nb_video]._nb_video_frames = info.nb_frames;
@@ -303,11 +396,12 @@ UNUSED_ARG(mode);
     }
   else
     {
-
+float duration;
       _videos[_nb_video]._aviheader->getAudioStream (&_videos[_nb_video].
 						     _audiostream);
-      _videos[_nb_video]._audio_size =
-	_videos[_nb_video]._audiostream->getLength ();
+      _videos[_nb_video]._audio_size =_videos[_nb_video]._audiostream->getLength ();
+     
+      
 	// For mpeg2, try to guess if it is pulldowned material
 	double duration_a, duration_v;
 	double rdirect, rpulldown;
@@ -337,13 +431,18 @@ UNUSED_ARG(mode);
 			printf("Probably pulldowned, switching to 23.976 \n");
 			 AVIStreamHeader *ily =	_videos[_nb_video]._aviheader->	getVideoStreamHeader ();
       				ily->dwRate = 23976;
-      				ily->dwScale = 1000;			
+      				ily->dwScale = 1000;
+				info.fps1000=23976;	
 		
 		}
 		
 	
 	}
-	
+	duration=_videos[_nb_video]._nb_video_frames;
+	duration/=info.fps1000;
+	duration*=1000;			// duration in seconds
+	duration*=_wavinfo->frequency;  	// In sample
+	_videos[_nb_video]._audio_duration=(uint64_t)floor(duration);
 
     }
 
@@ -356,23 +455,23 @@ UNUSED_ARG(mode);
       info.fps1000 = 25 * 1000;
       updateVideoInfo (&info);
     }
-  uint32_t
-    l;
-  uint8_t *
-    d;
+  uint32_t    	l;
+  uint8_t 	*d;
   _videos[_nb_video]._aviheader->getExtraHeaderData (&l, &d);
   _videos[_nb_video].decoder = getDecoder (info.fcc,
 					   info.width, info.height, l, d);
 
-
+  _videos[_nb_video]._videoCache   =   new EditorCache(10,info.width,info.height) ;
   //
   //  And automatically create the segment
   //
   _segments[_nb_segment]._reference = _nb_video;
   _segments[_nb_segment]._audio_size = _videos[_nb_video]._audio_size;
+  _segments[_nb_segment]._audio_duration =_videos[_nb_video]._audio_duration;;
   _segments[_nb_segment]._audio_start = 0;
   _segments[_nb_segment]._start_frame = 0;
   _segments[_nb_segment]._nb_frames   =   _videos[_nb_video]._nb_video_frames ;
+
   _videos[_nb_video]._isAudioVbr=0;
   // next one please
 	_nb_video++;
@@ -388,8 +487,6 @@ TryAgain:
 	uint32_t err=0;
 
 		vid= &(_videos[_nb_video-1]);
-		vid->_forwardReference=0xFFFFFFF;
-		vid->_forwardFrame= NULL;
 		vid->_reorderReady=0;
 		// we only try if we got everything needed...
 		if(!vid->decoder)
@@ -403,24 +500,26 @@ TryAgain:
 			return 1;
 		}
 		printf("\n checking for B-Frames...\n");
-		if( vid->_nb_video_frames >15) // 12
+		if( vid->_nb_video_frames >12) // 12
 		{
-				uint8_t 		*buffer,*bufferin;
+				uint8_t 		*bufferin;
 				uint32_t 		len,flags,flag2;
 				uint8_t 		bframe=0, bconsistency=1;
-
-				buffer=new uint8_t [info.width* info.height*2];
+				uint32_t		scanned=12;
+				//buffer=new uint8_t [info.width* info.height*2];
+				if(vid->_nb_video_frames>50) scanned=50;
+				else				scanned=vid->_nb_video_frames;
+				
 				bufferin=new uint8_t [info.width* info.height*2];
-
-
+				ADMImage *buffer=new ADMImage(info.width,info.height);
 				// we decode 5 frames..should be enough to get an opinion
-				for(uint32_t i=0;i<13;i++)  //10
+				for(uint32_t i=0;i<scanned;i++)  //10
 				{
 					flags=flag2=0;
   					vid->_aviheader->getFrameNoAlloc (i,
 							 bufferin,
 							 &len, &flags);
-					if(!vid->decoder->uncompress( (uint8_t *)bufferin,(uint8_t *)buffer,len,&flag2 ))
+					if(!vid->decoder->uncompress( (uint8_t *)bufferin,buffer,len,&flag2 ))
 					{
 						err++;
 						printf("\n ***oops***\n");
@@ -443,15 +542,23 @@ TryAgain:
 					
 				}
 
-				delete [] buffer;
+				delete  buffer;
 				delete [] bufferin;
+				if(getEnv(ENV_EDITOR_BFRAME))
+				{
+					printf("Forcing Bframe present and incorrect\n");
+					bframe=1;
+					bconsistency=0;
+					
+				}
 				if(bframe)
 				{
 					printf("\n Mmm this appear to have b-frame...\n");
 					if(bconsistency)
 					{
 						printf("\n And the index is ok\n");
-						vid->_forwardFrame=new uint8_t [720*576*3];
+
+						//uint8_t [720*576*3];
 						vid->_reorderReady=vid->_aviheader->reorder();
 						if(vid->_reorderReady)
 						{
@@ -481,20 +588,27 @@ TryAgain:
 
 
 							//if(vid->decoder->isDivxPacked())
-							if(vid->decoder->isDivxPacked())
+							uint8_t forced= getEnv(ENV_EDITOR_PVOP);
+							if(vid->decoder->isDivxPacked() ||forced)
 							{
+								
 								// can only unpack avi
 								if(!count && type==AVI_FileType)
 								{
-									if(GUI_Question("It looks like Vop packed divx.\nDo you want me to unpack it ?"))
+									if( forced || GUI_Question(
+									"It looks like Vop packed divx.\n"
+									"Do you want me to unpack it ?"))
 									{
 									OpenDMLHeader *dml=NULL;
 									count++;	
 									dml=(OpenDMLHeader *)vid->_aviheader;
 									// Can we repack it ?
-									if(dml->unpackPacked())	
+									if(dml->unpackPacked())
+									{
 										goto TryAgain;
-									GUI_Alert("Could not unpack it\n, using backup decoder= not frame accurate.");
+									}
+									GUI_Alert("Could not unpack it\n"
+									", using backup decoder= not frame accurate.");
 									}
 								}
 #if  1 //def USE_DIVX
@@ -543,9 +657,9 @@ _VIDEOS *vid;
 				{
 						if((vid->_reorderReady=vid->_aviheader->reorder()))
 						{
+							aviInfo    info;
+							_videos[i]._aviheader->getVideoInfo (&info);
 							printf(" Video %lu has been reordered\n",i);
-							vid->_forwardFrame=new uint8_t [720*576*3];
-							vid->_forwardReference=0xFFFFFFF;
 						}
 
 				}
@@ -874,8 +988,8 @@ ADM_Composer::dumpSeg (void)
   printf ("\n________Video______________");
   for (seg = 0; seg < _nb_video; seg++)
     {
-      printf ("\n Video : %lu, nb video  :%lu, audio size:%lu",
-	      seg, _videos[seg]._nb_video_frames, _videos[seg]._audio_size);
+      printf ("\n Video : %lu, nb video  :%lu, audio size:%lu  audioDuration:%lu",
+	      seg, _videos[seg]._nb_video_frames, _videos[seg]._audio_size,_videos[seg]._audio_duration);
 
     }
 
@@ -883,20 +997,23 @@ ADM_Composer::dumpSeg (void)
   for (seg = 0; seg < _nb_segment; seg++)
     {
       printf
-	("\n Seg : %lu, ref: %lu start :%lu, size:%lu audio size : %lu audio start : %lu",
+	("\n Seg : %lu, ref: %lu start :%lu, size:%lu audio size : %lu audio start : %lu duration:%lu",
 	 seg, _segments[seg]._reference, _segments[seg]._start_frame,
 	 _segments[seg]._nb_frames, _segments[seg]._audio_size,
-	 _segments[seg]._audio_start);
+	 _segments[seg]._audio_start,
+	  _segments[seg]._audio_duration
+	 );
 
     }
   printf ("\n_________Clipboard_____________");
   for (seg = 0; seg < _nb_clipboard; seg++)
     {
       printf
-	("\n Seg : %lu, ref: %lu start :%lu, size:%lu audio size : %lu audio start : %lu\n",
+	("\n Seg : %lu, ref: %lu start :%lu, size:%lu audio size : %lu audio start : %lu  duration:%lu\n",
 	 seg, _clipboard[seg]._reference, _clipboard[seg]._start_frame,
 	 _clipboard[seg]._nb_frames, _clipboard[seg]._audio_size,
-	 _clipboard[seg]._audio_start);
+	 _clipboard[seg]._audio_start,
+	 _segments[seg]._audio_duration);
 
     }
 
@@ -950,6 +1067,7 @@ uint8_t
 //
 //      Update the real size of audio track by computing the
 // delta between sync @end and sync@begin
+// We also upate the duration of the selected part
 //
 
 uint8_t ADM_Composer::updateAudioTrack (uint32_t seg)
@@ -967,6 +1085,18 @@ uint8_t ADM_Composer::updateAudioTrack (uint32_t seg)
   // Mika
   if (!_videos[reference]._audiostream)
     return 1;
+  // Compute the resulting duration
+  // Of the segment
+  double duration;
+  aviInfo info;
+  	_videos[reference]._aviheader->getVideoInfo(&info);
+  	duration= _segments[seg]._nb_frames;
+	ADM_assert(info.fps1000);
+	duration/=info.fps1000;
+	duration*=1000*_videos[reference]._audiostream->getInfo()->frequency;
+	
+  _segments[seg]._audio_duration = (uint64_t)floor(duration);
+
   // If we cannot go to sync point start --> no need to continue
   // It can happen if audio track is shorter than video
   if (!audioGoToFn (seg, _segments[seg]._start_frame, &off))
@@ -993,7 +1123,7 @@ uint8_t ADM_Composer::updateAudioTrack (uint32_t seg)
 
   _segments[seg]._audio_size = pos_end - pos_start;
   _segments[seg]._audio_start = pos_start;
-
+  
   printf (" Audio start : %lu end : %lu size : %lu\n", pos_start, pos_end,
 	  _segments[seg]._audio_size);
 
@@ -1063,6 +1193,24 @@ uint8_t need_update=0;
     }
 
 }
+//_________________________________________
+uint8_t		ADM_Composer::setEnv(_ENV_EDITOR_FLAGS newflag)
+{
+	_internalFlags|=newflag;
+	return 1;
 
+}
+//_________________________________________
+//	Return 1 if the flag was set
+//		The flag is reset in all cases!!!!!!!!!!!!!
+uint8_t		ADM_Composer::getEnv(_ENV_EDITOR_FLAGS newflag)
+{
+uint8_t r=0;
+		if(_internalFlags&newflag) r=1;
+		_internalFlags&=~newflag;
+		if(r) { printf("Env override %d used\n",newflag);}
+		return r;
+
+}
 //
 //
