@@ -14,17 +14,18 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#include <config.h>
+ 
 #include <stdio.h>
 #include <stdlib.h>
 #include <strings.h>
 #include <math.h>
 #include <unistd.h>
-#include <ADM_assert.h>
+
 
 #include <time.h>
 #include <sys/time.h>
-#include <config.h>
+
 
 #include "gui_action.hxx"
 #ifdef USE_FFMPEG
@@ -34,7 +35,7 @@
 #include "fourcc.h"
 #include "avi_vars.h"
 #include "ADM_toolkit/toolkit.hxx"
-
+#include <ADM_assert.h>
 #include "ADM_encoder/ADM_vidEncode.hxx"
 
 #include "ADM_video/ADM_genvideo.hxx"
@@ -50,6 +51,9 @@
 #define MODULE_NAME MODULE_ENCODER
 #include "ADM_toolkit/ADM_debug.h"
 
+#include "ADM_dialog/DIA_enter.h"
+#include "oplug_mpeg/op_mpeg.h"
+#include "ADM_gui2/GUI_ui.h"
 
 extern void UI_setVProcessToggleStatus( uint8_t status );
 extern void GUI_setVideoCodec(Action action );
@@ -64,9 +68,15 @@ extern void oplug_mpeg_svcd(char *name);
 extern void oplug_mpeg_dvd(char *name);
 extern void oplug_mpeg_svcdConf( void );
 extern void oplug_mpeg_dvdConf( void );
+extern void mpeg_passthrough(  char *name );
 
+extern void UI_PrintCurrentVCodec(const char *str);
 extern void oplug_mpegff_conf(void);
 
+uint32_t encoderGetNbEncoder(void);
+const char* encoderGetIndexedName(uint32_t i);
+extern void UI_setVideoCodec(int i);
+
 #ifdef USE_XVID_4 
 	#include "ADM_codecs/ADM_xvid4.h"
 	#include "ADM_codecs/ADM_xvid4param.h"
@@ -99,8 +109,10 @@ extern int getFFCompressParams(COMPRESSION_MODE * mode, uint32_t * qz,
 	#include "ADM_encoder/adm_encmjpeg.h"
 #endif
 
-
-
+extern  uint8_t DIA_DVDffParam(COMPRESSION_MODE * mode, uint32_t * qz,
+		   				   uint32_t * br,uint32_t *fsize,
+						   FFcodecSetting *conf);
+#define FF_TRELLIS 0 // use treillis for mpeg1 encoding
 /*
   	Codec settings here
 
@@ -191,14 +203,14 @@ extern int getFFCompressParams(COMPRESSION_MODE * mode, uint32_t * qz,
 	0.5,		// spatial masking
 	0,		// NAQ
 	0,		// Use xvid ratecontrol
-	0,		// buffersize
+	40,		// buffersize VCD like
 	0		// DUMMY
 	
 	
  	}
   };
- FFMPEGConfig mpeg2encSVCDConfig={
-  	{COMPRESS_CBR,4,1500000,700},
+  FFMPEGConfig ffmpegMpeg2Config={
+  	{COMPRESS_CBR,4,1500*1000,700},
 	{
 	 ME_EPZS,//	ME
 	 0, // 		GMC
@@ -220,15 +232,15 @@ extern int getFFCompressParams(COMPRESSION_MODE * mode, uint32_t * qz,
 	 1,
  	 0.5,// 	qcompress;  /* amount of qscale change between easy & hard scenes (0.0-1.0)*/
     	 0.5,// 	qblur;      /* amount of qscale smoothing over time (0.0-1.0) */
-	(600*1000>>3),		// min bitrate in kB/S
-	(2200*1000)>>3,		// max bitrate
+	0,		// min bitrate in kB/S
+	(2500*1000)>>3,		// max bitrate
 	0,					// user_matrix 0->default, 1 tmpg, 2 anim , 3 kvcd
 	12,					// Safe gop size limit
 	NULL,				// inter & intra matrix, will be set depending on user_matrix
 	NULL,
-	0,				// interlaced
-	0,		        // WLA: bottom-field-first
-	0,				// widescreen
+	0,		// interlaced
+	0,		// WLA: bottom-field-first
+	0,		// wide screen
 	2,		// mb eval = distortion
 	8000,		// vratetol
 	0,
@@ -236,21 +248,25 @@ extern int getFFCompressParams(COMPRESSION_MODE * mode, uint32_t * qz,
 	0,
 	0.5,		// spatial masking
 	0,		// NAQ
+	1,		// Use xvid ratecontrol
+	112,		// buffersize 240 KB for Mpeg2 /
 	0		// DUMMY
+	
+	
  	}
   };
-  FFMPEGConfig mpeg2encDVDConfig={
-  	{COMPRESS_CBR,4,1500000,700},
+   FFMPEGConfig ffmpegMpeg2ConfigDVD={
+  	{COMPRESS_CBR,4,4*100*1000,3000},
 	{
 	 ME_EPZS,//	ME
 	 0, // 		GMC
 	 0,//		_4MV;
 	 0,//		_QPEL;
-	 0,//		_TREILLIS_QUANT
+	 FF_TRELLIS,//		_TREILLIS_QUANT
 	 2,//		qmin;
 	 31,//		qmax;
 	 3,//		max_qdiff;
-	 0,//		max_b_frames;
+	 2,//		max_b_frames;
 	 1, //		mpeg_quant;
 	 1,//
 	 -2, // 		luma_elim_threshold;
@@ -262,15 +278,15 @@ extern int getFFCompressParams(COMPRESSION_MODE * mode, uint32_t * qz,
 	 1,
  	 0.5,// 	qcompress;  /* amount of qscale change between easy & hard scenes (0.0-1.0)*/
     	 0.5,// 	qblur;      /* amount of qscale smoothing over time (0.0-1.0) */
-	(600*1000>>3),		// min bitrate in kB/S
+	0,		// min bitrate in kB/S
 	(8000*1000)>>3,		// max bitrate
 	0,					// user_matrix 0->default, 1 tmpg, 2 anim , 3 kvcd
 	12,					// Safe gop size limit
 	NULL,				// inter & intra matrix, will be set depending on user_matrix
 	NULL,
-	0,				// interlaced
-	0,		        // WLA: bottom-field-first
-	0,				// widescreen
+	0,		// interlaced
+	0,		// WLA: bottom-field-first
+	0,		// wide screen
 	2,		// mb eval = distortion
 	8000,		// vratetol
 	0,
@@ -278,9 +294,42 @@ extern int getFFCompressParams(COMPRESSION_MODE * mode, uint32_t * qz,
 	0,
 	0.5,		// spatial masking
 	0,		// NAQ
+	1,		// Use xvid ratecontrol
+	240,		// buffersize 240 KB for Mpeg2 /
 	0		// DUMMY
+	
+	
  	}
   };
+  // Mpeg2enc
+
+  #include "mpeg2enc/ADM_mpeg2enc.h"
+  
+ MPEG2ENCConfig mpeg2encSVCDConfig={
+  	{COMPRESS_CBR,4,1500000,700},
+	{
+	 	(2500*1000)>>3,		// Max BR
+		12,		// Gop size
+		0,		//int	wideScreen;
+		0,		//int	matrix;
+		0,		//int	interlacingType;
+		0		// bff
+	},
+	0		// unconfigured
+  };
+  
+  MPEG2ENCConfig mpeg2encDVDConfig={
+  	{COMPRESS_CBR,4,1500000,700},
+	{
+	 	(9000*1000)>>3,		// Max BR
+		12,		// Gop size
+		0,		//int	wideScreen;
+		0,		//int	matrix;
+		0,		//int	interlacingType;
+		0		// bff
+	},
+	0		// unconfigured
+  };
 
 
 #endif
@@ -398,7 +447,7 @@ static MJPEGConfig mjpegConfig={90,0};
 
 extern uint8_t DIA_mjpegCodecSetting( int *qual, int *swap );
 #endif
-char TwoPassLogFile[300]; 
+
 
 
 ///////////////////////////////////////////
@@ -407,15 +456,17 @@ SelectCodecType current_codec=CodecDivx;
 #else
 SelectCodecType current_codec=CodecFF;
 #endif
-
-EXTERN uint32_t videoProcessMode;
+extern void UI_PrintCurrentVCodec(const char *str);
+static void encoderPrint(void);
+static const char *encoderGetName(void);
+extern uint32_t videoProcessMode;
 
 uint8_t loadVideoCodecConf( char *name);
 uint8_t saveVideoCodecConf( char *name);
-static uint8_t mk_hex(uint8_t a,uint8_t b);
+uint8_t mk_hex(uint8_t a,uint8_t b);
 CodecFamilty videoCodecGetFamily( void )
 {
-	if(current_codec==CodecXVCD || current_codec==CodecXSVCD)
+	if(current_codec==CodecXVCD || current_codec==CodecXSVCD ||current_codec==CodecXDVD )
 			return CodecFamilyXVCD;
 	if(current_codec==CodecVCD || current_codec==CodecSVCD|| current_codec==CodecDVD)
 			 return CodecFamilyMpeg;
@@ -490,10 +541,16 @@ void videoCodecSetConf(  char *name,uint32_t extraLen, uint8_t *extraData)
 					case CodecVCD:
 						break;
 					case CodecSVCD:
-						MAKECONF(mpeg2encSVCDConfig);
+						if(extraLen && (extraLen == sizeof(mpeg2encSVCDConfig)) ){
+							memcpy(&mpeg2encSVCDConfig,extraData,extraLen);
+							mpeg2encSVCDConfig.configured = 1;
+						}
 						break;
 					case CodecDVD:
-						MAKECONF(mpeg2encDVDConfig);
+						if(extraLen && (extraLen == sizeof(mpeg2encDVDConfig)) ){
+							memcpy(&mpeg2encDVDConfig,extraData,extraLen);
+							mpeg2encDVDConfig.configured = 1;
+						}
 						break;
 
 
@@ -503,10 +560,16 @@ void videoCodecSetConf(  char *name,uint32_t extraLen, uint8_t *extraData)
 					case  CodecH263P:
 					case  CodecHuff:
 					case  CodecFFV1:
+					case  CodecSnow:
 											MAKECONF(ffmpegConfig);
 											break;
-					case CodecXVCD:
 					case CodecXSVCD:
+									MAKECONF(ffmpegMpeg2Config);
+									break;
+					case CodecXDVD:
+									MAKECONF(ffmpegMpeg2ConfigDVD);
+									break;
+					case CodecXVCD:
 									MAKECONF(ffmpegMpeg1Config);
 									break;
 #endif
@@ -567,13 +630,21 @@ const char  *videoCodecGetConf( uint32_t *optSize, uint8_t **data)
 					case  CodecH263P:
 					case  CodecHuff:
 					case  CodecFFV1:
+					case CodecSnow:
 
 
 											*data=(uint8_t *)&ffmpegConfig;
 											*optSize=sizeof(ffmpegConfig);
 											break;
-					case CodecXVCD:
 					case CodecXSVCD:
+									*data=(uint8_t *)&ffmpegMpeg2Config;
+									*optSize=sizeof(ffmpegMpeg2Config);
+									break;
+					case CodecXDVD:
+									*data=(uint8_t *)&ffmpegMpeg2ConfigDVD;
+									*optSize=sizeof(ffmpegMpeg2ConfigDVD);
+									break;
+					case CodecXVCD:
 
 									*data=(uint8_t *)&ffmpegMpeg1Config;
 									*optSize=sizeof(ffmpegMpeg1Config);
@@ -609,23 +680,42 @@ const char  *videoCodecGetConf( uint32_t *optSize, uint8_t **data)
 //%
 void EncoderSaveMpeg(char *name)
 {
-#ifdef USE_MJPEG
+uint8_t raw;
+	switch(UI_GetCurrentFormat())
+	{
+		case ADM_ES: 	raw=1;
+				break;
+		case ADM_PS:
+				raw=0;
+				break;
+		default:
+				GUI_Alert("Please select mpeg output");
+				return;
+	}
+	
 	switch(current_codec)
 	{
 		case CodecVCD:
-				oplug_mpeg_vcd(name);
+				if(raw)
+					oplug_mpeg_vcd(name);
+				else
+					oplug_mpeg_vcd_ps(name);
 				break;
 		case CodecSVCD:
-				oplug_mpeg_svcd(name);
+				if(raw)
+					oplug_mpeg_svcd(name);
+				else	
+					oplug_mpeg_svcd_ps(name);
 				break;
 		case CodecDVD:
-				oplug_mpeg_dvd(name);
+				if(raw)
+					oplug_mpeg_dvd(name);
+				else
+					oplug_mpeg_dvd_ps(name);
+				
 				break;
 		default:ADM_assert(0);
 	}
-#else
-	GUI_Alert("** NO MPEG ENCODING SUPPORT**");
-#endif
 
 }
 
@@ -679,6 +769,11 @@ int videoCodecConfigureAVI(  char *cmdString,uint32_t optSize, uint8_t *opt)
 						compmode=COMPRESS_2PASS;
 						aprintf("2pass\n");
 				}
+			if(!strcasecmp(cs,"follow"))
+				{
+						compmode=COMPRESS_SAME;
+						aprintf("Follow mode\n");
+				}
 			// search for other options
 			if(!strcasecmp(cs,"mbr")){
 			   compmode = NO_COMPRESSION_MODE;
@@ -730,48 +825,7 @@ int videoCodecConfigureAVI(  char *cmdString,uint32_t optSize, uint8_t *opt)
 
 		return 1;
 }
-#if 0
-void videoCodecConfigureMpeg(  char *cmdString)
-{
-// We accept 3 parameters
-		// mbr    : max bitrate in kbps
-		// quant : quant in kbps
-		// Other : Free string
-			char *i=cmdString;
-		        if( current_codec == CodecSVCD || current_codec ==CodecDVD ){
-				while( i && *i ){
-					if( !strncmp(i,"mbr=",4) ){
-					   unsigned int br;
-						i+=4;
-						br = atoi(i);
-						prefs->set( (current_codec==CodecSVCD ? CODECS_MPEG2ENC_SVCD_MAXBITRATE : CODECS_MPEG2ENC_DVD_MAXBITRATE), br );
-						i = index(i,','); if( i ) i++;
-						continue;
-					}
-					if( !strncmp(i,"quant=",6) ){
-					   unsigned int q;
-						i+=6;
-						q = atoi(i);
-						prefs->set( (current_codec==CodecSVCD ? CODECS_MPEG2ENC_SVCD_QUANTISATION : CODECS_MPEG2ENC_DVD_QUANTISATION), q );
-						i = index(i,','); if( i ) i++;
-						continue;
-					}
-					if( !strncmp(i,"other=",6) ){
-						i+=6;
-						prefs->set( (current_codec==CodecSVCD ? CODECS_MPEG2ENC_SVCD_EXTRAPARAMS : CODECS_MPEG2ENC_DVD_EXTRAPARAMS), i );
-						i = index(i,','); if( i ) i++;
-						continue;
-					}
-					break;
-				}
-			}
-			if( i && *i )
-				fprintf(stderr,"ignoring trailing \"%s\"\n",i);
-			return;
 
-
-}
-#endif
 int videoCodecConfigure(  char *cmdString,uint32_t optionSize,uint8_t  *option)
 {
 		CodecFamilty family;
@@ -798,46 +852,69 @@ int videoCodecConfigure(  char *cmdString,uint32_t optionSize,uint8_t  *option)
 
 }
 
-void encoderSetLogFile(char *name)
-{
-		strcpy( TwoPassLogFile,name);
-		printf("\n Log file is now :%s\n",TwoPassLogFile);
-}
 //___________________________________________________
 typedef struct codecEnumByName
 {
 	SelectCodecType type;
+	const char	*displayName;
 	const char	*name;
 }codecEnumByName;
 
 static const codecEnumByName mycodec[]=
 {
 #ifdef USE_DIVX
-	{CodecDivx	,"Divx"},
+	{CodecDivx	,"Divx","Divx"},
 #endif
 #ifdef USE_XX_XVID
-	{CodecXvid	,	"Xvid"},
+	{CodecXvid	,"Xvid","Xvid"},
 #endif
 
 #ifdef USE_XVID_4
-	{CodecXvid4	,	"Xvid4"},
+	{CodecXvid4	,"Xvid4","Xvid4"},
 #endif
-
-
-	{CodecMjpeg	,	"Mjpeg"},
+	{CodecMjpeg	,"MJpeg","Mjpeg"},
 #ifdef USE_MJPEG
-	{CodecVCD	,	"VCD"},
-	{CodecSVCD,	"SVCD"},
-	{CodecDVD,		"DVD"},
+	{CodecVCD	,"VCD","VCD"},
+	{CodecSVCD	,"SVCD","SVCD"},
+	{CodecDVD	,"DVD","DVD"},
 #endif
-	{CodecXVCD,	"XVCD"},
-	{CodecXSVCD,	"XSVCD"},
-	{CodecFF		,"FFmpeg4"},
-	{CodecH263	,	"H263"},
-	{CodecH263P	,"H263+"},
-	{CodecHuff		,"Huffyuv"},
-	{CodecFFV1		,"FFV1"}
+	{CodecXVCD	,"XVCD","XVCD"},
+	{CodecXSVCD	,"SVCD (lavc)","XSVCD"},
+	{CodecXDVD	,"DVD (lavc)","XDVD"},
+	{CodecFF	,"Lav Mpeg4","FFmpeg4"},
+	{CodecH263	,"H263","H263"},
+	{CodecH263P	,"H263+","H263+"},
+	{CodecHuff	,"Huffyuv","Huffyuv"},
+	{CodecFFV1	,"FFV1","FFV1"},
+	{CodecSnow	,"Snow","Snow"}
 };
+uint32_t encoderGetNbEncoder(void)
+{
+	return sizeof(mycodec)/sizeof(codecEnumByName);
+}
+const char* encoderGetIndexedName(uint32_t i)
+{
+	ADM_assert(i<sizeof(mycodec)/sizeof(codecEnumByName));
+	return mycodec[i].displayName;
+}
+void videoCodecChanged(int newcodec)
+{
+	ADM_assert(newcodec<sizeof(mycodec)/sizeof(codecEnumByName));
+	current_codec=mycodec[newcodec].type;
+}
+void encoderPrint(void)
+{
+	for(uint32_t i=0;i<sizeof(mycodec)/sizeof(codecEnumByName);i++)
+	{
+		if(current_codec==mycodec[i].type)
+		{
+			UI_setVideoCodec(i);
+			return;
+		}
+	
+	}
+	ADM_assert(0);
+}
 //___________________________________________________
 void saveEncoderConfig( void )
 {
@@ -851,6 +928,18 @@ void saveEncoderConfig( void )
 	}
 	
 }
+const char *encoderGetName(void)
+{
+	for(uint32_t i=0;i< sizeof(mycodec)/sizeof(codecEnumByName);i++)
+	{
+		if(current_codec==mycodec[i].type)
+			return mycodec[i].name;
+	
+	}
+	return "???";
+
+}
+
 void loadEncoderConfig ( void )
 {
  char *name;
@@ -860,6 +949,13 @@ void loadEncoderConfig ( void )
 			return;
 		}
 		videoCodecSelectByName(name);
+		/* change some hardcoded defaults ... */
+#ifdef USE_XX_XVID
+		prefs->get(CODECS_XVID_ENCTYPE,   (uint*)&(xvidConfig.generic.mode));
+		prefs->get(CODECS_XVID_QUANTIZER, &(xvidConfig.generic.qz));
+		prefs->get(CODECS_XVID_BITRATE,   &(xvidConfig.generic.bitrate));
+		prefs->get(CODECS_XVID_FINALSIZE, &(xvidConfig.generic.finalsize));
+#endif
 }
 int videoCodecSelectByName(const char *name)
 {
@@ -898,7 +994,8 @@ const char *videoCodecGetName( void )
 
 void initEncoders( void)
 {
-		strcpy( TwoPassLogFile,"/tmp/Xvid2passLog");
+//		strcpy( TwoPassLogFile,"/tmp/Xvid2passLog");
+		printf("**********OBSOLETE*********\n");
 }
 ///
 ///  Prompt for a codec and allow configuration
@@ -910,11 +1007,14 @@ uint8_t DIA_videoCodec( SelectCodecType *codec );
 void videoCodecSelect( void )
 {
 	DIA_videoCodec( &current_codec );
+	encoderPrint();
+	// HERE UI_PrintCurrentVCodec( (current_codec))
 
 }
 void videoCodecSetcodec(SelectCodecType codec)
 {
 	current_codec=codec;
+	encoderPrint();
 
 }
 void videoCodecConfigureUI( void )
@@ -938,11 +1038,25 @@ void videoCodecConfigureUI( void )
 						break;
 
 #endif
-		case CodecXVCD :
 		case CodecXSVCD :
-						oplug_mpegff_conf();
-
+			 			DIA_DVDffParam(&ffmpegMpeg2Config.generic.mode,
+								&ffmpegMpeg2Config.generic.qz,
+								&ffmpegMpeg2Config.generic.bitrate,
+								&ffmpegMpeg2Config.generic.finalsize,
+								&ffmpegMpeg2Config.specific);
 						break;
+		case CodecXDVD :
+			 			DIA_DVDffParam(&ffmpegMpeg2ConfigDVD.generic.mode,
+								&ffmpegMpeg2ConfigDVD.generic.qz,
+								&ffmpegMpeg2ConfigDVD.generic.bitrate,
+								&ffmpegMpeg2ConfigDVD.generic.finalsize,
+								&ffmpegMpeg2ConfigDVD.specific);
+						break;
+		case CodecXVCD :
+						oplug_mpegff_conf();
+						break;
+		
+
 
 #ifdef USE_XX_XVID
       	 	case CodecXvid :
@@ -976,6 +1090,17 @@ void videoCodecConfigureUI( void )
 				break;
 		case CodecFFV1:
 				break;
+		case CodecSnow:
+				{
+					//ffmpegConfig.generic.mode=COMPRESS_CQ;
+					int val=ffmpegConfig.generic.qz;
+					
+					  if(DIA_GetIntegerValue(&val, 2, 31, "Snow Quantizer","Snow Quantizer"))
+					  {
+						ffmpegConfig.generic.qz=val;;
+					  }
+				}
+					break;
 
 		case  CodecH263P:
 					printf("\n H263P\n");					
@@ -1061,13 +1186,17 @@ void setVideoEncoderSettings(COMPRESSION_MODE mode, uint32_t  param, uint32_t ex
 					case  CodecH263P:
 					case  CodecHuff:
 					case  CodecFFV1:
+					case  CodecSnow:
 
-											generic=&ffmpegConfig.generic ;
-											specific=&ffmpegConfig.specific;
-											specSize=sizeof(ffmpegConfig.specific);
-											break;
+									generic=&ffmpegConfig.generic ;
+									specific=&ffmpegConfig.specific;
+									specSize=sizeof(ffmpegConfig.specific);
+									break;
+					case CodecXSVCD:		generic=&ffmpegMpeg2Config.generic;
+									specific=&ffmpegMpeg2Config.specific;
+									specSize=sizeof(ffmpegMpeg2Config.specific);
+									break;
 					case CodecXVCD:
-					case CodecXSVCD:
 									generic=&ffmpegMpeg1Config.generic;
 									specific=&ffmpegMpeg1Config.specific;
 									specSize=sizeof(ffmpegMpeg1Config.specific);
@@ -1080,6 +1209,9 @@ void setVideoEncoderSettings(COMPRESSION_MODE mode, uint32_t  param, uint32_t ex
 	  generic->mode=mode;
 	  switch(mode)
 	  {
+	  			case COMPRESS_SAME:
+								aprintf("Same as input\n");
+								break;
 				case COMPRESS_CBR:
 								aprintf("CBR : %lu kbps\n",param);
 								generic->bitrate=param;
@@ -1137,6 +1269,9 @@ Encoder *e=NULL;
 		case   CodecFFV1:
 					e=new   EncoderFFMPEGFFV1(&ffmpegConfig);
 				    	break;
+		case   CodecSnow:
+					e=new EncodeFFMPEGSNow(&ffmpegConfig);
+					break;
 		case   CodecH263P:
 					e=new   EncoderFFMPEG(FF_H263P,&ffmpegConfig);
 				    	break;		
@@ -1296,3 +1431,6 @@ int a1,b1;
 	return (a1<<4)+b1;
 
 }
+
+
+// EOF
