@@ -17,7 +17,7 @@
  #ifndef __VIDEO_FILTERS__
  #define  __VIDEO_FILTERS__
 
- #define MAX_FILTER 60
+ #define MAX_FILTER 80
 #include "ADM_script/adm_scanner.h"
  	typedef enum
  	{
@@ -70,6 +70,9 @@
 		VF_DECOMB,
 		VF_DECIMATE,
 		VF_MSMOOTH,
+		VF_STACKFIELD,
+		VF_WHIRL,
+		VF_EQUALIZER,
 		VF_DUMMY
  	 }VF_FILTERS;
  	
@@ -94,13 +97,17 @@
    typedef struct
    {
    		uint32_t nb;
-		char 	*param[20];
+		const char 	*param[20];
    }FILTER_PARAM;
    
   AVDMGenericVideoStream *getLastVideoFilter( uint32_t frameStart, uint32_t nbFrame);
     AVDMGenericVideoStream *getLastVideoFilter( void );
  AVDMGenericVideoStream *getFirstVideoFilter( uint32_t frameStart, uint32_t nbFrame);
   AVDMGenericVideoStream *getFirstVideoFilter( void);
+  AVDMGenericVideoStream *getFirstCurrentVideoFilter( void);
+  
+  void	filterSetPostProc( void );
+  
 #ifdef USE_LIBXML2
 void filterSaveXml(char *name);
 void filterSaveXml(char *name,uint8_t silent);
