@@ -40,6 +40,8 @@
 #include "ADM_toolkit/ADM_debug.h"
 #include "ADM_toolkit/toolkit_gtk.h"
 
+#include "ADM_codecs/ADM_codec.h"
+#include "ADM_gui2/GUI_ui.h"
 
 void frame2time(uint32_t frame, uint32_t fps, uint16_t * hh, uint16_t * mm,
 	   uint16_t * ss, uint16_t * ms);
@@ -72,7 +74,13 @@ extern GtkWidget	*create_mainWindow (void);
 extern void guiCallback(GtkMenuItem * menuitem, gpointer user_data);
 extern void HandleAction(Action act);
 extern void UI_on_key_press(GtkWidget *widget, GdkEventKey* event, gpointer user_data);
-
+// To build vcodec
+extern uint32_t encoderGetNbEncoder(void);
+extern const char* encoderGetIndexedName(uint32_t i);
+// To build a codec
+uint32_t audioFilterGetNbEncoder(void);
+const char* audioFilterGetIndexedName(uint32_t i);
+//
 static uint8_t  bindGUI( void );
 static gboolean destroyCallback(GtkWidget * widget,	  GdkEvent * event, gpointer user_data);
 static gboolean  on_drawingarea1_expose_event(GtkWidget * widget,  GdkEventExpose * event, gpointer user_data);
@@ -115,11 +123,14 @@ buttonCallBack_S buttonCallback[]=
 	{"buttonSaveAvi"		,"clicked"		,ACT_SaveAvi},
 	{"buttonFilters"		,"clicked"		,ACT_VideoParameter},
 	{"buttonAudioFilter"		,"clicked"		,ACT_AudioFilters},
-	{"buttonVCodec"			,"clicked"		,ACT_VideoCodec},
-	{"buttonACodec"			,"clicked"		,ACT_AudioCodec},
+	{"buttonConfV"			,"clicked"		,ACT_VideoCodec},
+	{"buttonConfA"			,"clicked"		,ACT_AudioCodec},
 	{"buttonRecent"			,"clicked"		,ACT_RecentFiles},
 	{"buttonPrevBlack"		,"clicked"		,ACT_PrevBlackFrame},
 	{"buttonNextBlack"		,"clicked"		,ACT_NextBlackFrame},
+	{"buttonGotoA"			,"clicked"		,ACT_GotoMarkA},
+	{"buttonGotoB"			,"clicked"		,ACT_GotoMarkB},	
+	{"buttonBitrate"		,"clicked"		,ACT_Bitrate},	
 
 	{"togglebuttonPreview"		,"toggled"		,ACT_PreviewToggle},
 	{"toggleOutput"			,"toggled"		,ACT_OuputToggle},
@@ -130,7 +141,10 @@ buttonCallBack_S buttonCallback[]=
 	{"boxCurFrame"			,"editing_done"		,ACT_JumpToFrame},
 	{"boxCurFrame"			,"activate"		,ACT_JumpToFrame},
 	{"boxCurTime"			,"editing_done"		,ACT_TimeChanged},
-	{"togglebuttonAudio"		,"toggled"		,ACT_AudioModeToggle}
+	{"togglebuttonAudio"		,"toggled"		,ACT_AudioModeToggle},
+	{"optionVCodec"			,"changed"		,ACT_VideoCodecChanged},
+	{"optionACodec"			,"changed"		,ACT_AudioCodecChanged}
+	
 
 };
 
@@ -142,8 +156,9 @@ uint8_t initGUI( void )
 uint8_t ret=0;
 		// create top window
 		guiRootWindow=create_mainWindow();
-		if(!guiRootWindow) return 0;
 		
+		if(!guiRootWindow) return 0;
+		gtk_register_dialog(guiRootWindow);
 					
 		// and seek global sub entity
 		ret= bindGUI();		
@@ -159,17 +174,6 @@ uint8_t ret=0;
 	Set the parameter widget as transient 
 	for the main window
 */
-void		gtk_transient(GtkWidget *widget)
-{
-	if(!guiRootWindow) return;
-	gtk_window_set_modal(GTK_WINDOW(widget), 1);
-	gtk_window_set_transient_for (GTK_WINDOW(widget),GTK_WINDOW(guiRootWindow));
-	// set it modal also
-	
-	//gtk_window_set_transient_for (GTK_WINDOW(guiRootWindow),GTK_WINDOW(widget));
-
-
-}
 ///_____________________________________________________
 /// retrieve gtkwidget through their name
 /// the aim is to avoid having to modify the glade generated file
@@ -272,6 +276,42 @@ uint8_t  bindGUI( void )
  	gtk_signal_connect(GTK_OBJECT(guiDrawingArea), "expose_event",
 		       GTK_SIGNAL_FUNC(on_drawingarea1_expose_event),
 		       NULL);
+		       
+		       
+	// Finally add video codec...
+	uint32_t nbVid;
+	const char *name;
+	GtkWidget *menuv;
+		 menuv = gtk_menu_new ();
+		nbVid=encoderGetNbEncoder();
+		GtkWidget *vidWidget[nbVid];
+		printf("Found %d video encoder\n",nbVid);		       
+		for(uint32_t i=0;i<nbVid;i++)
+		{
+			name=encoderGetIndexedName(i);
+			vidWidget[i]=gtk_menu_item_new_with_mnemonic(name);
+  			gtk_widget_show (vidWidget[i]);
+  			gtk_container_add (GTK_CONTAINER (menuv), vidWidget[i]);
+		}
+	 gtk_option_menu_set_menu (GTK_OPTION_MENU (lookup_widget(guiRootWindow,"optionVCodec")), menuv);
+	// And A codec
+	// Finally add video codec...
+	uint32_t nbAud;
+	
+	GtkWidget *menua;
+		 menua = gtk_menu_new ();
+		nbAud=audioFilterGetNbEncoder();
+		GtkWidget *audWidget[nbAud];
+		printf("Found %d audio encoder\n",nbAud);		       
+		for(uint32_t i=0;i<nbAud;i++)
+		{
+			name=audioFilterGetIndexedName(i);
+			audWidget[i]=gtk_menu_item_new_with_mnemonic(name);
+  			gtk_widget_show (audWidget[i]);
+  			gtk_container_add (GTK_CONTAINER (menua), audWidget[i]);
+		}
+	 gtk_option_menu_set_menu (GTK_OPTION_MENU (lookup_widget(guiRootWindow,"optionACodec")), menua);
+
     return 1;
 
 }
@@ -318,26 +358,21 @@ void UI_setTitle(char *name)
  	gtk_window_set_title (GTK_WINDOW (guiRootWindow), title);
 
 }
-void UI_setFrameType( uint32_t frametype)
+void UI_setFrameType( uint32_t frametype,uint32_t qp)
 {
 GtkLabel *wid=(GtkLabel *)lookup_widget(guiRootWindow,"labelFrameType");
-
-	if(frametype==0xff)
-  			gtk_label_set_text( wid,"Frame: ?");
-	else
-		{
-			
-			if(frametype & 0x10)
-					gtk_label_set_text( wid,"Frame: I");
-			else
-				if(frametype & 0x4000)
-						gtk_label_set_text( wid,"Frame: B");
-					else
-						gtk_label_set_text( wid,"Frame: P");
-
-
-		}
-
+static char string[100];
+char	c='?';
+	switch(frametype)
+	{
+		case AVI_KEY_FRAME: c='I';break;
+		case AVI_B_FRAME: c='B';break;
+		case 0: c='P';break;
+		default:c='?';break;
+	
+	}
+	sprintf(string,"Frame:%c(%02d)",c,qp);
+	gtk_label_set_text( wid,string);	
 
 }
 ///
@@ -457,9 +492,9 @@ int UI_looseFocus( void)
 void UI_setMarkers(uint32_t a, uint32_t b )
 {
 char string[500];
-		sprintf(string,"A: %06lu",a);
+		sprintf(string," %06lu",a);
         	gtk_label_set_text(GTK_LABEL(guiMarkA),string);
-		sprintf(string,"B: %06lu",b);
+		sprintf(string," %06lu",b);
         	gtk_label_set_text(GTK_LABEL(guiMarkB),string);
 }
 ///
@@ -478,7 +513,7 @@ uint8_t UI_getPreviewToggleStatus( void )
 ///
 ///	Update the preview button toggle
 ///
-void UI_setPreviewToggleStatus( uint8_t status )
+uint8_t UI_setPreviewToggleStatus( uint8_t status )
 {
 gint b;
 	 if(status) b=TRUE;
@@ -585,6 +620,28 @@ void UI_BusyCursor( void )
 
 	
 }
+ int 	UI_getCurrentACodec(void)
+ {
+ 	return getRangeInMenu(lookup_widget(guiRootWindow,"optionACodec"));
+ 
+ }
+ int 	UI_getCurrentVCodec(void)
+ {
+ 
+ 	return getRangeInMenu(lookup_widget(guiRootWindow,"optionVCodec"));
+ 
+ }
+void UI_setAudioCodec( int i)
+{
+	gtk_option_menu_set_history(GTK_OPTION_MENU(lookup_widget(guiRootWindow,"optionACodec")), i);
+
+}
+void UI_setVideoCodec( int i)
+{
+	gtk_option_menu_set_history(GTK_OPTION_MENU(lookup_widget(guiRootWindow,"optionVCodec")), i);
+
+}
+
 void UI_NormalCursor( void )
 {
 //	gtk_widget_set_events(guiRootWindow,guiCursorEvtMask);
@@ -593,3 +650,21 @@ void UI_NormalCursor( void )
 
 	
 }
+void UI_PrintCurrentVCodec(const char *str)
+{
+ 	
+
+}
+ADM_OUT_FORMAT UI_GetCurrentFormat( void )
+{
+
+	return (ADM_OUT_FORMAT) getRangeInMenu(lookup_widget(guiRootWindow,"optionmenu1"));
+}
+uint8_t UI_SetCurrentFormat( ADM_OUT_FORMAT fmt )
+{
+
+	gtk_option_menu_set_history(GTK_OPTION_MENU(lookup_widget(guiRootWindow,"optionmenu1")), fmt);
+	return 1;
+}
+
+// EOF
