@@ -44,8 +44,9 @@
 
 //#define DEBUG
 //_____________________
-
+#include "config.h"
 #include <stdio.h>
+
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
@@ -53,14 +54,14 @@
           #include <sys/types.h>
 #endif
 #include <stdlib.h>
-#include <ADM_assert.h>
 #include <string.h>
-#include "config.h"
+
 #include "math.h"
 
 #include "ADM_library/default.h"
 #include "ADM_editor/ADM_Video.h"
 
+#include <ADM_assert.h>
 
 #include "ADM_library/fourcc.h"
 #include "ADM_nuv/ADM_nuv.h"
@@ -83,7 +84,7 @@ extern "C"
 #define MODULE_NAME MODULE_NUV
 #include "ADM_toolkit/ADM_debug.h"
 
-
+#include "prefs.h"
 #include "ADM_dialog/DIA_working.h"
 
 	#define DXFIELD(x) ((rtfileheader *)_nuv_header)->x
@@ -572,7 +573,7 @@ uint32_t rcount=0;
 								{\
 									vqueue=aqueue; \
 									aqueue=aqueue->_next; \
-									free(vqueue); \
+									ADM_dealloc(vqueue); \
 								}
 								aqueue=ahead._next;
 								PURGE;
@@ -623,10 +624,10 @@ uint32_t rcount=0;
 
 						/* Store R tags in rqueue for indexing/ chop by external tools */
 						rcount++;
-						n=(ChaineD *)malloc(sizeof(ChaineD));
+						n=(ChaineD *)ADM_alloc(sizeof(ChaineD));
 						ADM_assert(n);
 						n->_next=NULL;
-						n->_frame=(rtframeheader *)malloc(sizeof(rtframeheader));
+						n->_frame=(rtframeheader *)ADM_alloc(sizeof(rtframeheader));
 						n->_frame->comptype='R';
 						//memcpy(n->_frame,&frame,sizeof(frame));
 						n->_pos=ftello(_fd);
@@ -664,14 +665,14 @@ uint32_t rcount=0;
 #ifdef VERBOSE_SOUND
           					printf("\n Frame %lu, overshot %ld",v,overshot);
 #endif
-						if((overshot < -THRESHOLD)&&(_isPCM))
+						if(  (overshot < -THRESHOLD)&& _isPCM &&_audioResync)
 						{
 						// we insert a dummy packet in audio chain to compensate
 												
-						n=(ChaineD *)malloc(sizeof(ChaineD));
+						n=(ChaineD *)ADM_alloc(sizeof(ChaineD));
 						ADM_assert(n);
 						n->_next=NULL;
-						n->_frame=(rtframeheader *)malloc(sizeof(rtframeheader));
+						n->_frame=(rtframeheader *)ADM_alloc(sizeof(rtframeheader));
 						n->_frame->packetlength=THRESHOLD;
 #ifdef VERBOSE_SOUND
           					printf("\n Added %lu bytes",THRESHOLD);
@@ -797,10 +798,10 @@ uint32_t rcount=0;
 				// Video Chunk !!
 				case 'V':
 						if(!sync_met) break;
-						n=(ChaineD *)malloc(sizeof(ChaineD));
+						n=(ChaineD *)ADM_alloc(sizeof(ChaineD));
 						ADM_assert(n);
 						n->_next=NULL;
-						n->_frame=(rtframeheader *)malloc(sizeof(rtframeheader));
+						n->_frame=(rtframeheader *)ADM_alloc(sizeof(rtframeheader));
 						memcpy(n->_frame,&frame,sizeof(frame));
 						n->_pos=ftello(_fd);
 						 n->_kf=0;
@@ -823,10 +824,10 @@ uint32_t rcount=0;
 						// if it !PCM we take it as is
 						if(!_isPCM)
 						{
-							n=(ChaineD *)malloc(sizeof(ChaineD));
+							n=(ChaineD *)ADM_alloc(sizeof(ChaineD));
 							ADM_assert(n);
 							n->_next=NULL;
-							n->_frame=(rtframeheader *)malloc(sizeof(rtframeheader));
+							n->_frame=(rtframeheader *)ADM_alloc(sizeof(rtframeheader));
 							memcpy(n->_frame,&frame,sizeof(frame));
 							alen= n->_frame->packetlength;
 							n->_pos=ftello(_fd);
@@ -846,10 +847,10 @@ uint32_t rcount=0;
 									overshot-=frame.packetlength;
 									break;
 							}
-						n=(ChaineD *)malloc(sizeof(ChaineD));
+						n=(ChaineD *)ADM_alloc(sizeof(ChaineD));
 						ADM_assert(n);
 						n->_next=NULL;
-						n->_frame=(rtframeheader *)malloc(sizeof(rtframeheader));
+						n->_frame=(rtframeheader *)ADM_alloc(sizeof(rtframeheader));
 
 
 						memcpy(n->_frame,&frame,sizeof(frame));
@@ -892,10 +893,10 @@ uint32_t rcount=0;
 							{
 							// we insert a dummy packet in audio chain to compensate
 
-						n=(ChaineD *)malloc(sizeof(ChaineD));
+						n=(ChaineD *)ADM_alloc(sizeof(ChaineD));
 						ADM_assert(n);
 						n->_next=NULL;
-						n->_frame=(rtframeheader *)malloc(sizeof(rtframeheader));
+						n->_frame=(rtframeheader *)ADM_alloc(sizeof(rtframeheader));
 						n->_frame->packetlength=iestim-current_audio;
 						n->_frame->comptype='R';
 						//memcpy(n->_frame,&frame,sizeof(frame));
@@ -951,8 +952,8 @@ uint32_t rcount=0;
 
 			p=n;
 			n=n->_next;
-			free(p->_frame);
-			free(p);
+			ADM_dealloc(p->_frame);
+			ADM_dealloc(p);
 		}
 
 		// Scan rframe chain
@@ -967,8 +968,8 @@ uint32_t rcount=0;
 			_rIndex[i]._compression=n->_frame->comptype;
 			p=n;
 			n=n->_next;
-			free(p->_frame);
-			free(p);
+			ADM_dealloc(p->_frame);
+			ADM_dealloc(p);
 		}
 
 			// Scan audio chain
@@ -982,8 +983,8 @@ uint32_t rcount=0;
 			_audioIndex[i]._compression=n->_frame->comptype;
 			p=n;
 			n=n->_next;
-			free(p->_frame);
-			free(p);
+			ADM_dealloc(p->_frame);
+			ADM_dealloc(p);
 		}
 		printf("\n Index collapsed, found %lu keyframes\n",kf);
 		//
@@ -1052,25 +1053,38 @@ uint32_t rcount=0;
 #endif
 	       _old=new uint8_t [ DXFIELD(height)*DXFIELD(width)*3]; // too much
 	       delete work;
-// Jens patch here :)
 #if 1
-	       if(GUI_Question("Do you want to save an index ?"))
-	       {
-			char *mname=NULL;
-				GUI_FileSelWrite("Nuv index to save..",&mname);
-				if(mname)
-				{
-					saveIndex( mname,name);
+		{ unsigned int autoidx = 0;
+		  char *mname=NULL;
+			prefs->get(FEATURE_TRYAUTOIDX,&autoidx);
+			if( autoidx ){
+				mname = (char*)ADM_alloc(strlen(name)+strlen(".idx")+1);
+				ADM_assert(mname);
+				sprintf(mname,"%s.idx",name);
+				if( saveIndex( mname,name) == 1 ){
+					ADM_dealloc(mname);
+					return 1;
 				}
-	       }
-#endif // oops thanks Jens :)
+				ADM_dealloc(mname);
+			}
+			if(GUI_Question("Do you want to save an index ?")){
+				GUI_FileSelWrite("Nuv index to save..",&mname);
+				if(mname){
+					saveIndex( mname,name);
+					ADM_dealloc(mname);
+				}
+			}
+		}
+#endif
 	       return 1;
 
 }
 // Constructor , does nothing except insure null pointers
 nuvHeader::nuvHeader(void )
 {
+uint32_t sync;
 
+_audioResync=1;
 _videoIndex=NULL;
 _audioIndex=NULL;
 _tableIndex=NULL;
@@ -1095,6 +1109,14 @@ _ffv1_fourcc=0;
 _ffv1_extraLen=0;
 _ffv1_extraData=NULL;
 _audio_frequency=44100;
+if(prefs->get(FEATURE_DISABLE_NUV_RESYNC,&sync))
+{
+	if(sync) 
+	{
+		printf("******** AUDIO RESYNC DISABLED *************\n");
+		_audioResync=0;
+	}
+}
 
 }
 nuvHeader::~nuvHeader( )
@@ -1157,7 +1179,7 @@ uint8_t nuvHeader::saveIndex( const char *name,const char *org)
 	fprintf(fd,"ADNV\n"); // mark it as a avidemux index
 	fprintf(fd,"File: %s\n",org ); // mark it as a avidemux index
 	fprintf(fd,"wh: %lu %lu\n",DXFIELD(width), DXFIELD(height) ); // mark it as a avidemux index
-	fprintf(fd,"fps: %lu",_videostream.dwRate);
+	fprintf(fd,"fps: %lu\n",_videostream.dwRate);
 	fprintf(fd,"Lzo Pos:%llu\n",_lzo_pos);
 	fprintf(fd,"Lzo Size:%llu\n",_lzo_size);
 	fprintf(fd,"\n");
@@ -1165,6 +1187,13 @@ uint8_t nuvHeader::saveIndex( const char *name,const char *org)
 	fprintf(fd,"Xvid:%d\n",_isXvid);
 	fprintf(fd,"FFV1:%d\n",_isFFV1);
 	fprintf(fd,"ff4c:%x\n",_ffv1_fourcc);
+	fprintf(fd,"extr:%x\n",_ffv1_extraLen);
+	if(_ffv1_extraLen)
+	{
+		for(uint32_t i=0;i<_ffv1_extraLen;i++)
+			fprintf(fd,"%02x ",_ffv1_extraData[i]);
+		fprintf(fd,"\n");
+	}
 	fprintf(fd,"PCM:%d\n",_isPCM);
 	fprintf(fd,"Fq:%d\n",_audio_frequency);
 	fprintf(fd,"%lu video frames\n",_mainaviheader.dwTotalFrames);
@@ -1211,6 +1240,8 @@ uint8_t nuvHeader::saveIndex( const char *name,const char *org)
 /**
 		Load  as quick index for easy access
 */
+extern uint8_t mk_hex(uint8_t a,uint8_t b);
+
 uint8_t nuvHeader::loadIndex( const char *name)
 {
 char str[1024];
@@ -1288,6 +1319,27 @@ FILE *fd;
 	fscanf(fd,"Xvid:%d\n",&_isXvid);
 	fscanf(fd,"FFV1:%d\n",&_isFFV1);
 	fscanf(fd,"ff4c:%x\n",&_ffv1_fourcc);	
+	
+	fscanf(fd,"extr:%x\n",&_ffv1_extraLen);
+	if(_ffv1_extraLen)
+	{
+		char *start;
+		char *str=new char[_ffv1_extraLen*3+4];
+		
+		fgets(str,_ffv1_extraLen*3+3,fd);
+		
+		_ffv1_extraData=new uint8_t[_ffv1_extraLen];
+		
+		start=str;
+		for(uint32_t i=0;i<_ffv1_extraLen;i++)
+		{
+			_ffv1_extraData[i]=mk_hex(*start,*(start+1));
+			start+=3;
+		}
+		delete(str);
+		
+	}
+	
 	fscanf(fd,"PCM:%d\n",&_isPCM);
 	fscanf(fd,"Fq:%d\n",&_audio_frequency);
 	fscanf(fd,"%lu video frames\n",&nb);
@@ -1369,7 +1421,7 @@ FILE *fd;
 			fseeko(_fd,_lzo_pos,SEEK_SET);
 			fread(str,_lzo_size,1,_fd);
 			_rtjpeg->InitLong((char *)str, DXFIELD(width), DXFIELD(height) );
-			aprintf("Jpeg : %llu , %llu\n",_lzo_pos,_lzo_size);
+			printf("Jpeg : %llu , %llu\n",_lzo_pos,_lzo_size);
 		}
 
 
