@@ -32,18 +32,13 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include <stdio.h>
-#ifdef HAVE_SYS_PARAM_H
-#include <sys/param.h>
-#endif
-#ifdef __FreeBSD__
-          #include <sys/types.h>
-#endif
-#include <stdlib.h>
-#include <ADM_assert.h>
-#include <string.h>
 #include "config.h"
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include "math.h"
+#include <ADM_assert.h>
 
 #include "ADM_library/default.h"
 #include "ADM_library/fourcc.h"
@@ -68,7 +63,7 @@ oggHeader::oggHeader(void)
 	_lastImage=0xffff;
 	_lastFrag=0x0;	
 	_audio=NULL;
-	
+	_reordered=0;
 	memset(&_audioTracks[0],0,sizeof(OgAudioTrack));
 	memset(&_audioTracks[1],0,sizeof(OgAudioTrack));
 	
@@ -178,6 +173,16 @@ uint8_t  oggHeader::  getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* f
 
 uint8_t oggHeader::open(char *name)
 {
+#ifdef ADM_BIG_ENDIAN
+	#define SWAP64(x) { uint64_t y=x;x=R32((y>>16)>>16)+((R32(y&0x0ffffffff)<<16)<<16);}
+	#define SWAP32(x) x=R32(x)
+	#define SWAP16(x) x=R16(x)
+#else
+	#define SWAP64(x) ;
+	#define SWAP32(x) ;
+	#define SWAP16(x) ;
+#endif
+
 	OGMDemuxer 	*demux;
 	uint8_t  	buffer[64*1024];
 	stream_header	*header;
@@ -231,9 +236,9 @@ uint8_t oggHeader::open(char *name)
 				{
 					_audioTracks[0].audioTrack=id;
 					_audioTracks[0].encoding=WAV_OGG;
-					_audioTracks[0].channels=header->audio.channels;
-					_audioTracks[0].byterate=header->audio.avgbytespersec;
-					_audioTracks[0].frequency=header->samples_per_unit;
+					_audioTracks[0].channels=R16(header->audio.channels);
+					_audioTracks[0].byterate=R32(header->audio.avgbytespersec);
+					_audioTracks[0].frequency=R64(header->samples_per_unit);
 					printf("Taking that track as audio track 1\n");
 				}
 				else
@@ -241,9 +246,9 @@ uint8_t oggHeader::open(char *name)
 				{
 					_audioTracks[1].audioTrack=id;
 					_audioTracks[1].encoding=WAV_OGG;
-					_audioTracks[1].channels=header->audio.channels;
-					_audioTracks[1].byterate=header->audio.avgbytespersec;
-					_audioTracks[1].frequency=header->samples_per_unit;
+					_audioTracks[1].channels=R16(header->audio.channels);
+					_audioTracks[1].byterate=R32(header->audio.avgbytespersec);
+					_audioTracks[1].frequency=R64(header->samples_per_unit);
 					printf("Taking that track as audio track 2\n");
 				}
 				dumpHeader(header,1);
@@ -258,9 +263,9 @@ uint8_t oggHeader::open(char *name)
 				{
 					_audioTracks[0].audioTrack=id;
 					_audioTracks[0].encoding=codec;
-					_audioTracks[0].channels=header->audio.channels;
-					_audioTracks[0].byterate=header->audio.avgbytespersec;
-					_audioTracks[0].frequency=header->samples_per_unit;
+					_audioTracks[0].channels=R16(header->audio.channels);
+					_audioTracks[0].byterate=R32(header->audio.avgbytespersec);
+					_audioTracks[0].frequency=R64(header->samples_per_unit);
 					printf("Taking that track as audio track 1\n");
 				}
 				else
@@ -268,9 +273,9 @@ uint8_t oggHeader::open(char *name)
 				{
 					_audioTracks[1].audioTrack=id;
 					_audioTracks[1].encoding=codec;
-					_audioTracks[1].channels=header->audio.channels;
-					_audioTracks[1].byterate=header->audio.avgbytespersec;
-					_audioTracks[1].frequency=header->samples_per_unit;
+					_audioTracks[1].channels=R16(header->audio.channels);
+					_audioTracks[1].byterate=R32(header->audio.avgbytespersec);
+					_audioTracks[1].frequency=R64(header->samples_per_unit);
 					printf("Taking that track as audio track 2\n");
 				}
 				dumpHeader(header,1);
@@ -300,15 +305,6 @@ uint8_t oggHeader::open(char *name)
     		_videostream.dwScale=1000;
                 _videostream.dwRate=25000;
 
-#ifdef ADM_BIG_ENDIAN
-	#define SWAP64(x) { uint64_t y=x;x=R32((y>>16)>>16)+((R32(y&0x0ffffffff)<<16)<<16);}
-	#define SWAP32(x) x=R32(x)
-	#define SWAP16(x) x=R16(x)
-#else
-	#define SWAP64(x) ;
-	#define SWAP32(x) ;
-	#define SWAP16(x) ;
-#endif
 
 		SWAP32(header->video.width);
 		SWAP32(header->video.height);
@@ -328,8 +324,8 @@ double fps;
               memset( &_video_bih,0,sizeof(_video_bih));
                _video_bih.biBitCount=24;
 
-              _videostream.fccHandler=fourcc;
-              _video_bih.biCompression=0;
+              
+              _video_bih.biCompression=_videostream.fccHandler=fourcc;
 
               _videostream.dwLength= _mainaviheader.dwTotalFrames=1; // ??
                _videostream.dwInitialFrames= 0;
@@ -481,6 +477,7 @@ OgAudioIndex *tmpaudio[2];
 				else
 					_index[frame].size=cursize-1;
 				_index[frame].flags=frameFlag;
+				_index[frame].frame_index=frame;
 				aprintf("Detected frame : %lu,size %lu  page count : %lu\n",
 					frame,cursize,frame2);
 				frame++;
@@ -528,12 +525,13 @@ OgAudioIndex *tmpaudio[2];
 }
 /**
 		For OGM file we can either read sequentially
-		or rewind to a fresh page a forward from then
+		or rewind to a fresh page a forward from there
 
 */
 uint8_t  oggHeader::getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* framelen)
 {
 	uint64_t f;
+	uint32_t findex;
 	
 	if(!_index) return 0;
 	if(framenum>(uint32_t)(_videostream.dwLength-1)) return 0;
@@ -542,13 +540,14 @@ uint8_t  oggHeader::getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* fra
 	uint8_t bte,frag,*frags;
 	uint32_t red=0;
 
-
-	aprintf("****************** frame %lu requested **************\n",framenum);
+	findex=_index[framenum].frame_index;
+	aprintf("****************** frame %lu requested findex=%lu type%lu**************\n",
+			framenum,findex,_index[framenum].flags);
 	len=*framelen=_index[framenum].size;
 	// continue the previously read image ?
-	if((_lastImage+1)==framenum)
+	if((_lastImage+1)==findex)
 	{
-		seek=framenum;
+		seek=findex;
 		// read last frags
 		_demux->getLace(&frag,&frags);
 		if(_lastFrag>=frag)
@@ -565,6 +564,8 @@ uint8_t  oggHeader::getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* fra
 		{
 			aprintf("\t cont :%lu -> %02d ( %lu to go)\n",i,frags[i],len-frags[i]);
 			cursize=frags[i];
+			
+			
 			// first byte
 			// skip it			
 			if(!red && frags[i])
@@ -572,7 +573,15 @@ uint8_t  oggHeader::getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* fra
 				cursize--;
 				_demux->readBytes(1,ptr);
 			}
+			if(len<cursize)
+			{
+			printf("Len inconsistency : We still have %lu bytes to read and encountered a %lu lace\n",
+				len,cursize);
+				printf("The total frame len is %lu, frame number is %lu, findex=%lu,\n",
+					*framelen,framenum,findex);
+				ADM_assert(0);
 			
+			}
 			// get the frame ?
 			_demux->readBytes(cursize,ptr);
 			len-=cursize;
@@ -587,7 +596,7 @@ uint8_t  oggHeader::getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* fra
 				aprintf("--short seeking (%d)  \n",i);
 				if( len==0)
 				{
-					_lastImage=framenum;
+					_lastImage=findex;
 					aprintf("\n Got short frame\n");
 					return 1;
 				}
@@ -597,7 +606,7 @@ uint8_t  oggHeader::getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* fra
 					"%lu we got len to go %lu and reached a new frame, lastFrag=%lu/%u\n",
 										framenum,len,_lastFrag,frag);
 										
-					printf("For information the frame len is %lu\n",*framelen);
+					printf("For information the frame len is %lu, findex=%lu\n",*framelen,findex);
 					ADM_assert(0);
 				}
 
@@ -606,7 +615,7 @@ uint8_t  oggHeader::getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* fra
 	}
 	else
 	{
-		// look last seekable frame
+		// lookup last seekable frame
 		seek=framenum;
 		while(!_index[seek].pos) seek--;
 
@@ -614,6 +623,7 @@ uint8_t  oggHeader::getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* fra
 
 		// Jump to seek
 		ADM_assert(_demux->setPos(_index[seek].pos));
+		seek=_index[seek].frame_index;
 		// and now read forward
 	}
 	// Read a complete one
@@ -647,7 +657,7 @@ uint8_t  oggHeader::getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* fra
 			else
 				cursize=frags[i];
 			// get the frame ?
-			if(seek==framenum)
+			if(seek==findex)
 			{
 				_demux->readBytes(cursize,ptr);
 				len-=cursize;
@@ -660,7 +670,7 @@ uint8_t  oggHeader::getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* fra
 			aprintf(" Last frag : %lu\n",_lastFrag);
 			// got it all ?
 
-			if(seek>framenum)
+			if(seek>findex)
 			{
 				printf("\n When requesting frame %lu we got len to go %lu and reached a new frame, lastFrag=%lu/%u\n",
 										framenum,len,_lastFrag,frag);
@@ -673,16 +683,16 @@ uint8_t  oggHeader::getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* fra
 				// reset
 				red=0;
 				aprintf("--seeking (%ld) got : %lu \n",i,seek);
-				if(seek==framenum && len==0)
+				if(seek==findex && len==0)
 				{
-					_lastImage=framenum;
+					_lastImage=findex;
 					return 1;
 				}
-				else if(seek==framenum)
+				else if(seek==findex)
 				{
-					printf("\n Inconsistency : When requesting frame %lu we got len to go %lu and reached a new frame, lastFrag=%lu/%u\n",
+					printf("\n Inconsistency3 : When requesting frame %lu we got len to go %lu and reached a new frame, lastFrag=%lu/%u\n",
 										framenum,len,_lastFrag,frag);
-					printf("For information the frame len is %lu\n",*framelen);
+					printf("For information the frame len is %lu findex=%lu\n",*framelen,findex);
 					ADM_assert(0);
 				}
 				seek++;
