@@ -14,15 +14,16 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <ADM_assert.h>
+
 #include <string.h>
-#include "config.h"
+
 #include "math.h"
 
+#include <ADM_assert.h>
 #include "ADM_library/default.h"
 #include "ADM_editor/ADM_Video.h"
 
@@ -97,12 +98,18 @@ uint8_t  OpenDMLHeader::getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t*
 {
 uint64_t offset=_idx[framenum].offset; //+_mdatOffset;
 	 		
-
+// 	if(_recHack)
+// 	{
+// 		offset=4+4+4;
+// 	}
+// 	
+	
+	
  	fseeko(_fd,offset,SEEK_SET);
  	fread(ptr, _idx[framenum].size, 1, _fd);
   	*framelen=_idx[framenum].size;
 	aprintf("Size: %lu\n",_idx[framenum].size);
-	if(offset & 1) printf("odd!\n");
+//	if(offset & 1) printf("odd!\n");
  	return 1;
 }
 OpenDMLHeader::~OpenDMLHeader()
@@ -162,6 +169,7 @@ OpenDMLHeader::OpenDMLHeader(void)
 	_nbAudioChunk=0;
 	_audioTrack=NULL;
 	_reordered=0;
+	_recHack=0;
 
 	
 
