@@ -28,4 +28,7 @@
 #define MODULE_UNPACKER		0x4000000
 #define MODULE_ADEVICE		0x8000000
 #define MODULE_SCRIPT		0x10000000
+#define MODULE_OGM_WRITE	0x20000000
+#define MODULE_XVID_RCTL	0x40000000
+#define MODULE_LAVFORMAT	0x80000000
 
