@@ -17,17 +17,16 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
 #include "config.h"
+
 #include <stdlib.h>
 #include <glib.h>
 #include <signal.h>
-#include <ADM_assert.h>
 #ifndef CYG_MANGLING
 #include <unistd.h>
 #endif
 #include <math.h>
-#include "config.h"
+
 
 #include <gtk/gtk.h>
 
@@ -36,6 +35,8 @@
 #include "support.h"
 #include "avi_vars.h"
 //#include "ADM_gui/GUI_vars.h"
+#include <ADM_assert.h>
+
 #include "gui_action.hxx"
 #include "ADM_encoder/ADM_vidEncode.hxx"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
@@ -56,6 +57,7 @@ extern void filterLoadXml(char *n);
 extern void A_openAvi(char *name);
 extern void A_appendAvi (char *name);
 extern void A_saveAudio(char *name);
+extern int A_loadNone( void );
 extern void A_saveAudioDecodedTest(char *name);
 extern uint8_t indexMpeg(char *mpeg,char *file,uint8_t aid);
 extern void A_SaveAudioNVideo(char *name);
@@ -109,6 +111,13 @@ extern const char *getStrFromAudioCodec( uint32_t codec);
 extern void frame2time(uint32_t frame, uint32_t fps, uint16_t * hh, uint16_t * mm, uint16_t * ss, uint16_t * ms);
 extern uint8_t ADM_aviSetSplitSize(uint32_t size);
 extern uint8_t ogmSave(char *fd);
+static void set_autoindex(char *p);
+extern int A_SaveUnpackedVop( char *name);
+extern int A_saveDVDPS(char *name);
+//
+static int call_bframe(void);
+static int call_packedvop(void);
+static int call_saveDVD(char *a);
 //_________________________________________________________________________
 
 extern uint8_t audioShift;
@@ -154,35 +163,44 @@ AUTOMATON reaction_table[]=
 
 		{"begin",		1,"set start frame",			setBegin},
 		{"end",			1,"set end frame",			setEnd},
-		
+		{"save-dvd",		2,"save as dvd ps stream",		(one_arg_type)call_saveDVD},
+		{"save-unpacked-vop",	1,"save avi, unpacking vop",(one_arg_type)A_SaveUnpackedVop},		
 		{"save-ogm",		1,"save as ogm file ",			(one_arg_type)ogmSave},
 		{"save-raw-audio",	1,"save audio as-is ",			A_saveAudio},
 		{"save-raw-video",	1,"save raw video stream (mpeg/... ) ",	ADM_saveRaw},
 		{"save-uncompressed-audio",1,"save uncompressed audio",A_saveAudioDecodedTest},
 		{"index-mpeg",		3,"create index of vob/mpeg : vob.vob index.index audio#",
 								((one_arg_type )call_indexMpeg)},
-		{"load",		1	,"load video",		A_openAvi},
-		{"append",		1	,"append video",	A_appendAvi},
-		{"load-workbench",	1	,"load workbench file",	load_workbench},
-		{"save",		1	,"save avi",		save},		
-		{"external-mp3",	1	,"load external mpeg audio as audio track",(one_arg_type)GUI_loadMP3},
-		{"external-ac3",	1	,"load external ac3 audio as audio track",(one_arg_type)A_loadAC3},
-		{"external-wav",	1	,"load external wav audio as audio track",(one_arg_type)A_loadWave},
-		{"audio-delay",		1	,"set audio time shift in ms (+ or -)",	call_setAudio},
-		{"audio-map",		0	,"build audio map (MP3 VBR)",	call_buildtimemap},
-		{"audio-bitrate",	1	,"set audio encoding bitrate",	call_audiobitrate},
+		{"load",		1,"load video",		A_openAvi},
+		{"append",		1,"append video",	A_appendAvi},
+		{"load-workbench",	1,"load workbench file",	load_workbench},
+		{"save",		1,"save avi",		save},		
+		
+		{"force-b-frame",	0,"Force detection of bframe in next loaded file", (one_arg_type)call_bframe},
+		{"force-unpack",	0,"Force detection of packed vop in next loaded file"
+								,(one_arg_type)call_packedvop},
+		
+		
+		{"external-mp3",	1,"load external mpeg audio as audio track",(one_arg_type)GUI_loadMP3},
+		{"external-ac3",	1,"load external ac3 audio as audio track",(one_arg_type)A_loadAC3},
+		{"external-wav",	1,"load external wav audio as audio track",(one_arg_type)A_loadWave},
+		{"no-audio",		0,"load external wav audio as audio track",(one_arg_type)A_loadNone},
+		{"audio-delay",		1,"set audio time shift in ms (+ or -)",	call_setAudio},
+		{"audio-map",		0,"build audio map (MP3 VBR)",	call_buildtimemap},
+		{"audio-bitrate",	1,"set audio encoding bitrate",	call_audiobitrate},
 		{"fps",	1	,"set frames per second",	call_fps},
-		{"audio-codec",		1	,"set audio codec (MP2/MP3/AC3/NONE/TOOLAME)",call_audiocodec},
-		{"audio-toolame",	1	,"pipe audio to toolame and save to file",call_toolame},
-		{"video-codec",		1	,"set video codec (Divx/Xvid/FFmpeg4/VCD/SVCD/DVD/XVCD/XSVCD)",				call_videocodec},
+		{"audio-codec",		1,"set audio codec (MP2/MP3/AC3/NONE/TOOLAME)",call_audiocodec},
+		{"audio-toolame",	1,"pipe audio to toolame and save to file",call_toolame},
+		{"video-codec",		1,"set video codec (Divx/Xvid/FFmpeg4/VCD/SVCD/DVD/XVCD/XSVCD)",				call_videocodec},
 		{"video-conf",		1	,"set video codec conf (cq=q|cbr=br|2pass=size)[,mbr=br][,matrix=(0|1|2|3)]",				call_videoconf},
-		{"2pass-log",		1	,"select the log file for 2 passes mode",				encoderSetLogFile},
+//		{"2pass-log",		1	,"select the log file for 2 passes mode",				encoderSetLogFile},
 		{"set-pp",		2	,"set post processing default value, value(1=hdeblok|2=vdeblock|4=dering) and strength (0-5)",	(one_arg_type )	call_setPP},
 
 		{"autosplit",		1	,"split every N MBytes",call_autosplit},
 		{"requant",		3	,"requantize mpeg2 : percent quality[0..3] output_name",
 										(one_arg_type )call_requant},
 		{"info",		0	,"show information about loaded video and audio streams", show_info},
+		{"autoindex",		0	,"try to generate required index files", set_autoindex},
 		
 		{"help",		0,"print this",		call_help},
 		{"quit",		0,"exit avidemux",	call_quit}
@@ -303,6 +321,12 @@ void call_videoproc   (char *p) { UNUSED_ARG(p); HandleAction(ACT_VideoModeProce
 extern  int  audioNormalizeMode;
 extern void audioForceDownSample( void );
 extern void audioSetResample(uint32_t fq);
+int call_saveDVD(char *a)
+{
+	
+	A_saveDVDPS(a);
+}
+
 void call_normalize   (char *p)
 {
 	audioNormalizeMode=1; // Ugly
@@ -338,11 +362,7 @@ void call_buildtimemap(char *p) { UNUSED_ARG(p); aprintf("timemap\n");HandleActi
 
 void call_setPP(char *v,char *s)
 {
-int iv=3,is=5;
-	sscanf(v,"%d",&iv);
-	sscanf(s,"%d",&is);
-	aprintf("post proc %d %d\n",iv,is);
-	setPostProc(iv,is);
+// TODO
 	
 
 }
@@ -367,6 +387,11 @@ void call_audiocodec(char *p)
 		audioCodecSetcodec( AUDIOENC_NONE );
 	else if(!strcmp(p,"TOOLAME"))
 		audioCodecSetcodec( AUDIOENC_2LAME );		
+#ifdef USE_VORBIS		
+	else if(!strcmp(p,"VORBIS"))
+		audioCodecSetcodec( AUDIOENC_VORBIS );		
+#endif		
+		
 	else{
 		audioCodecSetcodec( AUDIOENC_NONE );
 		fprintf(stderr,"audio codec \"%s\" unknown.\n",p);
@@ -473,7 +498,7 @@ void call_requant(char *p, char *q, char *n)
 }
 void load_workbench(char*name){
    ADM_assert(name);
-   A_loadWorkbench(name);
+   A_openAvi(name);
  //  updateLoaded();
 }
 
@@ -487,6 +512,11 @@ void call_toolame(char *file)
 	A_Pipe(P_TOOLAME,file);
 }
 
+void set_autoindex(char *p){
+	UNUSED_ARG(p);
+	prefs->set(FEATURE_TRYAUTOIDX,(unsigned int)1);
+}
+
 void show_info(char *p){
    UNUSED_ARG(p);
    
@@ -532,5 +562,16 @@ void show_info(char *p){
    	printf("Nothing to get infos from\n");
    }
 }
+int call_bframe(void)
+{
+	video_body->setEnv(ENV_EDITOR_BFRAME);
+	return 1;
+}
+
+int call_packedvop(void)
+{
+	video_body->setEnv(ENV_EDITOR_PVOP);
+	return 1;
+}
 
 //EOF
