@@ -14,6 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+#include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -22,14 +23,12 @@
 #include <gtk/gtk.h>
 #include <time.h>
 #include <sys/time.h>
-#include <ADM_assert.h>
 #include <math.h>
 #include <iconv.h>
 
-#include "config.h"
+
 #include "fourcc.h"
 #include "avio.hxx"
-#include "config.h"
 
 #ifdef USE_FREETYPE
 
@@ -56,7 +55,8 @@
 #include "ADM_toolkit/ADM_debug.h"
 
 #include "prototype.h"
-
+#include "prefs.h"
+#include <ADM_assert.h>
 
 typedef struct unicd
 {
@@ -69,11 +69,12 @@ typedef struct unicd
 //
 static unicd  names[]=
 {
-	{(char *)"Ascii"	,(char *)"UNICODE"},
+	{(char *)"Ascii"	,(char *)"ISO-8859-1"},
 	{(char *)"Cyrillic"	,(char *)"WINDOWS-1251"}, // ru
 	{(char *)"Czech"	,(char *)"ISO-8859-2"},	// cz
 	{(char *)"German"	,(char *)"ISO-8859-9"}		// german ?
 	,{(char *)"Slovene"	,(char *)"CP1250"}		// UTF8
+	,{(char *)"UTF8"	,(char *)"UTF8"}		// UTF8
 	,{(char *)"Chinese Traditionnal(Big5)"	,(char *)"CP950"}		// UTF8
 	,{(char *)"Chinese Simplified (GB2312)"	,(char *)"CP936"}		// UTF8
 };
@@ -87,7 +88,6 @@ static void on_callback_color(GtkButton * button, gpointer user_data);
 static gboolean on_slider( void );
 
 static void indexSUB(char *name);
-static void fontCB(char *name);
 static void update(uint32_t value);
 static void read(void);
 
@@ -107,11 +107,11 @@ static int  GUI_subtitleParam(char *font,char *sub,int  *charset,int *size,uint3
 static gboolean gui_draw( void );
 static void draw( void);
 
+#define MAX_STRING 300
+static char subString[MAX_STRING];
+static char fontString[MAX_STRING];
 
-static char subString[300];
-static char fontString[300];
-
-static uint8_t  *sourceImage=NULL;
+static ADMImage  *sourceImage=NULL;
 static uint8_t *targetImage=NULL;
 static uint8_t *targetImageRGB=NULL;
 
@@ -137,15 +137,15 @@ uint32_t l,f;
 		_w=_info.width;
 		_h=_info.height;
 
-		sourceImage		=new uint8_t[_w*_h*2];
+		sourceImage		=new ADMImage(_w,_h);//uint8_t[_w*_h*2];
 		targetImage		=new uint8_t[_w*_h*2];
-		targetImageRGB	=new uint8_t[_w*_h*4];
+		targetImageRGB		=new uint8_t[_w*_h*4];
 
 		ADM_assert(instream->getFrameNumberNoAlloc(curframe,
 						&l,
 						sourceImage,
 						&f));
-
+				
 		 if(GUI_subtitleParam(	_conf->_fontname,
 		 					_conf->_subname,
 							&charset,
@@ -174,13 +174,24 @@ uint32_t l,f;
 
 				loadSubtitle();
 				loadFont();
+				
+				prefs->set(FILTERS_SUBTITLE_FONTNAME,_conf->_fontname);
+				prefs->set(FILTERS_SUBTITLE_CHARSET,_conf->_charset);
+				prefs->set(FILTERS_SUBTITLE_FONTSIZE,_conf->_fontsize);
+                                prefs->set(FILTERS_SUBTITLE_YPERCENT,_conf->_Y_percent);
+                                prefs->set(FILTERS_SUBTITLE_UPERCENT,_conf->_U_percent);
+                                prefs->set(FILTERS_SUBTITLE_VPERCENT,_conf->_V_percent);
+                                prefs->set(FILTERS_SUBTITLE_SELFADJUSTABLE,_conf->_selfAdjustable);
+                                prefs->set(FILTERS_SUBTITLE_USEBACKGROUNDCOLOR,_conf->_useBackgroundColor);
+				
 				ret=1;
 		}
-		delete [] sourceImage;
+		delete  sourceImage;
 		delete [] targetImage;
 		delete [] targetImageRGB;
 
-		sourceImage=targetImage=targetImageRGB=NULL;
+		sourceImage=NULL;
+		targetImage=targetImageRGB=NULL;
 		return 1;
 
 }
@@ -197,8 +208,12 @@ gint answer;
 #define WID(x) lookup_widget(dialog,#x)
 #define CHECK_GET(x,y) {y=gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(WID(x)));}
 #define CHECK_SET(x,y) {gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(WID(x)),y);}		
-       	dialog = create_dialog1();
 
+	printf("In:Y:%d U:%d V:%d\n",*coly,*colu,*colv);
+
+       	dialog = create_dialog1();
+	
+	
 	if(sub)    	strcpy( subString, sub);
 	if(font) 	 strcpy( fontString, font);
 
@@ -270,12 +285,14 @@ gint answer;
 
 
 	ret=0;
+	gtk_register_dialog(dialog);
 	while( (answer=gtk_dialog_run(GTK_DIALOG(dialog)))==GTK_RESPONSE_APPLY)
 	{
 		read();
 		update(glob_base);
 		draw();
 	}
+	gtk_unregister_dialog(dialog);
 	if(answer==GTK_RESPONSE_OK)
 	{
 				strcpy(sub,subString);
@@ -289,12 +306,13 @@ gint answer;
 				*coly=myY;
 				*colu=myU;
 				*colv=myV;
+				printf("Y:%d U:%d V:%d\n",*coly,*colu,*colv);
 				CHECK_GET(checkbutton_autosplit,*autocut);
 				CHECK_GET(checkbuttonbg,*bgcolor);
 				*delay= (int32_t)gtk_read_entry(WID(entry_delay));
 				ret=1;
 	}
-
+	
 	gtk_widget_destroy(dialog);
 	dialog=NULL;
 	return ret;
@@ -341,26 +359,23 @@ gboolean on_slider( void )
 }
 void on_callback_sub(GtkButton * button, gpointer user_data)
 {
-	     UNUSED_ARG(button);
-	     UNUSED_ARG(user_data);
-	     GUI_FileSelRead("Subtitle to load", indexSUB)  ;
-}
-void indexSUB(char *name)
-{
-	 strcpy(subString,name);
-	 gtk_label_set_text(GTK_LABEL(WID(label_sub)),name);
+	      UNUSED_ARG(button);
+	UNUSED_ARG(user_data);
+        //GUI_FileSelRead("TTF font to use", fontCB);
+	FileSel_SelectRead("Subtitle to load", subString,
+		MAX_STRING,subString);
+	gtk_label_set_text(GTK_LABEL(WID(label_sub)),subString);
 }
+
 void on_callback_font(GtkButton * button, gpointer user_data)
 {
         UNUSED_ARG(button);
 	UNUSED_ARG(user_data);
-        GUI_FileSelRead("TTF font to use", fontCB);
-
-}
-void fontCB(char *name)
-{
- 	strcpy(fontString,name);
-	gtk_label_set_text(GTK_LABEL(WID(label_font)),name);
+        //GUI_FileSelRead("TTF font to use", fontCB);
+	FileSel_SelectRead("TTF font to use", fontString,
+		MAX_STRING,fontString);
+	gtk_label_set_text(GTK_LABEL(WID(label_font)),fontString);
+	
 }
 /*--------------------------------------*/
 gboolean gui_draw( void )
@@ -393,9 +408,14 @@ void read ( void )
 void update(uint32_t value)
 {
 uint32_t h;
+uint32_t page=_w*_h;
 	//printf("\n Updating with %lu base line\n",value);
 	// grab it
-	memcpy(targetImage,sourceImage,(_w*_h*3)>>1);
+	
+	memcpy(targetImage,YPLANE(sourceImage),(_w*_h));
+	memcpy(targetImage+page,UPLANE(sourceImage),(_w*_h)>>2);
+	memcpy(targetImage+((page*5)>>2),VPLANE(sourceImage),(_w*_h)>>2);
+	
 	h=glob_font;
 	if(h>8) h-=4;
 
