@@ -80,9 +80,6 @@ char *Telecide::printConf( void )
 }
 
 
-#define UPLANE(x) (x+_info.width*_info.height)
-#define VPLANE(x) (x+((_info.width*_info.height*5)>>2))
-
 #define PROGRESSIVE  0x00000001
 #define MAGIC_NUMBER (0xdeadbeef)
 #define IN_PATTERN   0x00000002
@@ -172,7 +169,7 @@ Telecide::Telecide(AVDMGenericVideoStream *in,CONFcouple *couples)
 		_param->back_saved = _param->back;
 
 		// Set up pattern guidance.
-		cache = (struct CACHE_ENTRY *) malloc(CACHE_SIZE * sizeof(struct CACHE_ENTRY));
+		cache = (struct CACHE_ENTRY *) ADM_alloc(CACHE_SIZE * sizeof(struct CACHE_ENTRY));
 		for (i = 0; i < CACHE_SIZE; i++)
 		{
 			cache[i].frame = 0xffffffff;
@@ -201,14 +198,14 @@ Telecide::Telecide(AVDMGenericVideoStream *in,CONFcouple *couples)
 		xblocks = (_info.width+BLKSIZE-1) / BLKSIZE;
 		yblocks = (_info.height+BLKSIZE-1) / BLKSIZE;
 #ifdef WINDOWED_MATCH
-		matchp = (unsigned int *) malloc(xblocks * yblocks * sizeof(unsigned int));
+		matchp = (unsigned int *) ADM_alloc(xblocks * yblocks * sizeof(unsigned int));
 		
-		matchc = (unsigned int *) malloc(xblocks * yblocks * sizeof(unsigned int));
+		matchc = (unsigned int *) ADM_alloc(xblocks * yblocks * sizeof(unsigned int));
 		
 #endif
-		sump = (unsigned int *) malloc(xblocks * yblocks * sizeof(unsigned int));
+		sump = (unsigned int *) ADM_alloc(xblocks * yblocks * sizeof(unsigned int));
 		
-		sumc = (unsigned int *) malloc(xblocks * yblocks * sizeof(unsigned int));
+		sumc = (unsigned int *) ADM_alloc(xblocks * yblocks * sizeof(unsigned int));
 		
 
 		
@@ -218,13 +215,13 @@ Telecide::~Telecide()
 {
 		unsigned int *p;
 
-		if (cache != NULL) free(cache);
+		if (cache != NULL) ADM_dealloc(cache);
 #ifdef WINDOWED_MATCH
-		if (matchp != NULL) free(matchp);
-		if (matchc != NULL) free(matchc);
+		if (matchp != NULL) ADM_dealloc(matchp);
+		if (matchc != NULL) ADM_dealloc(matchc);
 #endif
-		if (sump != NULL) free(sump);
-		if (sumc != NULL) free(sumc);
+		if (sump != NULL) ADM_dealloc(sump);
+		if (sumc != NULL) ADM_dealloc(sumc);
 
 		delete vidCache;
 		vidCache=NULL;
@@ -292,12 +289,14 @@ void Telecide::Debug(int frame)
 }
 
 //______________________________________________________________
-uint8_t Telecide::getFrameNumberNoAlloc(uint32_t frame, uint32_t *len,
-				uint8_t *data,uint32_t *flags)
+uint8_t Telecide::getFrameNumberNoAlloc(uint32_t frame,
+				uint32_t *len,
+   				ADMImage *data,
+				uint32_t *flags)
 {
 uint32_t framep,framen;
-uint8_t * fp,* fc, *fn, *dst, *final;
-uint8_t * lc,* lp;
+ADMImage * fp,* fc, *fn, *dst, *final;
+ADMImage * lc,* lp;
 
 unsigned char *fprp, *fcrp, *fcrp_saved, *fnrp;
 	unsigned char *fprpU, *fcrpU, *fnrpU;//, *fcrp_savedU
@@ -314,7 +313,7 @@ unsigned char *fprp, *fcrp, *fcrp_saved, *fnrp;
 	
 	
 //	dst = env->NewVideoFrame(vi);
-	dst=data;
+	dst=data;//->data;
 	// Get the current frame.
 	
 	if (frame > _info.nb_frames - 1) frame = _info.nb_frames - 1;
@@ -327,7 +326,7 @@ unsigned char *fprp, *fcrp, *fcrp_saved, *fnrp;
 	//GETFRAME(pframe, fp);
 	fp=vidCache->getImage(framep);
 	ADM_assert(fp);
-	fprp = (unsigned char *) fp;
+	fprp = YPLANE( fp);
 	
 	{
 		fprpU = (unsigned char *)  UPLANE(fp);
@@ -336,7 +335,7 @@ unsigned char *fprp, *fcrp, *fcrp_saved, *fnrp;
 	
 	fc=vidCache->getImage(frame);
 	ADM_assert(fc);
-	fcrp = (unsigned char *) fc;
+	fcrp =YPLANE( fc);
 	
 	{
 		fcrpU = (unsigned char *) UPLANE(fc);
@@ -347,7 +346,7 @@ unsigned char *fprp, *fcrp, *fcrp_saved, *fnrp;
 	//GETFRAME(nframe, fn);
 	fn=vidCache->getImage(framen);
 	ADM_assert(fn);
-	fnrp = (unsigned char *) fn;
+	fnrp=YPLANE( fn);
 	
 	{
 		fnrpU = (unsigned char *)  UPLANE(fn);
@@ -371,7 +370,7 @@ unsigned char *fprp, *fcrp, *fcrp_saved, *fnrp;
 				//GETFRAME(y == 0 ? 1 : y - 1, lp);
 				lp=vidCache->getImage(y == 0 ? 1 : y - 1);
 				ADM_assert(lp);
-				prp = (unsigned char *) lp;
+				prp = YPLANE( lp);
 				{
 					prpU = (unsigned char *)  UPLANE(lp);
 					prpV = (unsigned char *) VPLANE(lp );
@@ -379,7 +378,7 @@ unsigned char *fprp, *fcrp, *fcrp_saved, *fnrp;
 				//GETFRAME(y, lc);
 				lc=vidCache->getImage(y);
 				ADM_assert(lc);
-				crp = (unsigned char *) lc;
+				crp = YPLANE( lc);
 				{
 					crpU = (unsigned char *) UPLANE(lc);
 					crpV = (unsigned char *) VPLANE(lc);
@@ -559,7 +558,7 @@ unsigned char *fprp, *fcrp, *fcrp_saved, *fnrp;
 	else strcpy(status, "[out-of-pattern]");
 
 	// Assemble and output the reconstructed frame according to the final match.
-	dstp = dst;
+	dstp = YPLANE(dst);
     
 	{
 		dstpU =  UPLANE(dst);
@@ -655,27 +654,27 @@ unsigned char *fprp, *fcrp, *fcrp_saved, *fnrp;
 		if (_param->blend == true)
 		{
 			// Blend mode.
-			final = data; //env->NewVideoFrame(vi);
+			final = (data); //env->NewVideoFrame(vi);
 			// Do first and last lines.
-			finalp = final;
-			dstp = dst;
-			dstpn = dstp + dpitch;
+			finalp = YPLANE(final);
+			dstp = YPLANE(dst);
+			dstpn =  (dstp) + dpitch;
 			for (x = 0; x < w; x++)
 			{
 				finalp[x] = (((int)dstp[x] + (int)dstpn[x]) >> 1);
 			}
-			finalp = final + (h-1)*dpitch;
-			dstp = dst + (h-1)*dpitch;
-			dstpp = dstp - dpitch;
+			finalp = YPLANE(final) + (h-1)*dpitch;
+			dstp = YPLANE(dst) + (h-1)*dpitch;
+			dstpp =  (dstp) - dpitch;
 			for (x = 0; x < w; x++)
 			{
 				finalp[x] = (((int)dstp[x] + (int)dstpp[x]) >> 1);
 			}
 			// Now do the rest.
-			dstp = dst + dpitch;
-			dstpp = dstp - dpitch;
-			dstpn = dstp + dpitch;
-			finalp = final + dpitch;
+			dstp = YPLANE(dst) + dpitch;
+			dstpp =  (dstp) - dpitch;
+			dstpn =  (dstp) + dpitch;
+			finalp = YPLANE(final) + dpitch;
 			for (y = 1; y < h - 1; y++)
 			{
 				for (x = 0; x < w; x++)
@@ -779,9 +778,9 @@ unsigned char *fprp, *fcrp, *fcrp_saved, *fnrp;
 					}
 				}
 			}
-			if (_param->show == true) Show(final, frame);
+			if (_param->show == true) Show(final->data, frame);
 			if (_param->debug == true) Debug(frame);
-			if (_param->hints == true) WriteHints(final, film, inpattern);
+			if (_param->hints == true) WriteHints(final->data, film, inpattern);
 			
 			vidCache->unlockAll();
 			return 1;
@@ -789,7 +788,7 @@ unsigned char *fprp, *fcrp, *fcrp_saved, *fnrp;
 
 		// Interpolate mode.
 		// Luma plane.
-		dstp = dst + dpitch;
+		dstp = YPLANE(dst) + dpitch;
 		dstpp = dstp - dpitch;
 		dstpn = dstp + dpitch;
 		for (y = 1; y < h - 1; y+=2)
@@ -853,15 +852,15 @@ unsigned char *fprp, *fcrp, *fcrp_saved, *fnrp;
 		}
 	}
 
-	if (_param->show == true) Show(dst, frame);
+	if (_param->show == true) Show(dst->data, frame);
 	if (_param->debug == true) Debug(frame);
-	if (_param->hints == true) WriteHints(dst, film, inpattern);
+	if (_param->hints == true) WriteHints(dst->data, film, inpattern);
 	vidCache->unlockAll();
 	return 1;
 }
 
 void Telecide::CalculateMetrics(int frame, unsigned char *fcrp, unsigned char *fcrpU, unsigned char *fcrpV,
-									unsigned char *fprp, unsigned char *fprpU, unsigned char *fprpV)
+			unsigned char *fprp, unsigned char *fprpU, unsigned char *fprpV)
 {
 	int x, y, p, c, tmp1, tmp2, skip;
 	bool vc;
