@@ -17,6 +17,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+ 
+ 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -33,31 +35,9 @@
 #include "ADM_toolkit/toolkit.hxx"
 #include "ADM_editor/ADM_edit.hxx"
 #include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_video/ADM_vidFlux.h"
-#include "ADM_filter/video_filters.h"
 
-
-static FILTER_PARAM fluxParam={2,{"temporal_threshold","spatial_threshold"}};
-
-
-SCRIPT_CREATE(fluxsmooth_script,ADMVideoFlux,fluxParam);
-
-//#define ASM_FLUX
-BUILD_CREATE(fluxsmooth_create,ADMVideoFlux);
-
-static uint64_t  spat_thresh,temp_thresh;
-static uint64_t  _l_counter_init,_l_indexer,_l_prev_pels,_l_next_pels;
-static int _l_src_pitch;
-static int _l_dst_pitch;
-static int _l_xmax;
-
-static int ycnt;
 static int16_t scaletab[16];
 static uint64_t scaletab_MMX[65536];
-static	uint8_t * _l_currp; 
-static	 uint8_t * _l_prevp;								  								  
-static	 uint8_t * _l_nextp; 
-static	 uint8_t * _l_destp; 
 
 void initScaleTab( void )
 {
@@ -74,13 +54,39 @@ void initScaleTab( void )
 							  (((uint64_t)scaletab[(i >> 12) & 15]) << 48);
 		}
 }
+ 
+#include "ADM_video/ADM_vidFlux.h"
+#include "ADM_filter/video_filters.h"
+
+static FILTER_PARAM fluxParam={2,{"temporal_threshold","spatial_threshold"}};
+
+
+SCRIPT_CREATE(fluxsmooth_script,ADMVideoFlux,fluxParam);
+
+//#define ASM_FLUX
+BUILD_CREATE(fluxsmooth_create,ADMVideoFlux);
+
+static uint64_t  spat_thresh,temp_thresh;
+static uint64_t  _l_counter_init,_l_indexer,_l_prev_pels,_l_next_pels;
+static int _l_src_pitch;
+static int _l_dst_pitch;
+static int _l_xmax;
+
+static int ycnt;
+static	uint8_t * _l_currp; 
+static	 uint8_t * _l_prevp;								  								  
+static	 uint8_t * _l_nextp; 
+static	 uint8_t * _l_destp; 
+
+
 static uint32_t size;
 
 ADMVideoFlux::ADMVideoFlux(AVDMGenericVideoStream *in,CONFcouple *couples)
-			: ADMVideoCached(in,couples)
+			
 {
   
-	
+	_in=in;
+	memcpy(&_info,in->getInfo(),sizeof(_info));
 	if(couples)
 	{
 		_param=NEW( FLUX_PARAM );
@@ -93,7 +99,8 @@ ADMVideoFlux::ADMVideoFlux(AVDMGenericVideoStream *in,CONFcouple *couples)
 		 _param->spatial_threshold=7;
 		 _param->temporal_threshold=7;
 	}
-  num_frame=0xffff0000;
+  	num_frame=0xffff0000;
+	vidCache=new VideoCache(5,in);
 }
 
 uint8_t	ADMVideoFlux::getCoupledConf( CONFcouple **couples)
@@ -128,6 +135,9 @@ int i;
 ADMVideoFlux::~ADMVideoFlux()
 {
 	DELETE(_param);
+	if(vidCache)
+		delete vidCache;
+	vidCache=NULL;
 }
 
 char	*ADMVideoFlux::printConf( void) 
@@ -141,51 +151,55 @@ char	*ADMVideoFlux::printConf( void)
 	
 }
 uint8_t ADMVideoFlux::getFrameNumberNoAlloc(uint32_t frame, uint32_t *len,
-          																	uint8_t *data,uint32_t *flags)
+          			ADMImage *data,uint32_t *flags)
 {
 UNUSED_ARG(flags);
 uint32_t dlen,dflags;
 uint32_t plane=_info.width*_info.height;
-
+ADMImage	*image,*next,*prev;
 
 
 			*len=(plane*3)>>1;
 			
 			size=(_info.width*_info.height*3)>>1;
 			if(frame>_info.nb_frames-1) return 0;
-			// check if it the 1st frame
-			if(frame> _info.nb_frames-1) return 0;
+			
+			image=vidCache->getImage(frame);
+			if(!image) return 0;
+			
 			if(!frame || (frame==_info.nb_frames-1))
 			{
-				 if(!_in->getFrameNumberNoAlloc(frame, &dlen,_buffer[0],&dflags))
-				 {
-					 	return 0;
-					}
-				 _bufnum[0]=frame;
-					memcpy(data,_buffer[0],size);
-					return 1;
-			}	    
-			
-			switch(fillCache( frame))
+
+				data->duplicate(image);
+				data->copyInfo(image);
+				vidCache->unlockAll();
+				return 1;
+			}
+			next=vidCache->getImage(frame+1);
+			if(!next)
 			{
-				 case 0: return 0; break;
-				 case 1: memcpy(data,_buffer[index_c],size); return 1; break;
-				 case 2: break;
-				 default:ADM_assert(0);
-			}				 
+				vidCache->unlockAll();
+				return 0;
+			}
+			prev=vidCache->getImage(frame-1);
+			if(!prev)
+			{
+				vidCache->unlockAll();
+				return 0;
+			}	    
 				
-//	printf("\n Action\n");		
+
 		   			
 // now we have everything
-int dst_pitch = _info.width,
+		int dst_pitch = _info.width,
 		src_pitch = _info.width,
 		row_size  = _info.width,
 		height    = _info.height;
 		
- uint8_t   *currp = _buffer[index_c],
-								*prevp = _buffer[index_p],
-								*nextp = _buffer[index_n];
-	uint8_t				*destp = data;
+ uint8_t   		*currp = YPLANE(image),
+			*prevp = YPLANE(prev),
+			*nextp = YPLANE(next);;
+	uint8_t		*destp = YPLANE(data);
 
 	// line 1 and last
 	memcpy(destp, currp, row_size);
@@ -207,10 +221,11 @@ int dst_pitch = _info.width,
 	src_pitch = _info.width>>1;
   row_size  = _info.width>>1;
 	height = _info.height>>1;
-	currp = _buffer[index_c]+plane;
-	prevp = _buffer[index_p]+plane;
-	nextp = _buffer[index_n]+plane;
-	destp = data+plane;
+	
+	currp = UPLANE(image);
+	prevp = UPLANE(prev);
+	nextp = UPLANE(next);
+	destp = UPLANE(data);;
 
 	memcpy(destp, currp, row_size);
 	memcpy(destp + dst_pitch * (height - 1),
@@ -232,10 +247,11 @@ int dst_pitch = _info.width,
 	src_pitch = _info.width>>1;
   row_size  = _info.width>>1;
 	height = _info.height>>1;
-	currp = _buffer[index_c]+plane;
-	prevp = _buffer[index_p]+plane;
-	nextp = _buffer[index_n]+plane;
-	destp = data+plane;
+	
+	currp = VPLANE(image);
+	prevp = VPLANE(prev);
+	nextp = VPLANE(next);
+	destp = VPLANE(data);;
 
 	memcpy(destp, currp, row_size);
 	memcpy(destp + dst_pitch * (height - 1),
@@ -254,7 +270,8 @@ int dst_pitch = _info.width,
 		DoFilter_C(currp, prevp, nextp, src_pitch,
 			destp, dst_pitch, row_size, height - 2);
 	#endif
-
+	data->copyInfo(image);
+	vidCache->unlockAll();
 	return 1;
 }	                           
 
@@ -398,7 +415,7 @@ void ADMVideoFlux::DoFilter_C(
 
 void ADMVideoFlux::DoFilter_MMX(
 uint8_t * currp, 
- uint8_t * prevp,								  								  
+ uint8_t * prevp,
  uint8_t * nextp, 
  int src_pitch,
  uint8_t * destp, 
