@@ -22,7 +22,7 @@
  class ADMfont
  {
  private:
- 		  iconv_t 		_conv; // =(iconv_t)-1;;
+ 		  
 		   FT_Face    _face;
 		   int			_faceAllocated;
 		   uint8_t		_use2bytes;
@@ -33,7 +33,7 @@
 		~ADMfont();
 
 	int initFreeType( char *fontname );
-	int fontDraw(char *target, int c, int stride, int size,int *ww);
+	int fontDraw(char *target, int c,int prevchar, int stride, int size,int *ww);
 	int fontSetSize ( int size);
 	int fontSetCharSet (char *code);
 
