@@ -30,10 +30,11 @@
 #include <math.h>
 #include <unistd.h>
 
-#include "ADM_assert.h"
+
 
 #include <time.h>
 #include <sys/time.h>
+#include <fcntl.h>	/* O_RDONLY */
 
 #include "config.h"
 
@@ -45,13 +46,14 @@
 
 #include "fourcc.h"
 #include "avi_vars.h"
+#include "ADM_assert.h"
 #include "ADM_toolkit/filesel.h"
 #include "ADM_toolkit/toolkit_gtk.h"
 #include "prototype.h"
 #include "ADM_toolkit/toolkit.hxx"
 #include "ADM_toolkit/bitmap.h"
-#include "subchunk.h"
-#include "avilist.h"
+//#include "subchunk.h"
+//#include "avilist.h"
 
 
 
@@ -88,8 +90,8 @@
 
 #include "mpeg2enc/ADM_mpeg2enc.h"
 
-
-
+#include "ADM_filter/video_filters.h"
+#include "ADM_assert.h"
 void A_handleSecondTrack (int tracktype);
 int A_delete(uint32_t start, uint32_t end);
 void A_saveImg (char *name);
@@ -98,6 +100,7 @@ void A_requantize(void);
 int A_saveJpg (char *name);
 int A_loadWave (char *name);
 int A_loadAC3 (char *name);
+int A_loadNone( void );
 void A_saveAudioDecodedTest (char *name);
 void A_openBrokenAvi (char *name);
 int A_openAvi2 (char *name, uint8_t mode);
@@ -123,10 +126,10 @@ uint8_t GUI_getDoubleValue (double *valye, float min, float max,
 extern void GUI_setMarks (uint32_t a, uint32_t b);
 extern void saveMpegFile (char *name);
 //static void A_selectEncoder ( void );
-extern void A_SaveAudioDualAudio (void);
-static void secondTrackMP3 (char *name);
+extern void A_SaveAudioDualAudio (char *a);
+
 extern uint8_t ADM_aviUISetMuxer(  void );
-static void secondTrackAC3 (char *name);
+
 
 static void updateSecondAudioTrack (void);
 
@@ -139,8 +142,8 @@ void ADM_cutWizard (void);
 void computeIT (int size, int nb, int brate, uint32_t * frame,
 		uint32_t * rsize);
 int ADM_saveRaw (char *name);
+static char * actual_workbench_file;
 static void A_saveWorkbench (char *name);
-void A_loadWorkbench (char *name);
 void updateLoaded (void);
 extern void encoderSetLogFile (char *name);
 extern void videoCodecSelect (void);
@@ -149,26 +152,17 @@ extern uint8_t DIA_RecentFiles( char **name );
 extern void mpeg_passthrough(  char *name );
 static void A_videoCheck( void);
 extern void parseScript(char *scriptname);
-#define USE_FFMPEG_AS_DEFAULT
-#ifdef USE_FFMPEG
-//uint8_t       use_fast_ffmpeg=1;
-#ifdef USE_FFMPEG_AS_DEFAULT
-uint8_t use_fast_ffmpeg = 1;
-#else
-uint8_t use_fast_ffmpeg = 0;
-
-#endif
-
-#else
-uint8_t use_fast_ffmpeg = 0;
-#endif
 int A_saveDVDPS(char *name);
+static void	A_setPostproc( void );
 extern uint8_t ogmSave(char  *name);
 //__________
 extern uint8_t ogmSave(char *fd);
-
-
-
+extern uint8_t GUI_getFrame(uint32_t frameno, ADMImage *image, uint32_t *flags);
+extern int A_SaveUnpackedVop( char *name);
+extern void      videoCodecConfigureUI(void);
+extern void audioCodecChanged(int newcodec);
+extern void videoCodecChanged(int newcodec);
+extern void DIA_Calculator(uint32_t *sizeInMeg, uint32_t *avgBitrate );
 extern int ignore_change;
 
 PARAM_MUX muxMode = MUX_REGULAR;
@@ -198,6 +192,21 @@ HandleAction (Action action)
 
   switch (action)
     {
+      case ACT_AudioConfigure:
+    		audioCodecSelect();
+		return;
+	case ACT_VideoConfigure:
+    		videoCodecSelect();
+		return;
+    case ACT_VideoCodecChanged:
+    		
+    		videoCodecChanged(UI_getCurrentVCodec());
+		return;
+   case ACT_AudioCodecChanged:
+   		audioCodecChanged(UI_getCurrentACodec());
+    		
+		return;
+    
     case ACT_RunScript:
     			 GUI_FileSelRead ("Select script to load ", parseScript);
     		return;
@@ -213,10 +222,12 @@ HandleAction (Action action)
     		 DIA_about( );
 		 return;
     case ACT_VideoCodec:
-      videoCodecSelect ();
+      //videoCodecSelect ();
+      videoCodecConfigureUI();
       return;
     case ACT_AudioCodec:
-      audioCodecSelect ();
+      //audioCodecSelect ();
+      audioCodecConfigure();
       return;
 
     case ACT_AudioFilters:
@@ -240,15 +251,10 @@ HandleAction (Action action)
       prefs->save ();
       return;
     case ACT_SetLogFile:
-      GUI_FileSelWrite ("Select log File to use", encoderSetLogFile);
+//      GUI_FileSelWrite ("Select log File to use", encoderSetLogFile);
+	GUI_Alert("Obsolete!");
       return;
       break;
-    case ACT_LoadWork:
-      GUI_FileSelRead ("Select workbench to load ", A_loadWorkbench);
-
-      return;
-      break;
-
     case ACT_SetMuxParam:
       ADM_aviUISetMuxer();
       return;
@@ -276,9 +282,7 @@ HandleAction (Action action)
 				   return;break;
 #endif                                  
     case ACT_Fast:
-      use_fast_ffmpeg = 1 - use_fast_ffmpeg;
-      printf (" Fast FFmpeg is now :%d\n", use_fast_ffmpeg);
-      return;
+      ADM_assert(0);
       break;
     case ACT_Exit:
       { uint8_t saveprefsonexit;
@@ -422,6 +426,19 @@ HandleAction (Action action)
   // we have an AVI loaded
   switch (action)
     {
+    case ACT_Bitrate:
+    			{
+				uint32_t a,b;
+				DIA_Calculator(&a,&b );
+			}
+    			break;
+    case ACT_SaveUnpackedMpeg4:
+    			if(GUI_Question("This is to be used to undo packed vop on mpeg4.\nContinue ?"))
+			{ 
+				GUI_FileSelWrite ("Select Avi file to write", (SELFILE_CB *)A_SaveUnpackedVop);
+				
+			}
+    			break;
 #ifdef TEST_UNPACK
     case ACT_Requant:
     			video_body->unpackPacked();
@@ -458,7 +475,15 @@ case ACT_Pipe2Other:
     case ACT_SaveWork:
       GUI_FileSelWrite ("Select workbench to save ", A_saveWorkbench);
       break;
-
+    case ACT_SaveCurrentWork:
+      if( actual_workbench_file ){
+        char *tmp = ADM_strdup(actual_workbench_file);
+         A_saveWorkbench( tmp ); // will write "actual_workbench_file" itself
+         ADM_dealloc(tmp);
+      }else{
+         GUI_FileSelWrite ("Select workbench to save ", A_saveWorkbench);
+      }
+      break;
 	case ACT_JumpToFrame: 
 		// read value	
 			printf("Jump!\n");	 
@@ -527,7 +552,7 @@ case ACT_Pipe2Other:
 
     case ACT_SaveDualAudio:
       //GUI_FileSelWrite ("Select AVI to save ",
-      A_SaveAudioDualAudio();
+      A_SaveAudioDualAudio(NULL);
       break;
 
     case ACT_SaveBunchJPG:
@@ -578,7 +603,7 @@ case ACT_Pipe2Other:
 	GUI_PlayAvi ();
       break;
     case ACT_SetPostProcessing:
-      GUI_Alert ("Obsolete");
+      A_setPostproc();
       break;
 
     case ACT_NextFrame:
@@ -744,6 +769,11 @@ case ACT_Pipe2Other:
       		UI_setMarkers (frameStart, frameEnd);
       		ReSync ();
 
+		// forget last project file
+		if( actual_workbench_file ){
+			ADM_dealloc(actual_workbench_file);
+			actual_workbench_file = NULL;
+		}
 	}
 	break;
 
@@ -827,20 +857,8 @@ case ACT_Pipe2Other:
   // gtk_widget_grab_focus(sb_frame);
 }
 
-#ifdef USE_MJPEG
 
 
-void
-A_saveMpeg (char *name)
-{
-
-  oplug_mpeg_vcd (name);
-
-}
-
-
-#endif
-
 //_____________________________________________________________
 //
 // Open AVI File
@@ -892,7 +910,7 @@ int A_openAvi2 (char *name, uint8_t mode)
 
       if (rdr_decomp_buffer)
 	{
-	  free (rdr_decomp_buffer);
+	  delete  rdr_decomp_buffer;
 	  rdr_decomp_buffer = NULL;
 	}
 
@@ -903,6 +921,13 @@ int A_openAvi2 (char *name, uint8_t mode)
   else
     res = video_body->addFile (name);
   DIA_StopBusy ();
+
+  // forget last project file
+  if( actual_workbench_file ){
+     ADM_dealloc(actual_workbench_file);
+     actual_workbench_file = NULL;
+  }
+
   if (res!=ADM_OK)			// an error occured
     {
     	if(ADM_IGN==res) 
@@ -916,19 +941,40 @@ int A_openAvi2 (char *name, uint8_t mode)
       GUI_Alert ("Problem opening that file!");
       return 0;
     }
-	{ char *longname = PathCanonize(name);
-	  int i;
-		// remember this file
-		prefs->set_lastfile(longname);
-		updateLoaded ();
-		for(i=strlen(longname);i>=0;i--)
-			if( longname[i] == '/' ){
-				i++;
-				break;
+
+    { int fd,i;
+      char magic[4];
+      char *longname = PathCanonize(name);
+
+	/* check myself it is a project file (transparent detected and read
+        ** by video_body->addFile (name);
+	*/
+	if( (fd = open(longname,O_RDONLY)) != -1 ){
+		if( read(fd,magic,4) == 4 ){
+			/* remember a workbench file */
+			if( !strncmp(magic,"ADMW",4) ){
+				actual_workbench_file = ADM_strdup(longname);
 			}
-		UI_setTitle(longname+i);
-		free(longname);
+		}
+		close(fd);
 	}
+
+	/* remember any video or workbench file to "recent" */
+	prefs->set_lastfile(longname);
+
+	updateLoaded ();
+	for(i=strlen(longname);i>=0;i--)
+#ifdef CYG_MANGLING
+		if( longname[i] == '\\' ){
+#else
+		if( longname[i] == '/' ){
+#endif
+			i++;
+			break;
+		}
+	UI_setTitle(longname+i);
+	ADM_dealloc(longname);
+    }
 	return 1;
 }
 
@@ -954,10 +1000,9 @@ void  updateLoaded ()
     }
 
   curframe = 0;
-
+  getFirstVideoFilter(); // reinit first filter
   video_body->flushCache();
-  ADM_assert (rdr_decomp_buffer =
-	  (uint8_t *) malloc (3 * avifileinfo->width * avifileinfo->height));
+  ADM_assert (rdr_decomp_buffer =new ADMImage(avifileinfo->width,avifileinfo->height));
 
   //frameStart = 0;
   //frameEnd = avifileinfo->nb_frames - 1;
@@ -1009,18 +1054,22 @@ void  updateLoaded ()
   // Init renderer
   renderResize (avifileinfo->width, avifileinfo->height);
   curframe = 0;
-  rebuild_status_bar ();
+  
 
   // Draw first frame
-  if (!video_body->getUncompressedFrame (curframe, rdr_decomp_buffer))
-    {
+  rebuild_status_bar (); 
+  getFirstVideoFilter(); // Rebuild filter if needed
+  if(!GUI_getFrame( curframe, rdr_decomp_buffer,NULL))
+  {
       GUI_Alert ("Problem decompressing frame!");
     }
   else
     {
-      renderUpdateImage (rdr_decomp_buffer);
+      renderUpdateImage (rdr_decomp_buffer->data);
       renderRefresh ();
+      update_status_bar(rdr_decomp_buffer);
     }
+   
    printf("\n** conf updated **\n");
 }
 
@@ -1101,46 +1150,74 @@ A_saveAudio (char *name)
   DIA_working *work;
   FILE *out;
 
-#define BITT 500
-  uint8_t buffer[BITT];
+#define ONE_STRIKE (64*1024)
+  uint8_t *buffer=NULL;
 
   if (!currentaudiostream)
     return;
   if (!currentaudiostream->isCompressed ())
     {
       GUI_Alert
-	("The audio is wav PCM. \nPlease select Audio Process mode \notherwise the audio stream will be\n unreadable (raw PCM))");
+	("The audio is wav PCM. \nPlease select Audio Process mode \n"
+	"otherwise the audio stream will be\n unreadable (raw PCM))");
       return;
     }
 
-  work=new DIA_working("Saving audio");
+  
   out = fopen (name, "wb");
-  ADM_assert (out);
+  if (!out) return;
+  
+  work=new DIA_working("Saving audio");
+  
+  uint32_t timeEnd,timeStart,sample,hold,len;
+  uint64_t tgt_sample,cur_sample;
+  double   duration;
 
-// compute start position
-  currentaudiostream->goToTime (video_body->getTime (frameStart));
-// compute max bytes to write (with little margin)
-  max =
-    currentaudiostream->convTime2Offset (video_body->
-					 getTime (frameEnd + 1)) -
-    currentaudiostream->convTime2Offset (video_body->getTime (frameStart));
-  written = 0;
-  while (1)
+  // compute start position and duration in samples
+    
+   timeStart=video_body->getTime (frameStart);
+   timeEnd=video_body->getTime (frameEnd+1);
+
+   currentaudiostream->goToTime (timeStart);
+   duration=timeEnd-timeStart;
+   printf("Duration:%f ms\n",duration);
+   if(duration<0) duration=-duration;
+  
+   duration/=1000;   
+   duration*=currentaudiostream->getInfo()->frequency;
+   
+   tgt_sample=(uint64_t)floor(duration);  
+   
+   cur_sample=0;
+   written = 0;
+   hold=0;
+   buffer=new uint8_t[ONE_STRIKE*2];
+   while (1)
     {
-      len2 = currentaudiostream->read (BITT, (uint8_t *) buffer);
-      fwrite (buffer, len2, 1, out);
-      if (len2 != BITT)
-	break;
-      written += len2;
-      if (written > max)
-	break;			// we wrote everything !
-
-      work->update(written, max);
+    	if(!currentaudiostream->getPacket(buffer+hold,&len,&sample)) break;
+	hold+=len;
+	written+=len;
+	cur_sample+=sample;
+	if(hold>ONE_STRIKE)
+	{
+		fwrite(buffer,hold,1,out);
+		hold=0;		
+	}
+	if(cur_sample>tgt_sample)
+		break;   
+      work->update(cur_sample>>10, tgt_sample>>10);
       if(!work->isAlive()) break;
     };
+  if(hold)
+  {
+  	fwrite(buffer,hold,1,out);
+	hold=0;  
+  }
+  
   fclose (out);
   delete work;
-  printf ("\n wanted %u bytes, written %u\n", max, written);
+  delete buffer;
+  printf ("\n wanted %llu samples, goto %llu samples, written %u bytes\n", tgt_sample,cur_sample, written);
 
 
 }
@@ -1222,7 +1299,7 @@ void A_saveBunchJpg(char *name)
   uint32_t sz,fl;
   FILE *fd;
   uint8_t *buffer=NULL;
-  uint8_t *src=NULL;
+  ADMImage *src=NULL;
   uint32_t curImg;
   char	 fullName[2048],*ext;
 
@@ -1239,7 +1316,8 @@ void A_saveBunchJpg(char *name)
 	sz = avifileinfo->width* avifileinfo->height * 3;
 	buffer=new uint8_t [sz];
 	ADM_assert(buffer);
-	src=new uint8_t [sz];
+	//src=new uint8_t [sz];
+	src=new ADMImage(avifileinfo->width,avifileinfo->height);
 	ADM_assert(src);
 
 
@@ -1248,7 +1326,7 @@ void A_saveBunchJpg(char *name)
 		
 	for(curImg=frameStart;curImg<=frameEnd;curImg++)
 	{		
-		if (!video_body->getUncompressedFrame (curImg, src))
+		if (!GUI_getFrame (curImg, src,NULL))
 		{
 			GUI_Alert("Cannot uncompress video!");
 			goto _bunch_abort;
@@ -1327,14 +1405,14 @@ sz = avifileinfo->width* avifileinfo->height * 3;
 
   uint8_t *out;
 
-  	out=(uint8_t *)malloc(sz);
+  	out=(uint8_t *)ADM_alloc(sz);
 	if(!out)
 	{
 		GUI_Alert("Memory error!");
 		return;
 	}
 
-	 if(!COL_yv12rgbBMP(bmph.biWidth, bmph.biHeight,rdr_decomp_buffer, out))
+	 if(!COL_yv12rgbBMP(bmph.biWidth, bmph.biHeight,rdr_decomp_buffer->data, out))
 	 {
 		GUI_Alert("Error converting to BMP !");
 		return;
@@ -1343,7 +1421,7 @@ sz = avifileinfo->width* avifileinfo->height * 3;
   	if (!fd)
     	{
       	GUI_Alert ("Something bad happened.");
-	free(out);
+	ADM_dealloc(out);
       	return;
     	}
 
@@ -1375,7 +1453,7 @@ sz = avifileinfo->width* avifileinfo->height * 3;
       	fwrite (out, sz, 1, fd);
 
     	fclose(fd);
-    	free(out);
+    	ADM_dealloc(out);
 
   GUI_Alert ("Done.");
 
@@ -1408,7 +1486,10 @@ A_loadAC3 (char *name)
   wavinfo = currentaudiostream->getInfo ();
   return 1;
 }
-
+int A_loadNone( void )
+{
+ 	changeAudioStream ((AVDMGenericAudioStream *) NULL, AudioNone);
+}
 //_____________________________________________________________
 //
 //              Load wave
@@ -1462,10 +1543,13 @@ A_saveAudioDecodedTest (char *name)
 {
 
 // debug audio seek
-  uint32_t len2, gauge = 0;
-  uint32_t written = 0, max;
+  uint32_t len, gauge = 0;
+  uint32_t written = 0;
   FILE *out;
   AVDMGenericAudioStream *saveFilter;
+  
+  uint64_t sampleTarget,sampleCurrent;
+  
 #undef BITT
 #define BITT 4*1152
 #define OUTCHUNK 1024*1024
@@ -1487,16 +1571,13 @@ A_saveAudioDecodedTest (char *name)
       return;
     }
 
-  outbuffer = (uint8_t *) malloc (2 * OUTCHUNK);	// 1Meg cache;
+  outbuffer = (uint8_t *) ADM_alloc (2 * OUTCHUNK);	// 1Meg cache;
   if (!outbuffer)
     {
       GUI_Alert ("Memory Error!");
       return;
     }
-// compute max bytes to read (with little margin)
-  max = getAudioByteCount( frameStart, frameEnd);
 
-  printf ("\n input : %u bytes\n", max);
 
 
 // re-ignite first filter...
@@ -1514,68 +1595,64 @@ A_saveAudioDecodedTest (char *name)
   /*          from begin and end of the audio stream. That was not good :) Now it runs correctly also if you use */
   /*          audio stream with same length then video, therefore is premature ending :) */
 
-  uint32_t delay = 0;
-  if (audioDelay > 0)
-    {
-      saveFilter =
-	buildAudioFilter (currentaudiostream,
-			  video_body->getTime (frameStart), max);
-    }
-  else
-    {
-      delay = currentaudiostream->convTime2Offset (-audioDelay);
-      saveFilter =
-	buildAudioFilter (currentaudiostream,
-			  video_body->getTime (frameStart), max + delay);
-    }
-
-    DIA_working *work=new DIA_working("Saving audio");
+ 
+	saveFilter =	buildAudioFilter (currentaudiostream,
+			  video_body->getTime (frameStart), 0xffffffff);
+   
+    	DIA_working *work=new DIA_working("Saving audio");
 
 
 //
 //  Create First filter that is null filter
 //
   saveFilter->writeHeader (out);
-  printf (".. Starting ..\n");
-  if (audioDelay > 0)
+  uint32_t tstart,tend,samples;
+  double duration;
+  tstart=video_body->getTime(frameStart);
+  tend=video_body->getTime(frameEnd+1);
+  duration=(tend-tstart);
+  duration*=saveFilter->getInfo()->frequency;
+  duration/=1000.;
+  
+  sampleTarget=(uint64_t)floor(duration);
+  sampleCurrent=0;
+  gauge=0;
+  
+  while ((sampleCurrent<sampleTarget))
     {
-      max = saveFilter->getLength ();
-    }
-  else
-    {
-      max = saveFilter->getLength () - delay;
-    }
-  printf ("\n Computed length : %u\n", max);
-  while (1)
-    {
-      len2 = saveFilter->readDecompress (BITT, outbuffer + gauge);
+      if(!saveFilter->getPacket(outbuffer + gauge,&len,&samples))
+      {
+        printf("Audio save:Read error\n");
+      	break;
+      }
       //      printf("Got : %lu\n",len2);
-      gauge += len2;
+      gauge += len;
+      sampleCurrent+=samples;
       // update GUI                   
-	if (work->update (written, max))	// abort request ?
-	    goto abortSaveAudio;
-      if ((len2 == 0) || (gauge > OUTCHUNK))	// either out buffer is full
-	// or we read nothing -> end of file
+	if (work->update (sampleCurrent>>10, sampleTarget>>10))	// abort request ?
+	    break;;
+      if (gauge > OUTCHUNK)	// either out buffer is full	
 	{
-	  fwrite (outbuffer, 1, gauge, out);
-	  //      fflush(out);    
+	  fwrite (outbuffer, 1, gauge, out);	  
 	  written += gauge;
 	  gauge = 0;
-	  if (len2 == 0)
-	    break;		// premature ending
-	 
-	  //printf("\n written %lu/%lu max\n",written,max);
-	}
-      //      if(written>max) break; // we wrote everything !
+	}   	
     };
-abortSaveAudio:
+// Clean up
+	if(gauge)
+	{
+		fwrite (outbuffer,  gauge,1, out);	  
+		written += gauge;
+		gauge = 0;	
+	}
   saveFilter->endWrite (out, written);
   fclose (out);
-  free (outbuffer);
+  ADM_dealloc (outbuffer);
   delete work;
   deleteAudioFilter ();
   currentaudiostream->endDecompress ();
-  printf (" actually written %u\n", written);
+  printf ("AudioSave: actually written %u\n", written);
+  printf ("Audiosave: target sample:%llu, got :%llu\n",sampleTarget,sampleCurrent);
 
 
 }
@@ -1628,136 +1705,67 @@ void
 A_handleSecondTrack (int tracktype)
 {
   /* lock which one is selected in GUI */
-
-
-
-  switch (tracktype)
-    {
-
-    case 0:
-      if (secondaudiostream)
+char *trackName=NULL;
+	 if (secondaudiostream)
 	{
 	  delete secondaudiostream;
 	  secondaudiostream = NULL;
 	  printf ("\n second audio stream destroyed\n");
 	}
-      updateSecondAudioTrack ();
-
-      break;
-    case 1:			// MP3
-      if (secondaudiostream && secondaudiostream_isac3 == 0)
-	return;
-      if (secondaudiostream)
+	GUI_FileSelRead("Second Track", &trackName);
+	if(!trackName)
+		{
+			printf("Cancelled\n");
+			return ;
+		}
+	switch(tracktype)
 	{
-	  delete secondaudiostream;
-	  secondaudiostream = NULL;
-	  printf ("\n second audio stream destroyed\n");
+		case 0:
+			return;
+			break;
+		case 1: //MP3
+		{
+			 AVDMMP3AudioStream *tmp;
+
+  			tmp = new AVDMMP3AudioStream ();
+  			if (!tmp->open (trackName))
+    			{
+      				delete tmp;
+      				printf ("\n Cancelled MP3 load\n");
+    			}
+  			else
+    			{
+      				secondaudiostream = tmp;      
+      				printf ("\n MP3 loaded\n");
+				GUI_Alert("Second track loaded.");
+    			}
+		}
+			break;
+		case 2: //AC3
+			{
+			AVDMAC3AudioStream *tmp;
+
+  			tmp = new AVDMAC3AudioStream ();
+  			if (!tmp->open (trackName))
+    			{
+      				delete tmp;
+      				printf ("\n Cancelled AC3 load\n");
+    			}
+  			else
+    			{
+      				secondaudiostream = tmp;
+      				printf ("\n AC3 loaded\n");
+				GUI_Alert("Second track loaded.");
+    			}
+			}
+			break;
+		default: ADM_assert(0);
 	}
-
-      secondaudiostream_isac3 = 0;
-      GUI_FileSelRead ("Select MP3", secondTrackMP3);
-      break;
-
-    case 2:			// AC3
-      if (secondaudiostream && secondaudiostream_isac3 == 1)
-	return;
-
-      if (secondaudiostream)
-	{
-	  delete secondaudiostream;
-	  secondaudiostream = NULL;
-	  printf ("\n second audio stream destroyed\n");
-	}
-
-      secondaudiostream_isac3 = 1;
-      GUI_FileSelRead ("Select AC3", secondTrackAC3);
-      break;
-
-
-
-    }
-
 }
 
 
-void
-secondTrackAC3 (char *name)
-{
-  AVDMAC3AudioStream *tmp;
-
-  tmp = new AVDMAC3AudioStream ();
-  if (!tmp->open (name))
-    {
-      delete tmp;
-      printf ("\n Cancelled AC3 load\n");
-    }
-  else
-    {
-      secondaudiostream = tmp;
-      secondaudiostream_isac3 = 1;
-      printf ("\n AC3 loaded\n");
-    }
-  updateSecondAudioTrack ();
-}
-
-
-void
-secondTrackMP3 (char *name)
-{
-  AVDMMP3AudioStream *tmp;
-
-  tmp = new AVDMMP3AudioStream ();
-  if (!tmp->open (name))
-    {
-      delete tmp;
-      printf ("\n Cancelled MP3 load\n");
-    }
-  else
-    {
-      secondaudiostream = tmp;
-      secondaudiostream_isac3 = 0;
-      printf ("\n MP3 loaded\n");
-    }
-  updateSecondAudioTrack ();
-
-}
-
-void
-updateSecondAudioTrack (void)
-{
-  return;
-#if 0
-//#define GOGLE(x,y) gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (x), y)
-#define GOGLE(x,y) {gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (x), y);}
-
-
-  if (!secondaudiostream)
-    {
-      GOGLE (second_track_none, TRUE);
-      GOGLE (second_track_ac3, FALSE);
-      GOGLE (second_track_mp3, FALSE);
-
-    }
-  else
-    {
-      GOGLE (second_track_none, FALSE);
-
-      if (secondaudiostream_isac3)
-	{
-	  GOGLE (second_track_ac3, TRUE);
-	  GOGLE (second_track_mp3, FALSE);
-
-	}
-      else
-	{
-	  GOGLE (second_track_ac3, FALSE);
-	  GOGLE (second_track_mp3, TRUE);
-	}
-    }
-#endif
-
 #warning fixme
-}
+
 
 extern void getCutPoints (int br);
 void
@@ -1942,24 +1950,11 @@ void
 A_saveWorkbench (char *name)
 {
   video_body->saveWorbench (name);
+  if( actual_workbench_file )
+     ADM_dealloc(actual_workbench_file);
+  actual_workbench_file = ADM_strdup(name);
 }
 
-void A_loadWorkbench (char *name)
-{
-  /// check if name exists
-  FILE *fd;
-  fd = fopen (name, "rb");
-  if (!fd)
-    return;
-  fclose (fd);
-
- if( video_body->loadWorbench (name))
-   {
-    updateLoaded ();
-      // remember this file
-     prefs->set_lastfile(name);
-    }
-}
 //---------------------
 extern int DIA_audioEncoder(int *pmode, int *pbitrate,const char *title);
 /**---------------------------------------------------
@@ -2018,7 +2013,7 @@ void A_Pipe(pipID who,char *outfile)
 		}
 		else
 		{
-			file=strdup(outfile);
+			file=ADM_strdup(outfile);
 		}
 
 	if(!file) return;
@@ -2047,9 +2042,9 @@ void A_Pipe(pipID who,char *outfile)
 				break;
 	}
     deleteAudioFilter();
-    if(param) free(param);
-    if(cmd) free(cmd);
-    if(file) free(file);
+    if(param) ADM_dealloc(param);
+    if(cmd) ADM_dealloc(cmd);
+    if(file) ADM_dealloc(file);
     GUI_Alert("Done!");
 
 }
@@ -2085,18 +2080,19 @@ uint32_t max=0;
 void A_videoCheck( void)
 {
 uint32_t nb=0;
-uint32_t buf[720*576*2];
+//uint32_t buf[720*576*2];
 uint32_t error=0;
+ADMImage *aImage;
 DIA_working *work;
 
 	nb = avifileinfo->nb_frames;
 	work=new DIA_working("Checking video");
-
+	aImage=new ADMImage(avifileinfo->width,avifileinfo->height);
   for(uint32_t i=0;i<nb;i++)
   {
 	work->update(i, nb);
       	if(!work->isAlive()) break;
-	if(!video_body->getUncompressedFrame (i, (uint8_t *)buf))
+	if(!GUI_getFrame (i, aImage,NULL))
 	{
 		error ++;
 		printf("Frame %u has error\n",i);
@@ -2104,6 +2100,7 @@ DIA_working *work;
 
     };
   delete work;
+  delete aImage;
   if(error==0)
   	GUI_Alert("No error found !");
 else
@@ -2213,5 +2210,23 @@ uint32_t count;
 
 
 }
+extern int DIA_getMPParams( int *pplevel, int *ppstrength,int *swap);
+
+
+//
+void	A_setPostproc( void )
+{
+int type,strength,swap;
+	if(!avifileinfo) return;
+	
+	video_body->getPostProc(&type,&strength,&swap);
+
+ 	if(DIA_getMPParams( &type, &strength,&swap))
+ 	{
+		video_body->setPostProc(type,strength,swap);
+ 	}
+
+}
+
 // EOF
 
