@@ -19,6 +19,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
@@ -28,15 +30,16 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <errno.h>
-#include <ADM_assert.h>
 
 
-#include "config.h"
+
 
 #include "ADM_lavcodec.h"
 #include "fourcc.h"
 #include "avi_vars.h"
 #include "ADM_toolkit/toolkit.hxx"
+#include <ADM_assert.h>
+
 #include "subchunk.h"
 
 #include "ADM_encoder/ADM_vidEncode.hxx"
@@ -68,12 +71,10 @@
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 #include "prefs.h"
 
-extern "C" {
-#include "ADM_encoder/xvid_vbr.h"
-};
+
 #include "ADM_dialog/DIA_enter.h"
 
-static vbr_control_t mpegvbr;
+
 
 #include "ADM_toolkit/ADM_debugID.h"
 #define MODULE_NAME MODULE_MPEG2ENC
@@ -85,11 +86,12 @@ static vbr_control_t mpegvbr;
 #include "ADM_encoder/adm_encffmpeg.h"
 
 
-#warning FIXME: Duplicate define with mpeg2enc -> bad
-#define MPEG_PREFILL 29
 
-extern FFMPEGConfig mpeg2encSVCDConfig;
-extern FFMPEGConfig mpeg2encDVDConfig;
+#warning FIXME: Duplicate define with mpeg2enc -> bad
+#define MPEG_PREFILL 5
+
+extern MPEG2ENCConfig mpeg2encSVCDConfig;
+extern MPEG2ENCConfig mpeg2encDVDConfig;
 extern uint8_t audioShift;
 extern int32_t audioDelay;
 // IF set do 1st pass with CBR with max bitrate = average bitrate AND disabling padding
@@ -109,13 +111,14 @@ mpegWritter::mpegWritter( void )
 	_fps1000=0;
 	_page=0;
 	_codec=NULL;
-	_buffer=NULL;
+	aImage=NULL;
 	_buffer_out=NULL;
 	_audio=NULL;
 	_audioBuffer=NULL;
 	_muxer=NULL;
 	_outputAsPs=0;
 	audioWanted=audioGot=0;
+	_ratecontrol=NULL;
 
 }
 mpegWritter::mpegWritter( uint8_t ps )
@@ -124,12 +127,14 @@ mpegWritter::mpegWritter( uint8_t ps )
 	_fps1000=0;
 	_page=0;
 	_codec=NULL;
-	_buffer=NULL;
+	aImage=NULL;
 	_buffer_out=NULL;
 	_audio=NULL;
 	_audioBuffer=NULL;
 	_muxer=NULL;
-	_outputAsPs=1;
+	_outputAsPs=ps;
+	audioWanted=audioGot=0;
+	_ratecontrol=NULL;
 
 }
 //_______________________________________
@@ -143,7 +148,20 @@ mpegWritter::~mpegWritter(  )
 /*---------------------------------------------------------------------------------------*/
 uint8_t  mpegWritter::save_svcd(char *name)
 {
-
+	if(_outputAsPs)
+	{
+		switch(_outputAsPs)
+		{
+			case 2:
+				if(!initLveMux(name,MUXER_SVCD))
+					return 0;
+				break;
+			
+			default:
+				ADM_assert(0);
+				break;
+		}
+	}
 	switch(mpeg2encSVCDConfig.generic.mode)
 	{
 		case COMPRESS_CBR:
@@ -182,21 +200,24 @@ uint8_t  mpegWritter::save_svcd(char *name)
 }
 
 
-#define PACK_AUDIO 	{ uint32_t audiolen=0, audioread=0;	\
-				 { \
-				audioWanted+=_audioOneFrame; \
-				if(_muxer->audioEmpty()) \
-	 				audiolen=(uint32_t)floor(8+audioWanted-audioGot);\
-				else \
- 					audiolen=(uint32_t)floor(audioWanted-audioGot);\
-				audioread = _audio->read (audiolen,_audioBuffer); \
-				if(audioread!=audiolen) printf("Mmm not enough audio..\n"); \
-					_muxer->writeAudioPacket(audioread,_audioBuffer);\
-				encoding->feedAudioFrame(audioread); \
-				audioGot+=audioread;\
-				}\
-			}
-				
+
+#define PACK_AUDIO \
+{ \
+	uint32_t samples; \
+	while(_muxer->needAudio()) \
+	{				\
+		if(!_audio->getPacket(_audioBuffer, &audiolen, &samples))	\
+		{ \
+			break; \
+		}\
+		if(audiolen) \
+		{\
+			_muxer->writeAudioPacket(audiolen,_audioBuffer); \
+			encoding->feedAudioFrame(audiolen); \
+		}\
+		audioGot+=audiolen; \
+	} \
+}
 /*---------------------------------------------------------------------------------------*/
 uint8_t  mpegWritter::save_dvd(char *name)
 {
@@ -206,10 +227,17 @@ WAVHeader		*info=NULL,tmpinfo;
 	// look if we have a suitable audio
 	if(_outputAsPs)
 	{
-		if(!initLveMux(name))
+		switch(_outputAsPs)
 		{
-			return 0;
-		}				
+			case 1:
+				if(!initLveMux(name,MUXER_DVD))
+					return 0;
+				break;
+			
+			default:
+				ADM_assert(0);
+				break;
+		}
 	}
 
 	switch(mpeg2encDVDConfig.generic.mode)
@@ -257,7 +285,22 @@ WAVHeader		*info=NULL,tmpinfo;
 
 uint8_t  mpegWritter::save_vcd(char *name)
 {
-//	return save_regular(name,ADM_VCD,1,1,0,0,0);
+
+// look if we have a suitable audio
+	if(_outputAsPs)
+	{
+		switch(_outputAsPs)
+		{
+			case 2:
+				if(!initLveMux(name,MUXER_VCD))
+					return 0;
+				break;
+			
+			default:
+				ADM_assert(0);
+				break;
+		}
+	}
 	return save_regular(name,ADM_VCD,1,1,0,0,0,0); // WLA
 
 }
@@ -317,10 +360,11 @@ DIA_encoding		*encoding;
 	printf("\n mpeg2enc init done \n");
 
 
-	_buffer	=new uint8_t[_w*_h*2];
+	//_buffer	=new uint8_t[_w*_h*2];
+	aImage=new ADMImage(_w,_h);
 	_buffer_out=new uint8_t[_w*_h*2];
 
-	ADM_assert(  _buffer);
+	ADM_assert(  aImage);
 	ADM_assert(  _buffer_out);
 
 	encoding=new DIA_encoding(_fps1000);
@@ -378,7 +422,7 @@ DIA_encoding		*encoding;
 	for(uint32_t i=0;i<_total;i++)
 			{
             			if(!incoming->getFrameNumberNoAlloc(i, &size,
-					(uint8_t *) _buffer,&flags))
+					aImage,&flags))
 				{
 						delete encoding;
                					GUI_Alert("Encoding error !");
@@ -387,7 +431,7 @@ DIA_encoding		*encoding;
 						end();
 						return 0 ;
 				}
-				_codec->encode(	_buffer,_buffer_out , &len,&flags,&outquant);
+				_codec->encode(	aImage,_buffer_out , &len,&flags,&outquant);
 				total_size+=len;
 				encoding->feedFrame(len);
 				encoding->setQuant(outquant);
@@ -397,7 +441,8 @@ DIA_encoding		*encoding;
 				if(!len) continue;
 				if(_muxer)
 				{		
-						_muxer->writeVideoPacket(len,_buffer_out);
+						_muxer->writeVideoPacket(len,_buffer_out,
+							i-MPEG_PREFILL,_codec->getCodedPictureNumber());
 						PACK_AUDIO;
 						
 				}else
@@ -420,14 +465,15 @@ DIA_encoding		*encoding;
 			encoding->setPhasis("Finishing");
 			for(uint32_t i=0;i<MPEG_PREFILL;i++)
 			{
-				_codec->encode(_buffer,_buffer_out , &len,&flags);
+				_codec->encode(aImage,_buffer_out , &len,&flags);
 				total_size+=len;
 				encoding->feedFrame(len);
 				if(!_muxer)
 					fwrite(_buffer_out,len,1,fd);
 				else
 				{
-					_muxer->writeVideoPacket(len,_buffer_out);
+					_muxer->writeVideoPacket(len,_buffer_out,
+							_total-MPEG_PREFILL+i,_codec->getCodedPictureNumber());
 					PACK_AUDIO;
 				}
 
@@ -471,7 +517,8 @@ char *statname;
 	_fps1000=incoming->getInfo()->fps1000;
 		_total=incoming->getInfo()->nb_frames;
 	if(!_total) return 0;
-	_buffer	=new uint8_t[_w*_h*2];
+	//_buffer	=new uint8_t[_w*_h*2];
+	aImage=new ADMImage(_w,_h);
 	_buffer_out=new uint8_t[_w*_h*2];
 
 
@@ -485,7 +532,7 @@ char *statname;
 
 	// check if stat file exists ?
 	uint8_t reuse=0;
-#ifndef CYG_MANGLING	
+#if 1 //ndef CYG_MANGLING	
 	FILE *fd;	
 	fd=fopen(statname,"rt");
 	if(fd)
@@ -494,6 +541,9 @@ char *statname;
 		if(GUI_Question("Reuse log file ?")) reuse=1;
 	}
 #endif	
+	//_ratecontrol=new ADM_oldXvidRc(_fps1000,statname);
+	_ratecontrol=new ADM_newXvidRc(_fps1000,statname);
+	
 #if 1
 if(!reuse)
 //	if(!dopass1(name,statname,final_size,bitrate,mpegtype,matrix,interlaced,widescreen))
@@ -545,32 +595,16 @@ int intra,q;
 	if(!init(name,mpegtype,interlaced,bff,widescreen)) return 0; // WLA
 	printf("\n mpeg2enc init done \n");
 
-	ADM_assert(  _buffer);
+	ADM_assert(  aImage);
 	ADM_assert(  _buffer_out);
 
 	q=2; // q=2
 	encoding->setPhasis("1st Pass");
 	bitrate=0; // we dont care in pass 1 ...
 
- 	memset(&mpegvbr,0,sizeof(mpegvbr));
-       	if(0>  vbrSetDefaults(&mpegvbr)) 				return 0;
-	mpegvbr.fps=_fps1000/1000.;
+ 	
 
- 	mpegvbr.mode=VBR_MODE_2PASS_1;
-	mpegvbr.desired_size=final_size*1024*1024;
-	mpegvbr.debug=0;
-	mpegvbr.filename=statname; //XvidInternal2pass_statfile;
-
-					
-	br=mpegvbr.desired_size*8;
-	br=br/_total;				// bit / frame
-	br=br*mpegvbr.fps;
-	br/=1000;
-	avg=(uint32_t)floor(br);
-
-	printf("Average bitrate : %lu\n",avg);
-
-	if(0>   vbrInit(&mpegvbr))             				return 0;
+	ADM_assert(_ratecontrol->startPass1());
 
 	switch(mpegtype)
 	{
@@ -621,7 +655,7 @@ int intra,q;
 	for(uint32_t i=0;i<_total;i++)
 	{
 		_codec->setQuantize(q);
-        	if(!	incoming->getFrameNumberNoAlloc(i, &size,(uint8_t *) _buffer,&flags))
+        	if(!incoming->getFrameNumberNoAlloc(i, &size,aImage,&flags))
 		{
         		GUI_Alert("Encoding error !");
 			end();
@@ -630,35 +664,25 @@ int intra,q;
 		if(i<MPEG_PREFILL)
 				{
 
-					_codec->encode(_buffer,_buffer_out , &len,&flags,&outquant);
+					_codec->encode(aImage,_buffer_out , &len,&flags,&outquant);
 					continue;
 				}
-		_codec->encode(		_buffer,_buffer_out , &len,&flags,&outquant);
+		_codec->encode(		aImage,_buffer_out , &len,&flags,&outquant);
 		total_size+=len;
 
-		if(flags & AVI_KEY_FRAME) intra=1;
-			else					intra=0;
+		
 		aprintf("inquant  : %02d outquant :%02d Intra %d, len %lu\n",q,outquant,intra,len);
 
+		ADM_rframe ftype;
 		switch(flags)
 		{
-			case AVI_KEY_FRAME: 	type=1;
-						break;
-			case AVI_B_FRAME: 	type=3;
-						break;
-			default:
-						type=2;
-						break;
+			case AVI_KEY_FRAME: 	ftype=RF_I;break;
+			case AVI_B_FRAME: 	ftype=RF_B;break;
+			default:		ftype=RF_P;break;
 		}
 
-		vbrUpdate(&mpegvbr,
-				outquant,
-				intra,
-				0,
-				len,
-				0,
-				0,
-				type);
+		ADM_assert(_ratecontrol->logPass1(outquant,ftype,len));
+		
 		encoding->setFrame(i,_total);
 		encoding->setQuant(outquant);
 		encoding->feedFrame(len);
@@ -671,31 +695,21 @@ int intra,q;
 	// flush queue
 	for(uint32_t i=0;i<MPEG_PREFILL;i++)
 	{
-		_codec->encode(		_buffer,_buffer_out , &len,&flags,&outquant);
+		_codec->encode(		aImage,_buffer_out , &len,&flags,&outquant);
 		total_size+=len;
 
-		if(flags & AVI_KEY_FRAME) intra=1;
-			else					intra=0;
+		
 		aprintf("inquant  : %02d outquant :%02d Intra %d\n",q,outquant,intra);
 
+		ADM_rframe ftype;
 		switch(flags)
 		{
-			case AVI_KEY_FRAME: 	type=1;
-									break;
-			case AVI_B_FRAME: 	type=3;
-									break;
-			default:
-								type=2;
-								break;
+			case AVI_KEY_FRAME: 	ftype=RF_I;break;
+			case AVI_B_FRAME: 	ftype=RF_B;break;
+			default:		ftype=RF_P;break;
 		}
-		vbrUpdate(&mpegvbr,
-				outquant,
-				intra,
-				0,
-				len,
-				0,
-				0,
-				type);
+		ADM_assert(_ratecontrol->logPass1(outquant,ftype,len));
+
 		encoding->setFrame(i,MPEG_PREFILL);
 		encoding->setQuant(outquant);
 		encoding->feedFrame(len);
@@ -704,7 +718,7 @@ int intra,q;
 	// flush queue
 	delete _codec;
 	_codec=NULL;
-	vbrFinish(&mpegvbr);
+	
 	return 1;
 }
 /*--------------------------------------------------------------------*/
@@ -721,6 +735,9 @@ FILE			*fd=NULL;
 uint64_t		total_size=0;
 uint32_t		len,flags,type,outquant,audiolen;
 
+uint32_t		quantstat[] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+
+	#define PRINT_QUANT_STAT {unsigned int i=2,sum=0,total=0;for(;i<32;i++){printf("Quant % 2u: % 7u times\n",i,quantstat[i]);sum+=i*quantstat[i];total+=quantstat[i];}printf("\nQuant over all: %2.2f\n",(float)sum/(float)total);}
 
    	incoming = getLastVideoFilter (frameStart,frameEnd-frameStart);
 	if(!_audio)
@@ -742,48 +759,15 @@ uint32_t		len,flags,type,outquant,audiolen;
 	}
 			printf("\n mpeg2enc init done \n");
 
-	ADM_assert(  _buffer);
+	ADM_assert(  aImage);
 	ADM_assert(  _buffer_out);
 	encoding->reset();
 	encoding->setFrame (0, _total);
 
 /*-------------------- Pass 1 over, go to pass 2 --------------------------------*/
-	total_size=0;
-	 memset(&mpegvbr,0,sizeof(mpegvbr));
-	if(0>  vbrSetDefaults(&mpegvbr))
-	{
-		printf("set default failed\n");
-		return 0;
-	}
-	mpegvbr.fps=_fps1000/1000.;
-
-	mpegvbr.mode=VBR_MODE_2PASS_2;
-	mpegvbr.desired_size=final_size*1024*1024;
-	mpegvbr.debug=0;
-	mpegvbr.filename=statname; //XvidInternal2pass_statfile;
-
-	float br;
-	uint32_t avg;
-
-	br=mpegvbr.desired_size*8;
-	br=br/_total;				// bit / frame
-	br=br*mpegvbr.fps;
-
-	mpegvbr.desired_bitrate= (int)floor(br);
-	avg=(uint32_t)floor(br/1000.);
-	printf("average bitrate : %lu\n",avg);
-	//mpegvbr.maxAllowedBitrate=(2500*1000)>>3; 
-	// enable stuff in xvid
-	//mpegvbr.twopass_max_bitrate=2500*1000;
-	//mpegvbr.alt_curve_high_dist=10;
-	//mpegvbr.alt_curve_low_dist=30;
-	//mpegvbr.alt_curve_type=VBR_ALT_CURVE_AGGRESIVE;
-
-	if(0>vbrInit(&mpegvbr))
-	{
-		GUI_Alert("Error initializing 2 pass!");
-		return 0;
-	}
+	
+	ADM_assert(_ratecontrol->startPass2(final_size,_total));
+	
 	encoding->setPhasis("2nd Pass");
 	q=2;
 
@@ -829,7 +813,7 @@ uint32_t		len,flags,type,outquant,audiolen;
 	}
 	for(uint32_t i=0;i<_total;i++)
 	{
-        	if(!incoming->getFrameNumberNoAlloc(i, &size,(uint8_t *) _buffer,&flags))
+        	if(!incoming->getFrameNumberNoAlloc(i, &size,aImage,&flags))
 		{
                		GUI_Alert("Encoding error !");
 			if(!_audio)
@@ -842,41 +826,35 @@ uint32_t		len,flags,type,outquant,audiolen;
 		if(i<MPEG_PREFILL)
 		{
 
-			_codec->encode(_buffer,_buffer_out , &len,&flags,&outquant);	
+			_codec->encode(aImage,_buffer_out , &len,&flags,&outquant);	
+			quantstat[outquant]++;
 			continue;
 		}
 		encoding->feedFrame(len); // Set
-		/* prepare quantization for next gop */
-		//if(vbr_next_intra( &mpegvbr))
-		{
-			q=vbrGetQuant(&mpegvbr);
-			_codec->setQuantize(q);
-		}
-		_codec->encode(_buffer,_buffer_out , &len,&flags,&outquant);
+		//
+		ADM_rframe ftype,ztype;
+		uint32_t qz;
+		ADM_assert(_ratecontrol->getQz(&qz,&ztype));
+		q=qz;
+		_codec->setQuantize(q);
+		_codec->encode(aImage,_buffer_out , &len,&flags,&outquant);
+		quantstat[outquant]++;
 		encoding->setQuant(outquant);
-		if(flags & AVI_KEY_FRAME) intra=1;
-		else			intra=0;
+		
 		switch(flags)
 		{
-			case AVI_KEY_FRAME: 	type=1;
-																		break;
-			case AVI_B_FRAME: 	type=3;
-																		break;
-			default:
-						type=2;
-						break;
+			case AVI_KEY_FRAME: 	ftype=RF_I;break;
+			case AVI_B_FRAME: 	ftype=RF_B;break;
+			default:		ftype=RF_P;break;
+		}
+		if(ftype!=ztype)
+		{
+			printf("**Frame type does not match %d %d\n",ztype,ftype);
 		}
 		aprintf("inquant  : %02d outquant %02d Intra %d size :%d flags %x\n",
 				q,outquant,intra,len,flags);
-		vbrUpdate(&mpegvbr,
-				outquant,
-				//q,
-				intra,
-				0,
-				len,
-				0,
-				0,
-				type);
+		ADM_assert(_ratecontrol->logPass2(outquant,ftype,len));
+		
 
 		total_size+=len;
 	
@@ -889,7 +867,7 @@ uint32_t		len,flags,type,outquant,audiolen;
 			{
 				
 				// write video
-				_muxer->writeVideoPacket(len,_buffer_out);
+				_muxer->writeVideoPacket(len,_buffer_out,i-MPEG_PREFILL,_codec->getCodedPictureNumber());
 						
 				PACK_AUDIO;
 			}
@@ -898,6 +876,7 @@ uint32_t		len,flags,type,outquant,audiolen;
 				
 		if(!encoding->isAlive())
 		{
+			 PRINT_QUANT_STAT
 			 end();
 			 fclose(fd);
 			 return 0;
@@ -909,34 +888,23 @@ uint32_t		len,flags,type,outquant,audiolen;
 	for(uint32_t i=0;i<MPEG_PREFILL;i++)
 	{
 		
-		q=vbrGetQuant(&mpegvbr);
+		ADM_rframe ftype;
+		uint32_t qz;
+		ADM_assert(_ratecontrol->getQz(&qz,&ftype));
+		q=qz;
 		_codec->setQuantize(q);
-		_codec->encode(		_buffer,_buffer_out , &len,&flags,&outquant);
+		_codec->encode(		aImage,_buffer_out , &len,&flags,&outquant);
+		quantstat[outquant]++;
 		encoding->setQuant(outquant);
-		if(flags & AVI_KEY_FRAME) intra=1;
-			else		intra=0;
 		switch(flags)
 		{
-			case AVI_KEY_FRAME: 	type=1;
-						break;
-			case AVI_B_FRAME: 	type=3;
-						break;
-			default:
-						type=2;
-						break;
-		}		
-
-		printf("inquant  : %02d outquant %02d Intra %d size :%d flags %x\n",q,outquant,
-					intra,len,flags);
-		vbrUpdate(&mpegvbr,
-				outquant,
-				//q,
-				intra,
-				0,
-				len,
-				0,
-				0,
-				type);
+			case AVI_KEY_FRAME: 	ftype=RF_I;break;
+			case AVI_B_FRAME: 	ftype=RF_B;break;
+			default:		ftype=RF_P;break;
+		}
+		aprintf("inquant  : %02d outquant %02d Intra %d size :%d flags %x\n",
+				q,outquant,intra,len,flags);
+		ADM_assert(_ratecontrol->logPass2(outquant,ftype,len));
 
 		total_size+=len;
 		if(!_muxer)
@@ -947,7 +915,7 @@ uint32_t		len,flags,type,outquant,audiolen;
 		else
 		{
 			// write video
-			_muxer->writeVideoPacket(len,_buffer_out);		
+			_muxer->writeVideoPacket(len,_buffer_out,_total+i-MPEG_PREFILL,_codec->getCodedPictureNumber());
 			PACK_AUDIO;
 
 		}
@@ -967,6 +935,7 @@ uint32_t		len,flags,type,outquant,audiolen;
 		_muxer=NULL;	
 	}
 
+	PRINT_QUANT_STAT
 	 end();
 	return 1;
 }
@@ -998,9 +967,10 @@ uint8_t mpegWritter::end( void )
 	_codec=NULL;
 	// grab last bytes
 
-	if(_buffer) delete [] _buffer;
+	if(aImage) delete  aImage;
 	if(_buffer_out) delete [] _buffer_out;
-	_buffer=_buffer_out=NULL;
+	aImage=NULL;
+	_buffer_out=NULL;
 	
 	if(_audioBuffer)
 	{
@@ -1013,6 +983,11 @@ uint8_t mpegWritter::end( void )
 		delete _muxer;
 		_muxer=NULL;
 	}
+	if(_ratecontrol)
+	{
+		delete _ratecontrol;
+		_ratecontrol=NULL;
+	}
       return 1;
 }
 
@@ -1026,12 +1001,12 @@ int dummy_func_mpeg( int i )
 //
 //	Set up the audio chain for audio+video writting
 //
-uint8_t mpegWritter::initLveMux( char *name )
+uint8_t mpegWritter::initLveMux( char *name,ADM_MUXER_TYPE type )
 {
 double one_pcm_audio_frame;
 uint32_t fps1000;
 
-	_audio=mpt_getAudioStream(&one_pcm_audio_frame);
+	_audio=mpt_getAudioStream();
 	if(!_audio)
 	{
 		printf("Cannot initialize lvemux\n");
@@ -1039,14 +1014,19 @@ uint32_t fps1000;
 	}
 	fps1000=getLastVideoFilter()->getInfo()->fps1000;
 	
-  	printf (" One audio frame : %f bytes\n", one_pcm_audio_frame);
-  	_audioOneFrame=one_pcm_audio_frame;
+  	
+  	
 	_audioBuffer=new uint8_t[MAXAUDIO]; // equivalent to 1 sec @ 448 kbps, should be more than
 					// enough, even with the buffering
 	printf("----- Audio Track for mpeg Ready.------\n");
 	
-	_muxer=new MpegMuxer();
-	if(!_muxer->open(name,MUX_MPEG_VRATE,fps1000,_audio->getInfo(),(float)one_pcm_audio_frame))
+	_muxer=new lavMuxer();	
+	// open( char *filename, uint32_t vbitrate, aviInfo *info, WAVHeader *audioheader,float need);
+	aviInfo info;
+	info.width=getLastVideoFilter()->getInfo()->width;
+	info.height=getLastVideoFilter()->getInfo()->height;
+	info.fps1000=getLastVideoFilter()->getInfo()->fps1000;
+	if(!_muxer->open(name,0,type,&info,_audio->getInfo()))
 	{
 		delete _muxer;
 		_muxer=NULL;
@@ -1059,118 +1039,31 @@ uint32_t fps1000;
 }
 
 
-AVDMGenericAudioStream *mpt_getAudioStream(double *mypcm,uint8_t silent)
+AVDMGenericAudioStream *mpt_getAudioStream(void)
 {
-
-// Second check the audio track
-  	uint32_t fps1000;
-	uint32_t one_pcm_audio_frame;
-	int err;
-	AVDMGenericAudioStream *_audio=NULL;
-     
-	
-	if(!currentaudiostream) return NULL;
-	
-      	// compute the number of bytes in the incoming stream
-      	// to feed the filter chain
-      	double	byt;
-      	byt =	video_body->getTime (frameEnd + 1) - video_body->getTime (frameStart);
-      	byt *= currentaudiostream->getInfo ()->frequency;
-      	byt *= currentaudiostream->getInfo ()->channels;
-      	byt *= 2;
-      	byt /= 1000.;
-
-	if(audioProcessMode)
+AVDMGenericAudioStream *audio=NULL;
+	if (audioProcessMode)	// else Raw copy mode
 	{
-      		_audio = buildAudioFilter (currentaudiostream,video_body->getTime (frameStart),
-				  (uint32_t) floor (byt));
-	}
-	else
-	{				
-        	uint32_t    tstart,tend;
-		int32_t shift=0;
-		
-		if(!silent)
+		if (currentaudiostream->isCompressed ())
 		{
-			if(!  DIA_GetIntegerValue((int*)&shift, -1000, +1000, "Audio/video shift", 
-				"Audio Video Shift (ms):"))
+			if (!currentaudiostream->isDecompressable ())
 			{
-				return 0;		
+				return NULL;
 			}
 		}
-		else
-		{
-			shift=0;
-		}
-		
-	  	tstart = video_body->getTime (frameStart);		
-		tend = video_body->getTime (frameEnd);
-		deleteAudioFilter();
-		_audio=buildRawAudioFilter(  tstart, tend-tstart, shift);
+	      	audio = buildAudioFilter (currentaudiostream,video_body->getTime (frameStart),
+				  (uint32_t) 0xffffffff);
 	}
-   	
-	if(_audio->getInfo()->encoding!=WAV_MP2 && _audio->getInfo()->encoding!=WAV_AC3)
+  	else // copymode
 	{
-		deleteAudioFilter();
-		return NULL;
+	// else prepare the incoming raw stream
+	// audio copy mode here
+	int32_t shift=0;
+	if(audioDelay && audioShift) shift=audioDelay;
+	audio=buildRawAudioFilter( video_body->getTime (frameStart), 
+		0xffffffff, shift);
 	}
-	//________________
-	uint32_t one_frame;
-  	aviInfo   info;
-	double    one_frame_double, one_delta_frame;
-  	WAVHeader *wav = NULL;
-
-  	ADM_assert (_audio);
-
-  	wav = _audio->getInfo ();
-  
-	if(videoProcessMode)
-	{
-  		fps1000 = getLastVideoFilter()->getInfo()->fps1000;
-	}else
-	{
-		fps1000 = avifileinfo->fps1000;
-	}
-  	
-  	// compute duration of a audio frame
-  	// in ms
-  	ADM_assert (fps1000);
-  	printf (" fps : %lu\n", fps1000);
-  	one_frame_double = (double) fps1000;
-  	one_frame_double = 1. / one_frame_double;
-  	// now we have 1/1000*fps=1/1000*duration of a frame in second
-  	one_frame_double *= 1000000.;
-  	// in ms now;
-  	one_frame = (uint32_t) floor (one_frame_double);
-  	printf (" One audio frame : %lu (%f) ms\n", one_frame,one_frame_double);
-
-
-  	double    pcm;
-  	// *2 because one sample is 16 bits
-  	// fix hitokiri bug part 1.
-  	pcm = one_frame_double * 2.;
-	pcm*= wav->frequency;
-	pcm*= wav->channels;
-  	pcm/= 1000.;
-  	one_pcm_audio_frame = (uint32_t) floor (pcm+0.5);
-  	printf (" one PCM audio frame is %lu bytes (%f) \n", one_pcm_audio_frame,pcm);
-
-  	// get the equivalent in bytes
-  	ADM_assert (wav);
-  	one_frame_double /= 1000.;	// go back to seconds
-  	one_frame_double *= wav->byterate;
-
-
-	  one_frame = (uint32_t) floor (one_frame_double+0.5);
-	
-  	#define SCALE 100.
-	*mypcm=one_frame_double;
-	// do some round up if needed, 100 is enough (?)
-	one_pcm_audio_frame=(uint32_t)floor(SCALE*(*mypcm)+0.5);
-	*mypcm=one_pcm_audio_frame;
-	*mypcm/=SCALE;
-	printf (" one coded audio frame is %lu bytes (%f was %f \n", one_frame,*mypcm,one_frame_double);  	
-	
-	return _audio;
+	return audio;
 }
+// EOF
 
