@@ -4,7 +4,7 @@
 #include <strings.h>
 #include <unistd.h>	/* access(), R_OK */
 #include <errno.h>	/* errno, ENOENT */
-#include <ADM_assert.h>
+
 #include "ADM_library/default.h"
 #include "ADM_toolkit/toolkit.hxx"
 
@@ -14,6 +14,9 @@
 #include <libxml/tree.h>
 #include <libxml/parser.h>
 #endif
+#include <ADM_assert.h>
+
+#undef free
 
 extern char *PathCanonize(const char *tmpname);
 
@@ -37,18 +40,45 @@ typedef struct {
 } opt_def;
 
 static opt_def opt_defs [] = {
-	{"codecs.mpeg2enc.svcd.maxbitrate",		UINT,	"2600",	NULL,	"0",	"2500"	},
-	{"codecs.mpeg2enc.svcd.quantisation",		UINT,	"10",	NULL,	"2",	"31"	},
-	{"codecs.mpeg2enc.svcd.ExtraParams",		STRING,"",	NULL, NULL, NULL },
-	{"codecs.mpeg2enc.dvd.maxbitrate",		UINT,	"9500",	NULL,	"0",	"9800"	},
-	{"codecs.mpeg2enc.dvd.quantisation",		UINT,	"7",	NULL,	"2",	"31"	},
-	{"codecs.mpeg2enc.dvd.ExtraParams",		STRING,"",	NULL, NULL, NULL },
+	{"codecs.svcd.enctype",		UINT,	"0",	NULL,	"0",	"99999"},
+	{"codecs.svcd.bitrate",		UINT,	"1500000",NULL,	"16000","2748000"},
+	{"codecs.svcd.quantizer",		UINT,	"4",	NULL,	"2",	"31"	},
+	{"codecs.svcd.finalsize",	UINT,	"700",	NULL,	"0",	"99999"},
+	{"codecs.svcd.interlaced",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"codecs.svcd.bff",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"codecs.svcd.widescreen",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"codecs.svcd.matrix",		UINT,	"0",	NULL,	"0",	"99999"},
+	{"codecs.svcd.gopsize",		UINT,	"12",	NULL,	"0",	"99999"},
+	{"codecs.svcd.maxbitrate",		UINT,	"2500",	NULL,	"0",	"2748"	},
+	{"codecs.dvd.enctype",		UINT,	"0",	NULL,	"0",	"99999"},
+	{"codecs.dvd.bitrate",		UINT,	"1500000",NULL,	"16000","9900000"},
+	{"codecs.dvd.quantizer",		UINT,	"4",	NULL,	"2",	"31"	},
+	{"codecs.dvd.finalsize",	UINT,	"700",	NULL,	"0",	"99999"},
+	{"codecs.dvd.interlaced",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"codecs.dvd.bff",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"codecs.dvd.widescreen",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"codecs.dvd.matrix",		UINT,	"0",	NULL,	"0",	"99999"},
+	{"codecs.dvd.gopsize",		UINT,	"12",	NULL,	"0",	"99999"},
+	{"codecs.dvd.maxbitrate",		UINT,	"9000",	NULL,	"0",	"9900"	},
+	{"codecs.xvid.enctype",		UINT,	"0",	NULL,	"0",	"99999"},
+	{"codecs.xvid.quantizer",		UINT,	"4",	NULL,	"2",	"32"	},
+	{"codecs.xvid.bitrate",		UINT,	"1500000",NULL,	"17",	"5900000"},
+	{"codecs.xvid.finalsize",	UINT,	"700",	NULL,	"0",	"3999"	},
+	{"filters.subtitle.fontname",		STRING,"/usr/X11R6/lib/X11/fonts/truetype/arial.ttf",NULL, NULL, NULL },
+	{"filters.subtitle.charset",		STRING,"ISO-8859-1",NULL, NULL, NULL },
+	{"filters.subtitle.fontsize",		UINT,	"24",	NULL,	"1",	"576"	},
+	{"filters.subtitle.ypercent",	INT,	"255",	NULL,	"0",	"255"	},
+	{"filters.subtitle.upercent",		INT,	"0",	NULL,	"0",	"255"	},
+	{"filters.subtitle.vpercent",		INT,	"0",	NULL,	"0",	"255"	},
+	{"filters.subtitle.selfadjustable",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"filters.subtitle.usebackgroundcolor",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"test.string",		STRING,"abcdhfgd",NULL, NULL, NULL },
 	{"test.int",		INT,	"0",	NULL,	"-3",	"3"	},
 	{"test.uint",		UINT,	"1",	NULL,	"0",	"3"	},
 	{"test.long",		LONG,	"1",	NULL,	"-4",	"999999999999"},
 	{"test.ulong",		ULONG,	"2",	NULL,	"0",	"999999999999"},
 	{"test.float",	FLOAT,	"0.0",	NULL,	"-0.35","0.35"	},
+	{"settings.mpegsplit",	UINT,	"790",	NULL,	"400",	"900"	},
 	{"codecs.preferredcodec",		STRING,"FFmpeg4",NULL, NULL, NULL },
 	{"device.audiodevice",	STRING,"OSS",	NULL, NULL, NULL },
 	{"lastfiles.file1",		STRING,"",	NULL, NULL, NULL },
@@ -65,10 +95,14 @@ static opt_def opt_defs [] = {
 	{"requant_path",		STRING,"",	NULL, NULL, NULL },
 	{"feature.swap_if_A_greater_than_B",		UINT,	"1",	NULL,	"0",	"1"	},
 	{"feature.svcdres.preferedsourceratio",		STRING,"1:1",	NULL, NULL, NULL },
-	{"feature.saveprefsonexit",		UINT,	"1",	NULL,	"0",	"1"	}
+	{"feature.saveprefsonexit",		UINT,	"1",	NULL,	"0",	"1"	},
+	{"feature.ignoresavedmarkers",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"feature.use_lavcodec_mpeg",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"feature.disable_nuv_resync",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"feature.tryautoidx",		UINT,	"0",	NULL,	"0",	"1"	}
 };
 
-int num_opts = 29;
+int num_opts = 60;
 // </prefs_gen>
 
 #ifdef USE_LIBXML2
@@ -130,7 +164,7 @@ xmlNodePtr goto_node_with_create(xmlNodePtr cur, const char *str){
 
 void set_content(const char *option, xmlNodePtr x){
    int idx = -1;
-   char *str;
+   char *str,*str2;
 	for( int i=0; i < num_opts; i++ ){
 		if( !strcmp(opt_defs[i].name,option) ){
 			idx = i;
@@ -145,9 +179,14 @@ void set_content(const char *option, xmlNodePtr x){
 		fprintf(stderr,"no content in xmlNode for option \"%s\".\n",option);
 		return;
 	}
+	
+	str2=(char *)ADM_alloc(strlen(str)+1);
+	strcpy(str2,str);
+	free(str);
+	
 	if( opt_defs[idx].current_val )
-		free(opt_defs[idx].current_val);
-	opt_defs[idx].current_val = str;
+		ADM_dealloc(opt_defs[idx].current_val);
+	opt_defs[idx].current_val = str2;
 	#ifdef DEBUG_PREFS
 	fprintf(stderr,"Prefs: %s => %s\n",opt_defs[idx].name,opt_defs[idx].current_val);
 	#endif
@@ -169,7 +208,7 @@ preferences::~preferences(){
   unsigned int idx;
 	for( idx=0; idx < 4; idx++ ){
 		if( internal_lastfiles[idx] )
-			free(internal_lastfiles[idx]);
+			ADM_dealloc(internal_lastfiles[idx]);
 	}
 	#ifdef USE_LIBXML2
 	if( xdoc )
@@ -473,7 +512,7 @@ int preferences::get(options option, char **val){
 		p = opt_defs[option].default_val;
 	// no type check : every value can be represented by a string
 	// not an error -> it's a magic feature
-	if( (*val = strdup(p) ) )
+	if( (*val = ADM_strdup(p) ) )
 		return RC_OK;
 	return RC_FAILED; // strdup() out of memory
 }
@@ -481,6 +520,7 @@ int preferences::get(options option, char **val){
 int preferences::set(options option, const unsigned int val){
    unsigned int l,r;
    char buf[1024];
+   unsigned int v = val;
 	// check type of option
 	if( opt_defs[option].type != UINT ){
 		fprintf(stderr,"preferences::set(%s,uint) called for type %d\n",
@@ -496,20 +536,22 @@ int preferences::set(options option, const unsigned int val){
 		fprintf(stderr,"error reading opt_defs[option].maximum\n");
 		return RC_FAILED;
 	}
-	if( val < l ){
-		fprintf(stderr,"%s : value < min : %u < %u\n", opt_defs[option].name, val, l);
-		return RC_FAILED;
+	if( v < l ){
+		fprintf(stderr,"%s : value < min : %u < %u\n", opt_defs[option].name, v, l);
+		v = l;
+		fprintf(stderr,"   using %u as value instead.\n", v);
 	}
-	if( val > r ){
-		fprintf(stderr,"%s : value > max : %u > %u\n", opt_defs[option].name, val, r);
-		return RC_FAILED;
+	if( v > r ){
+		fprintf(stderr,"%s : value > max : %u > %u\n", opt_defs[option].name, v, r);
+		v = r;
+		fprintf(stderr,"   using %u as value instead.\n", v);
 	}
 	// set value
 	if( opt_defs[option].current_val )
-		free(opt_defs[option].current_val);
-	snprintf(buf,1024,"%u",val);
+		ADM_dealloc(opt_defs[option].current_val);
+	snprintf(buf,1024,"%u",v);
 	buf[1023] = '\0';
-	opt_defs[option].current_val = strdup(buf);
+	opt_defs[option].current_val = ADM_strdup(buf);
 	if( ! opt_defs[option].current_val )
 		return RC_FAILED;
 	return RC_OK;
@@ -518,6 +560,7 @@ int preferences::set(options option, const unsigned int val){
 int preferences::set(options option, const int val){
    int l,r;
    char buf[1024];
+   int v = val;
 	// check type of option
 	if( opt_defs[option].type != INT ){
 		fprintf(stderr,"preferences::set(%s,int) called for type %d\n",
@@ -532,20 +575,22 @@ int preferences::set(options option, const int val){
 		fprintf(stderr,"error reading opt_defs[option].maximum\n");
 		return RC_FAILED;
 	}
-	if( val < l ){
-		fprintf(stderr,"%s : value < min : %d < %d\n", opt_defs[option].name, val, l);
-		return RC_FAILED;
+	if( v < l ){
+		fprintf(stderr,"%s : value < min : %d < %d\n", opt_defs[option].name, v, l);
+		v = l;
+		fprintf(stderr,"   using %d as value instead.\n", v);
 	}
-	if( val > r ){
-		fprintf(stderr,"%s : value > max : %d > %d\n", opt_defs[option].name, val, r);
-		return RC_FAILED;
+	if( v > r ){
+		fprintf(stderr,"%s : value > max : %d > %d\n", opt_defs[option].name, v, r);
+		v = r;
+		fprintf(stderr,"   using %d as value instead.\n", v);
 	}
 	// set value
 	if( opt_defs[option].current_val )
-		free(opt_defs[option].current_val);
-	snprintf(buf,1024,"%d",val);
+		ADM_dealloc(opt_defs[option].current_val);
+	snprintf(buf,1024,"%d",v);
 	buf[1023] = '\0';
-	opt_defs[option].current_val = strdup(buf);
+	opt_defs[option].current_val = ADM_strdup(buf);
 	if( ! opt_defs[option].current_val )
 		return RC_FAILED;
 	return RC_OK;
@@ -554,6 +599,7 @@ int preferences::set(options option, const int val){
 int preferences::set(options option, const unsigned long val){
    unsigned long l,r;
    char buf[1024];
+   unsigned long v = val;
 	// check type of option
 	if( opt_defs[option].type != ULONG ){
 		fprintf(stderr,"preferences::set(%s,ulong) called for type %d\n",
@@ -569,20 +615,22 @@ int preferences::set(options option, const unsigned long val){
 		fprintf(stderr,"error reading opt_defs[option].maximum\n");
 		return RC_FAILED;
 	}
-	if( val < l ){
-		fprintf(stderr,"%s : value < min : %lu < %lu\n", opt_defs[option].name, val, l);
-		return RC_FAILED;
+	if( v < l ){
+		fprintf(stderr,"%s : value < min : %lu < %lu\n", opt_defs[option].name, v, l);
+		v = l;
+		fprintf(stderr,"   using %lu as value instead.\n", v);
 	}
-	if( val > r ){
-		fprintf(stderr,"%s : value > max : %lu > %lu\n", opt_defs[option].name, val, r);
-		return RC_FAILED;
+	if( v > r ){
+		fprintf(stderr,"%s : value > max : %lu > %lu\n", opt_defs[option].name, v, r);
+		v = r;
+		fprintf(stderr,"   using %lu as value instead.\n", v);
 	}
 	// set value
 	if( opt_defs[option].current_val )
-		free(opt_defs[option].current_val);
-	snprintf(buf,1024,"%lu",val);
+		ADM_dealloc(opt_defs[option].current_val);
+	snprintf(buf,1024,"%lu",v);
 	buf[1023] = '\0';
-	opt_defs[option].current_val = strdup(buf);
+	opt_defs[option].current_val = ADM_strdup(buf);
 	if( ! opt_defs[option].current_val )
 		return RC_FAILED;
 	return RC_OK;
@@ -591,6 +639,7 @@ int preferences::set(options option, const unsigned long val){
 int preferences::set(options option, const long val){
    long l,r;
    char buf[1024];
+   long v = val;
 	// check type of option
 	if( opt_defs[option].type != LONG ){
 		fprintf(stderr,"preferences::set(%s,long) called for type %d\n",
@@ -606,20 +655,22 @@ int preferences::set(options option, const long val){
 		fprintf(stderr,"error reading opt_defs[option].maximum\n");
 		return RC_FAILED;
 	}
-	if( val < l ){
-		fprintf(stderr,"%s : value < min : %ld < %ld\n", opt_defs[option].name, val, l);
-		return RC_FAILED;
+	if( v < l ){
+		fprintf(stderr,"%s : value < min : %ld < %ld\n", opt_defs[option].name, v, l);
+		v = l;
+		fprintf(stderr,"   using %ld as value instead.\n", v);
 	}
-	if( val > r ){
-		fprintf(stderr,"%s : value > max : %ld > %ld\n", opt_defs[option].name, val, r);
-		return RC_FAILED;
+	if( v > r ){
+		fprintf(stderr,"%s : value > max : %ld > %ld\n", opt_defs[option].name, v, r);
+		v = r;
+		fprintf(stderr,"   using %ld as value instead.\n", v);
 	}
 	// set value
 	if( opt_defs[option].current_val )
-		free(opt_defs[option].current_val);
-	snprintf(buf,1024,"%ld",val);
+		ADM_dealloc(opt_defs[option].current_val);
+	snprintf(buf,1024,"%ld",v);
 	buf[1023] = '\0';
-	opt_defs[option].current_val = strdup(buf);
+	opt_defs[option].current_val = ADM_strdup(buf);
 	if( ! opt_defs[option].current_val )
 		return RC_FAILED;
 	return RC_OK;
@@ -628,6 +679,7 @@ int preferences::set(options option, const long val){
 int preferences::set(options option, const float val){
    float l,r;
    char buf[1024];
+   float v = val;
 	// check type of option
 	if( opt_defs[option].type != FLOAT ){
 		fprintf(stderr,"preferences::set(%s,float) called for type %d\n",
@@ -643,20 +695,22 @@ int preferences::set(options option, const float val){
 		fprintf(stderr,"error reading opt_defs[option].maximum\n");
 		return RC_FAILED;
 	}
-	if( val < l ){
-		fprintf(stderr,"%s : value < min : %f < %f\n", opt_defs[option].name, val, l);
-		return RC_FAILED;
+	if( v < l ){
+		fprintf(stderr,"%s : value < min : %f < %f\n", opt_defs[option].name, v, l);
+		v = l;
+		fprintf(stderr,"   using %f as value instead.\n", v);
 	}
-	if( val > r ){
-		fprintf(stderr,"%s : value > max : %f > %f\n", opt_defs[option].name, val, r);
-		return RC_FAILED;
+	if( v > r ){
+		fprintf(stderr,"%s : value > max : %f > %f\n", opt_defs[option].name, v, r);
+		v = r;
+		fprintf(stderr,"   using %f as value instead.\n", v);
 	}
 	// set value
 	if( opt_defs[option].current_val )
-		free(opt_defs[option].current_val);
-	snprintf(buf,1024,"%f",val);
+		ADM_dealloc(opt_defs[option].current_val);
+	snprintf(buf,1024,"%f",v);
 	buf[1023] = '\0';
-	opt_defs[option].current_val = strdup(buf);
+	opt_defs[option].current_val = ADM_strdup(buf);
 	if( ! opt_defs[option].current_val )
 		return RC_FAILED;
 	return RC_OK;
@@ -674,8 +728,8 @@ int preferences::set(options option, const char * val){
 		return RC_FAILED;
 	// set value
 	if( opt_defs[option].current_val )
-		free(opt_defs[option].current_val);
-	opt_defs[option].current_val = strdup(val);
+		ADM_dealloc(opt_defs[option].current_val);
+	opt_defs[option].current_val = ADM_strdup(val);
 	if( ! opt_defs[option].current_val )
 		return RC_FAILED;
 	return RC_OK;
@@ -741,11 +795,11 @@ int preferences::set_lastfile(const char* file){
 		; // nothing to do - always on top
 	}else{
 		if( opt_defs[LASTFILES_FILE4].current_val )
-			free(opt_defs[LASTFILES_FILE4].current_val);
+			ADM_dealloc(opt_defs[LASTFILES_FILE4].current_val);
 		opt_defs[LASTFILES_FILE4].current_val = opt_defs[LASTFILES_FILE3].current_val;
 		opt_defs[LASTFILES_FILE3].current_val = opt_defs[LASTFILES_FILE2].current_val;
 		opt_defs[LASTFILES_FILE2].current_val = opt_defs[LASTFILES_FILE1].current_val;
-		opt_defs[LASTFILES_FILE1].current_val = strdup(internal_file);
+		opt_defs[LASTFILES_FILE1].current_val = ADM_strdup(internal_file);
 	}
 
 #ifdef USE_LIBXML2
@@ -790,7 +844,7 @@ int preferences::set_lastfile(const char* file){
 	PRT_LAFI("=> LASTFILES_",3,opt_defs[LASTFILES_FILE3].current_val);
 	PRT_LAFI("=> LASTFILES_",4,opt_defs[LASTFILES_FILE4].current_val);
 #endif
-	free(internal_file);
+	ADM_dealloc(internal_file);
 	return RC_OK;
 }
 
@@ -804,18 +858,18 @@ const char **preferences::get_lastfiles(void){
 #endif
 	for( idx=0; idx < 4; idx++ ){
 		if( internal_lastfiles[idx] ){
-			free(internal_lastfiles[idx]);
+			ADM_dealloc(internal_lastfiles[idx]);
 			internal_lastfiles[idx] = NULL;
 		}
 	}
 	if( opt_defs[LASTFILES_FILE1].current_val )
-		internal_lastfiles[0] = strdup(opt_defs[LASTFILES_FILE1].current_val);
+		internal_lastfiles[0] = ADM_strdup(opt_defs[LASTFILES_FILE1].current_val);
 	if( opt_defs[LASTFILES_FILE2].current_val )
-		internal_lastfiles[1] = strdup(opt_defs[LASTFILES_FILE2].current_val);
+		internal_lastfiles[1] = ADM_strdup(opt_defs[LASTFILES_FILE2].current_val);
 	if( opt_defs[LASTFILES_FILE3].current_val )
-		internal_lastfiles[2] = strdup(opt_defs[LASTFILES_FILE3].current_val);
+		internal_lastfiles[2] = ADM_strdup(opt_defs[LASTFILES_FILE3].current_val);
 	if( opt_defs[LASTFILES_FILE4].current_val )
-		internal_lastfiles[3] = strdup(opt_defs[LASTFILES_FILE4].current_val);
+		internal_lastfiles[3] = ADM_strdup(opt_defs[LASTFILES_FILE4].current_val);
 	internal_lastfiles[4] = NULL;
 
 #ifdef DEBUG_PREFS
