@@ -8,18 +8,45 @@
 
 // <prefs_gen>
 typedef enum {
-	CODECS_MPEG2ENC_SVCD_MAXBITRATE,
-	CODECS_MPEG2ENC_SVCD_QUANTISATION,
-	CODECS_MPEG2ENC_SVCD_EXTRAPARAMS,
-	CODECS_MPEG2ENC_DVD_MAXBITRATE,
-	CODECS_MPEG2ENC_DVD_QUANTISATION,
-	CODECS_MPEG2ENC_DVD_EXTRAPARAMS,
+	CODECS_SVCD_ENCTYPE,
+	CODECS_SVCD_BITRATE,
+	CODECS_SVCD_QUANTIZER,
+	CODECS_SVCD_FINALSIZE,
+	CODECS_SVCD_INTERLACED,
+	CODECS_SVCD_BFF,
+	CODECS_SVCD_WIDESCREEN,
+	CODECS_SVCD_MATRIX,
+	CODECS_SVCD_GOPSIZE,
+	CODECS_SVCD_MAXBITRATE,
+	CODECS_DVD_ENCTYPE,
+	CODECS_DVD_BITRATE,
+	CODECS_DVD_QUANTIZER,
+	CODECS_DVD_FINALSIZE,
+	CODECS_DVD_INTERLACED,
+	CODECS_DVD_BFF,
+	CODECS_DVD_WIDESCREEN,
+	CODECS_DVD_MATRIX,
+	CODECS_DVD_GOPSIZE,
+	CODECS_DVD_MAXBITRATE,
+	CODECS_XVID_ENCTYPE,
+	CODECS_XVID_QUANTIZER,
+	CODECS_XVID_BITRATE,
+	CODECS_XVID_FINALSIZE,
+	FILTERS_SUBTITLE_FONTNAME,
+	FILTERS_SUBTITLE_CHARSET,
+	FILTERS_SUBTITLE_FONTSIZE,
+	FILTERS_SUBTITLE_YPERCENT,
+	FILTERS_SUBTITLE_UPERCENT,
+	FILTERS_SUBTITLE_VPERCENT,
+	FILTERS_SUBTITLE_SELFADJUSTABLE,
+	FILTERS_SUBTITLE_USEBACKGROUNDCOLOR,
 	TEST_STRING,
 	TEST_INT,
 	TEST_UINT,
 	TEST_LONG,
 	TEST_ULONG,
 	TEST_FLOAT,
+	SETTINGS_MPEGSPLIT,
 	CODECS_PREFERREDCODEC,
 	DEVICE_AUDIODEVICE,
 	LASTFILES_FILE1,
@@ -36,7 +63,11 @@ typedef enum {
 	REQUANT_PATH,
 	FEATURE_SWAP_IF_A_GREATER_THAN_B,
 	FEATURE_SVCDRES_PREFEREDSOURCERATIO,
-	FEATURE_SAVEPREFSONEXIT
+	FEATURE_SAVEPREFSONEXIT,
+	FEATURE_IGNORESAVEDMARKERS,
+	FEATURE_USE_LAVCODEC_MPEG,
+	FEATURE_DISABLE_NUV_RESYNC,
+	FEATURE_TRYAUTOIDX
 } options;
 // </prefs_gen>
 
